within SorpLib.Applications.AdsorptionChiller.ModelicaMediaLibrary.Tester;
model TestOneBedAdsorptionChiller
  "Model to test one-bed adsorption chiller model"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  OneBedAdsorptionChiller adsorptionChiller(
    evaporatorGeometry(length=7),
    condenserGeometry(length=6),
    adsorberGeometry(length_hx=10),
    is_flapValve=true,
    use_casing_evap=true,
    use_casing_cond=true,
    use_casing_ads=true)
                       "Model of the one-bed adsorption chiller"
    annotation (Placement(transformation(extent={{-30,-30},{30,30}})));

  //
  // Definition of boundaries
  //
protected
  Components.Boundaries.ModelicaMediaLibrary.LiquidBoundary adsorberInlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.VolumeFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.1,
    V_flow(displayUnit="l/min") = -0.00016666666666667,
    use_TInput=true,
    T=313.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Inlet boundary for adsorber"
    annotation (Placement(transformation(extent={{-70,-20},{-50,0}})));

  Components.Boundaries.ModelicaMediaLibrary.LiquidBoundary adsorberOutlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    p=1000000,
    m_flow=-0.1,
    T=313.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Outlet boundary for adsorber"
    annotation (Placement(transformation(extent={{-70,0},{-50,20}})));
  Modelica.Blocks.Sources.Pulse temperatureInput(
    amplitude=60,
    period=1000,
    offset=273.15 + 30) "Temperature input for adsorber heat exchanger"
    annotation (Placement(transformation(extent={{-100,-20},{-80,0}})));
  Components.Boundaries.ModelicaMediaLibrary.LiquidBoundary evaporatorInlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.VolumeFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.1,
    V_flow(displayUnit="l/min") = -0.00016666666666667,
    use_TInput=false,
    T=283.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Inlet boundary for evaporator"
    annotation (Placement(transformation(extent={{-70,-50},{-50,-30}})));

  Components.Boundaries.ModelicaMediaLibrary.LiquidBoundary evaporatorOutlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    p=100000,
    m_flow=-0.1,
    T=313.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Outlet boundary for evaporator"
    annotation (Placement(transformation(extent={{50,-50},{70,-30}})));
  Components.Boundaries.ModelicaMediaLibrary.LiquidBoundary condenserInlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.VolumeFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.1,
    V_flow(displayUnit="l/min") = -0.00016666666666667,
    use_TInput=false,
    T=303.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Inlet boundary for condenser"
    annotation (Placement(transformation(extent={{-70,30},{-50,50}})));

  Components.Boundaries.ModelicaMediaLibrary.LiquidBoundary condenserOutlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    p=100000,
    m_flow=-0.1,
    T=313.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Outlet boundary for condenser"
    annotation (Placement(transformation(extent={{50,30},{70,50}})));

equation
  //
  // Connection of fluid ports
  //
  connect(evaporatorInlet.port, adsorptionChiller.evaporator_in) annotation (
      Line(
      points={{-60,-40},{-40,-40},{-40,-21},{-30,-21}},
      color={28,108,200},
      thickness=1));
  connect(adsorptionChiller.evaporator_out, evaporatorOutlet.port) annotation (
      Line(
      points={{30,-21},{40,-21},{40,-40},{60,-40}},
      color={28,108,200},
      thickness=1));
  connect(condenserInlet.port, adsorptionChiller.condenser_in) annotation (Line(
      points={{-60,40},{-40,40},{-40,21},{-30,21}},
      color={28,108,200},
      thickness=1));
  connect(condenserOutlet.port, adsorptionChiller.condenser_out) annotation (
      Line(
      points={{60,40},{40,40},{40,21},{30,21}},
      color={28,108,200},
      thickness=1));
  connect(adsorberInlet.port, adsorptionChiller.adsorberBedOne_in) annotation (
      Line(
      points={{-60,-10},{-40,-10},{-40,-3.6},{-30,-3.6}},
      color={28,108,200},
      thickness=1));
  connect(adsorberOutlet.port, adsorptionChiller.adsorberBedOne_out)
    annotation (Line(
      points={{-60,10},{-40,10},{-40,4.2},{-30,4.2}},
      color={28,108,200},
      thickness=1));
  connect(temperatureInput.y, adsorberInlet.T_input) annotation (Line(points={{-79,
          -10},{-70,-10},{-70,-17},{-61.2,-17}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=10000), Documentation(revisions="<html>
<ul>
  <li>
  January 25, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestOneBedAdsorptionChiller;
