within SorpLib.Applications.AdsorptionChiller.TILMediaLibrary;
model TwoBedAdsorptionChiller
  "Two-bed adsorption chiller model based on the TILMedia library"
  extends BasesClasses.PartialTwoBedSystem_N1_TILMediaLibrary;

  //
  // Definition of variables
  //
  SummaryRecords.TwoBedSystem_N1 summary(
    final evaporator=evaporator.summary,
    final condenser=condenser.summary,
    final adsorberBedOne=adsorberBedOne.summary,
    final adsorberBedTwo=adsorberBedTwo.summary,
    final mass_sorbent=2*m_sorbent,
    final mass_hx_ads=sum(adsorberBedOne.liquidHeatExchanger.wallCells.mass) +
      sum(adsorberBedTwo.liquidHeatExchanger.wallCells.mass),
    final mass_hx_evap=sum(evaporator.heatExchangerTubes.wallCells.mass),
    final mass_hx_cond=sum(condenser.heatExchangerTubes.wallCells.mass),
    final Q_flow_ads1_input=if avoid_events then
      (if noEvent(summary.adsorberBedOne.DH_liquid > 0) then summary.adsorberBedOne.DH_liquid else 0)
      else
      (if summary.adsorberBedOne.DH_liquid > 0 then summary.adsorberBedOne.DH_liquid else 0),
    final Q_flow_ads1_output=if avoid_events then
      (if noEvent(summary.adsorberBedOne.DH_liquid < 0) then summary.adsorberBedOne.DH_liquid else 0)
      else
      (if summary.adsorberBedOne.DH_liquid < 0 then summary.adsorberBedOne.DH_liquid else 0),
    final Q_flow_ads2_input=if avoid_events then
      (if noEvent(summary.adsorberBedTwo.DH_liquid > 0) then summary.adsorberBedTwo.DH_liquid else 0)
      else
      (if summary.adsorberBedTwo.DH_liquid > 0 then summary.adsorberBedTwo.DH_liquid else 0),
    final Q_flow_ads2_output=if avoid_events then
      (if noEvent(summary.adsorberBedTwo.DH_liquid < 0) then summary.adsorberBedTwo.DH_liquid else 0)
      else
      (if summary.adsorberBedTwo.DH_liquid < 0 then summary.adsorberBedTwo.DH_liquid else 0),
    final COP=
      max(0,summary.Q_E/(summary.Q_A_ads1_input +
      summary.Q_A_ads2_input + Modelica.Constants.small)),
    final SP_sor=
      max(0,summary.Q_E/(time*summary.mass_sorbent+Modelica.Constants.small)),
    final SH_sor_ads=max(0,summary.Q_E/
      (time*(summary.mass_sorbent+summary.mass_hx_ads)+Modelica.Constants.small)),
    final SP_sor_ads_evp_cond=max(0,summary.Q_E/
      (time*(summary.mass_sorbent+summary.mass_hx_ads+summary.mass_hx_evap+
       summary.mass_hx_cond)+Modelica.Constants.small)))
    "Record summarizing most important variables of the two-bed adsorption chiller"
    annotation (Placement(transformation(extent={{-20,100},{20,140}})));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 26, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TwoBedAdsorptionChiller;
