within SorpLib.Applications.BasesClasses;
partial model PartialOneBedSystem
  "Base model for all one-bed adsorption systems"

  //
  // Definition of general parameters
  //
  parameter Integer no_evap_cells_liquid(min=2)=10
    "Discretization number of liquid cells"
    annotation (Dialog(tab = "General", group = "Discretisation - Evaporator"),
                Evaluate=true,
                HideResult=true);
  parameter Integer no_evap_cells_wall(min=1)=no_evap_cells_liquid
    "Discretization number of wall cells (must be a facotr of no_evap_cells_liquid)"
    annotation (Dialog(tab = "General", group = "Discretisation - Evaporator"),
                Evaluate=true,
                HideResult=true);

  parameter Integer no_cond_cells_liquid(min=2)=10
    "Discretization number of liquid cells"
    annotation (Dialog(tab = "General", group = "Discretisation - Condenser"),
                Evaluate=true,
                HideResult=true);
  parameter Integer no_cond_cells_wall(min=1)=no_cond_cells_liquid
    "Discretization number of wall cells (must be a facotr of no_cond_cells_liquid)"
    annotation (Dialog(tab = "General", group = "Discretisation - Condenser"),
                Evaluate=true,
                HideResult=true);

  parameter Integer no_ads_cells_liquid(min=2)=20
    "Discretization number of liquid cells"
    annotation (Dialog(tab = "General", group = "Discretisation - Adsorber"),
                Evaluate=true,
                HideResult=true);
  parameter Integer no_ads_cells_wall(min=1)=no_ads_cells_liquid
    "Discretization number of wall cells (must be a facotr of no_ads_cells_liquid)"
    annotation (Dialog(tab = "General", group = "Discretisation - Adsorber"),
                Evaluate=true,
                HideResult=true);
  parameter Integer no_ads_cells_sorbent(min=1)=1
    "Discretization number of sorbent cells (must be a facotr of no_ads_cells_wall)"
    annotation (Dialog(tab = "General", group = "Discretisation - Adsorber"),
                Evaluate=true,
                HideResult=true);

  replaceable parameter Components.HeatExchangers.Geometry.EvaporatorCondenser
    evaporatorGeometry constrainedby
    Components.HeatExchangers.Geometry.EvaporatorCondenser
    "Geometry of evaporator"
    annotation (Dialog(tab="General", group="Geometry"),
                choicesAllMatching = true);
  replaceable parameter Components.HeatExchangers.Geometry.EvaporatorCondenser
    condenserGeometry constrainedby
    Components.HeatExchangers.Geometry.EvaporatorCondenser
    "Geometry of condenser"
    annotation (Dialog(tab="General", group="Geometry"),
                choicesAllMatching = true);
  replaceable parameter Components.ClosedAdsorbers.Geometry.ClosedAdsorber
    adsorberGeometry
    constrainedby Components.ClosedAdsorbers.Geometry.ClosedAdsorber
    "Geometry of closed adsorber"
    annotation (Dialog(tab="General", group="Geometry"),
                choicesAllMatching = true);

  parameter Boolean is_activelyCloseable = false
    "= true, if valve is actively closeable; otherwise, valve cannot be closed
     actively"
    annotation (Dialog(tab="General",group="Valve Setup"),
                Evaluate = true,
                HideResult=true);
  parameter Boolean is_flapValve = false
    "= true, if valve is flap valve; otherwise, valve is not a flap valve"
    annotation (Dialog(tab="General",group="Valve Setup"),
                Evaluate = true,
                HideResult=true);
  parameter Boolean allow_massRecovery = false
    "= true, if models for mass recovery are introduced"
    annotation (Dialog(tab="General",group="Valve Setup"),
                Evaluate = true,
                HideResult=true);

  //
  // Definition of parameters describing transport phenomena
  //
  parameter Boolean use_casing_evap = false
    " = true, to enable casing; otherwise, no casing is used"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Evaporator"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_evap_VLESide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
      (constantAlphaA=176) constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer calculation between wall cells and
    phase seperator"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Evaporator",
               enable = not use_alphaA_input),
               choices(choice(redeclare model HeatTransfer_evap_VLESide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_evap_VLESide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  parameter Internals.Types.BalancingWallElement balancingWallElement_evap=
   Internals.Types.BalancingWallElement.NS
   "Balancing method for wall cell"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Evaporator"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_evap_NS =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
    "Heat transfer model for north-south direction of wall"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Evaporator"),
                choices(choice(redeclare model HeatTransferModel_evap_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_evap_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_evap_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_evap_WE =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
      (constantR=1e12) constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
     "Heat transder model for west-east direction of wall"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Evaporator"),
                choices(choice(redeclare model HeatTransferModel_evap_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_evap_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_evap_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_evap_TubeSide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialExternalHeatTransferCoefficientLiquidTube
    "Heat transfer model for heat transfer coefficient betwenn liquid and wall
     cells"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Evaporator"),
                choices(choice(redeclare model HeatTransferModel_evap_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlpha
                          "Liquid heat exchanger | Constant alpha for each cell"),
                        choice(redeclare model HeatTransferModel_evap_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
                          "Liquid heat exchanger | Constant alphaA for each cell"),
                        choice(redeclare model HeatTransferModel_evap_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate
                          "Liquid heat exchanger | Sieder-Tate correlation"),
                        choice(redeclare model HeatTransferModel_evap_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.Schmidt
                          "Liquid heat exchanger | Schmidt-Korrelation")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_Casing_evap =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer calculation between casing and
    phase seperator"
    annotation (Dialog(tab="Transport Phenomena", group="Heat Transfer - Evaporator",
               enable = use_casing_evap),
               choices(choice(redeclare model HeatTransfer_Casing_evap =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_Casing_evap =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  replaceable model PressureDropModel_evap =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes
    "Pressure drop model"
    annotation (Dialog(tab="Transport Phenomena", group="Pressure Drop - Evaporator"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropModel_evap =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
                          "Liquid heat exchanger | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropModel_evap =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ConstantZeta
                          "Liquid heat exchanger | Constant resistance for each cell (i.e., zeta)"),
                        choice(redeclare model PressureDropModel_evap =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
                          "Liquid heat exchanger | Konakov correlation")));

  parameter Boolean use_casing_cond = false
    " = true, to enable casing; otherwise, no casing is used"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Condenser"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_cond_VLESide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
      (constantAlphaA=3174) constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer calculation between wall cells and
    phase seperator"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Condenser",
               enable = not use_alphaA_input),
               choices(choice(redeclare model HeatTransfer_cond_VLESide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_cond_VLESide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  parameter Internals.Types.BalancingWallElement balancingWallElement_cond=
   Internals.Types.BalancingWallElement.NS
   "Balancing method for wall cell"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Condenser"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_cond_NS =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
    "Heat transfer model for north-south direction of wall"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Condenser"),
                choices(choice(redeclare model HeatTransferModel_cond_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_cond_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_cond_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_cond_WE =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
      (constantR=1e12) constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
     "Heat transder model for west-east direction of wall"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Condenser"),
                choices(choice(redeclare model HeatTransferModel_cond_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_cond_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_cond_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_cond_TubeSide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.Schmidt
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialExternalHeatTransferCoefficientLiquidTube
    "Heat transfer model for heat transfer coefficient betwenn liquid and wall
     cells"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Condenser"),
                choices(choice(redeclare model HeatTransferModel_cond_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlpha
                          "Liquid heat exchanger | Constant alpha for each cell"),
                        choice(redeclare model HeatTransferModel_cond_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
                          "Liquid heat exchanger | Constant alphaA for each cell"),
                        choice(redeclare model HeatTransferModel_cond_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate
                          "Liquid heat exchanger | Sieder-Tate correlation"),
                        choice(redeclare model HeatTransferModel_cond_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.Schmidt
                          "Liquid heat exchanger | Schmidt-Korrelation")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_Casing_cond =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer calculation between casing and
    phase seperator"
    annotation (Dialog(tab="Transport Phenomena", group="Heat Transfer - Condenser",
               enable = use_casing_cond),
               choices(choice(redeclare model HeatTransfer_Casing_cond =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_Casing_cond =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  replaceable model PressureDropModel_cond =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes
    "Pressure drop model"
    annotation (Dialog(tab="Transport Phenomena", group="Pressure Drop - Condenser"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropModel_cond =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
                          "Liquid heat exchanger | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropModel_cond =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ConstantZeta
                          "Liquid heat exchanger | Constant resistance for each cell (i.e., zeta)"),
                        choice(redeclare model PressureDropModel_cond =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
                          "Liquid heat exchanger | Konakov correlation")));

  parameter Boolean use_casing_ads = false
    " = true, to enable casing; otherwise, no casing is used"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Adsorber"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_ads_WPair_to_TubeWall =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
      (constantAlphaA=153) constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer coefficient between heat exchanger
     wall cells and working pair cells"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Adsorber"),
               choices(choice(redeclare model
          HeatTransfer_ads_WPair_to_TubeWall =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model
          HeatTransfer_ads_WPair_to_TubeWall =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  parameter Internals.Types.BalancingWallElement balancingWallElement_ads=
   Internals.Types.BalancingWallElement.NS
   "Balancing method for wall cell"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Adsorber"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_ads_NS =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
    "Heat transfer model for north-south direction of wall"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Adsorber"),
                choices(choice(redeclare model HeatTransferModel_ads_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_ads_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_ads_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_ads_WE =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
      (constantR=1e12) constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
     "Heat transder model for west-east direction of wall"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Adsorber"),
                choices(choice(redeclare model HeatTransferModel_ads_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_ads_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_ads_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_ads_TubeSide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialExternalHeatTransferCoefficientLiquidTube
    "Heat transfer model for heat transfer coefficient betwenn liquid and wall
     cells"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer - Adsorber"),
                choices(choice(redeclare model HeatTransferModel_ads_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlpha
                          "Liquid heat exchanger | Constant alpha for each cell"),
                        choice(redeclare model HeatTransferModel_ads_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
                          "Liquid heat exchanger | Constant alphaA for each cell"),
                        choice(redeclare model HeatTransferModel_ads_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate
                          "Liquid heat exchanger | Sieder-Tate correlation"),
                        choice(redeclare model HeatTransferModel_ads_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.Schmidt
                          "Liquid heat exchanger | Schmidt-Korrelation")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_Casing_ads =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer calculation between casing and
    phase seperator"
    annotation (Dialog(tab="Transport Phenomena", group="Heat Transfer - Adsorber",
               enable = use_casing_ads),
               choices(choice(redeclare model HeatTransfer_Casing_ads =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_Casing_ads =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  replaceable model PressureDropModel_ads =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes
    "Pressure drop model"
    annotation (Dialog(tab="Transport Phenomena", group="Pressure Drop - Adsorber"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropModel_ads =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
                          "Liquid heat exchanger | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropModel_ads =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ConstantZeta
                          "Liquid heat exchanger | Constant resistance for each cell (i.e., zeta)"),
                        choice(redeclare model PressureDropModel_ads =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
                          "Liquid heat exchanger | Konakov correlation")));

  //
  // Definition of parameters describing the medium
  //
  parameter Integer no_components_VLE = 1
    "Number of components in VLE medium"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);
  parameter Integer no_components_liquid_evap = 1
    "Number of components in liquid heat transfer fluid of evaporator"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);
  parameter Integer no_components_liquid_cond = 1
    "Number of components in liquid heat transfer fluid of condenser"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);
  parameter Integer no_components_liquid_ads = 1
    "Number of components in liquid heat transfer fluid of adsorber"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);

  replaceable model WorkingPair =
    Media.WorkingPair.BaseClasses.PartialWorkingPair
    constrainedby Media.WorkingPair.BaseClasses.PartialWorkingPair
    "Working pair model"
    annotation (Dialog(tab="Media",group="Working Pair"),
                choicesAllMatching = true,
                Evaluate=true,
                HideResult=true);
  parameter Modelica.SIunits.Mass m_sorbent = 2.5
    "Mass of dry sorbent"
    annotation (Dialog(tab="Media",group="Working Pair"),
                HideResult=true);

  //
  // Definition of parameters describing the initialisation
  //
  parameter Modelica.SIunits.Pressure pInitial_evap_liquidCell_1=1e5+25000
    "Initial value for liquid pressure of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator"),
                HideResult = true);
  parameter Modelica.SIunits.Pressure pInitial_evap_liquidCell_N=1e5
    "Initial value for liquid pressure of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_evap_liquidCell_1=283.15
    "Initial value for liquid temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_evap_liquidCell_N=283.15
    "Initial value for liquid temperature of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_evap_wallCell_1 = 283.15
    "Initial value for wall temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_evap_wallCell_N = 283.15
    "Initial value for wall temperature of cell N"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_evap_casing = 313.15
    "Initial value for casing temperature"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator",
                enable = use_casing_evap),
                HideResult = true);

  parameter Modelica.SIunits.MassFlowRate m_flowInitial_evap_Liquid = 1e-4
    "Start value for mass flow rate"
    annotation (Dialog(tab="Initialisation", group="Start Values - Evaporator"),
                HideResult = true);

  parameter Modelica.SIunits.Pressure pInitial_cond_liquidCell_1=1e5+25000
    "Initial value for liquid pressure of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser"),
                HideResult = true);
  parameter Modelica.SIunits.Pressure pInitial_cond_liquidCell_N=1e5
    "Initial value for liquid pressure of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_cond_liquidCell_1=303.15
    "Initial value for liquid temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_cond_liquidCell_N=303.15
    "Initial value for liquid temperature of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_cond_wallCell_1 = 303.15
    "Initial value for wall temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_cond_wallCell_N = 303.15
    "Initial value for wall temperature of cell N"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_cond_casing = 313.15
    "Initial value for casing temperature"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser",
                enable = use_casing_cond),
                HideResult = true);

  parameter Modelica.SIunits.MassFlowRate m_flowInitial_cond_Liquid = 1e-4
    "Start value for mass flow rate"
    annotation (Dialog(tab="Initialisation", group="Start Values - Condenser"),
                HideResult = true);

  parameter Modelica.SIunits.Pressure pInitial_ads_liquidCell_1=10e5+25000
    "Initial value for liquid pressure of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Adsorber"),
                HideResult = true);
  parameter Modelica.SIunits.Pressure pInitial_ads_liquidCell_N=10e5
    "Initial value for liquid pressure of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Adsorber"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_ads_liquidCell_1=303.15
    "Initial value for liquid temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Adsorber"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_ads_liquidCell_N=303.15
    "Initial value for liquid temperature of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Adsorber"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_ads_wallCell_1 = 303.15
    "Initial value for wall temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Adsorber"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_ads_wallCell_N = 303.15
    "Initial value for wall temperature of cell N"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Adsorber"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_ads_WPair = 303.15
    "Initial value for equilibrium temperature of adsorbate"
    annotation (Dialog(group = "Initial Values - Adsorber", tab = "Initialisation"),
                HideResult=true);

  parameter Modelica.SIunits.Temperature TInitial_ads_casing = 313.15
    "Initial value for casing temperature"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Adsorber",
                enable = use_casing_ads),
                HideResult = true);

  parameter Modelica.SIunits.MassFlowRate m_flowInitial_ads_Liquid = 1e-4
    "Start value for mass flow rate"
    annotation (Dialog(tab="Initialisation", group="Start Values - Adsorber"),
                HideResult = true);

  //
  // Definition of parameters describing advanced options
  //
  parameter Boolean avoid_events = true
    "= true, if events are avoid by using noEvent()-operator"
    annotation (Dialog(tab = "Advanced", group = "Numerics"),
                Evaluate=true,
                HideResult = true);

  //
  // Definition of models
  //
  replaceable
    Components.HeatExchangers.EvaporatorCondenser.BaseClasses.PartialEvaporatorCondenser
    evaporator(
    final no_components=no_components_liquid_evap,
      final no_cells_liquid=no_evap_cells_liquid,
      final no_cells_wall=no_evap_cells_wall,
      final heatExchangerGeometry=evaporatorGeometry,
    final use_casing=use_casing_evap,
      final balancingWallElement=balancingWallElement_evap,
      redeclare final model HeatTransfer_VLESide = HeatTransfer_evap_VLESide,
      redeclare final model HeatTransferModel_TubeSide =
          HeatTransferModel_evap_TubeSide,
      redeclare final model HeatTransferModel_NS = HeatTransferModel_evap_NS,
      redeclare final model HeatTransferModel_WE = HeatTransferModel_evap_WE,
    redeclare final model HeatTransfer_Casing = HeatTransfer_Casing_evap,
      redeclare final model PressureDropModel = PressureDropModel_evap,
    final no_components_phaseSeperator=no_components_VLE,
      final pInitial_liquidCell_1=pInitial_evap_liquidCell_1,
      final pInitial_liquidCell_N=pInitial_evap_liquidCell_N,
      final TInitial_liquidCell_1=TInitial_evap_liquidCell_1,
      final TInitial_liquidCell_N=TInitial_evap_liquidCell_N,
      final TInitial_wallCell_1=TInitial_evap_wallCell_1,
      final TInitial_wallCell_N=TInitial_evap_wallCell_N,
      final m_flowInitial=m_flowInitial_evap_Liquid,
      final avoid_events=avoid_events,
    final TInitial_casing=TInitial_evap_casing,
        nPorts_Liquid=1)
    "Model of the evaporator"
    annotation (Placement(transformation(extent={{-24,-80},{24,-60}})));

  replaceable
    Components.HeatExchangers.EvaporatorCondenser.BaseClasses.PartialEvaporatorCondenser
    condenser(
    final no_components=no_components_liquid_cond,
      final no_cells_liquid=no_cond_cells_liquid,
      final no_cells_wall=no_cond_cells_wall,
      final heatExchangerGeometry=condenserGeometry,
    final use_casing=use_casing_cond,
      final balancingWallElement=balancingWallElement_cond,
      redeclare final model HeatTransfer_VLESide = HeatTransfer_cond_VLESide,
      redeclare final model HeatTransferModel_TubeSide =
          HeatTransferModel_cond_TubeSide,
      redeclare final model HeatTransferModel_NS = HeatTransferModel_cond_NS,
      redeclare final model HeatTransferModel_WE = HeatTransferModel_cond_WE,
    redeclare final model HeatTransfer_Casing = HeatTransfer_Casing_cond,
      redeclare final model PressureDropModel = PressureDropModel_cond,
    final no_components_phaseSeperator=no_components_VLE,
      final pInitial_liquidCell_1=pInitial_cond_liquidCell_1,
      final pInitial_liquidCell_N=pInitial_cond_liquidCell_N,
      final TInitial_liquidCell_1=TInitial_cond_liquidCell_1,
      final TInitial_liquidCell_N=TInitial_cond_liquidCell_N,
      final TInitial_wallCell_1=TInitial_cond_wallCell_1,
      final TInitial_wallCell_N=TInitial_cond_wallCell_N,
      final m_flowInitial=m_flowInitial_cond_Liquid,
      final avoid_events=avoid_events,
    final TInitial_casing=TInitial_cond_casing,
      nPorts_Liquid=1)
    "Model of the condenser"
    annotation (Placement(transformation(extent={{-24,80},{24,60}})));

  replaceable Components.Valves.BaseClasses.PartialValve_constantFillingLevel
    returnValve(
    final no_components=no_components_VLE,
      kp=0.1,
      setPoint_fillingLevel=0.15,
      restrictFlow_BA=false,
      final fillingLevel=condenser.phaseSeperator.l_liq_rel)
    "Model of the return valve"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},rotation=270,
                origin={0,-2})));

  replaceable Components.ClosedAdsorbers.BaseClasses.PartialAdsorber
    adsorberBedOne(
      final no_cells_liquid=no_ads_cells_liquid,
      final no_cells_wall=no_ads_cells_wall,
      final no_cells_sorbent=no_ads_cells_sorbent,
      final adsorberGeometry=adsorberGeometry,
    final use_casing=use_casing_ads,
      redeclare final model HeatTransfer_WPair_to_TubeWall =
          HeatTransfer_ads_WPair_to_TubeWall,
      final balancingWallElement=balancingWallElement_ads,
      redeclare final model HeatTransferModel_NS = HeatTransferModel_ads_NS,
      redeclare final model HeatTransferModel_WE = HeatTransferModel_ads_WE,
      redeclare final model HeatTransferModel_TubeSide =
          HeatTransferModel_ads_TubeSide,
    redeclare final model HeatTransfer_Casing = HeatTransfer_Casing_ads,
      redeclare final model PressureDropModel = PressureDropModel_ads,
      final no_components_VLE=no_components_VLE,
    final no_components_liquid=no_components_liquid_ads,
      redeclare final model WorkingPair = WorkingPair,
      final m_sorbent=m_sorbent,
      final pInitial_liquidCell_1=pInitial_ads_liquidCell_1,
      final pInitial_liquidCell_N=pInitial_ads_liquidCell_N,
      final TInitial_liquidCell_1=TInitial_ads_liquidCell_1,
      final TInitial_liquidCell_N=TInitial_ads_liquidCell_N,
      final TInitial_wallCell_1=TInitial_ads_wallCell_1,
      final TInitial_wallCell_N=TInitial_ads_wallCell_N,
      final TInitial_WPair=TInitial_ads_WPair,
    final TInitial_casing=TInitial_ads_casing,
      final m_flowInitial_Liquid=m_flowInitial_ads_Liquid,
      final avoid_events=avoid_events)
    "Model of the first adsorber bed"
    annotation (Placement(transformation(extent={{-40,-20},{-80,20}})));

  //
  // Definition of connectors
  //
  replaceable Components.Connectors.BaseClasses.PartialMediaConnector
    evaporator_in(final no_components=no_components_liquid_evap)
                                                 "Design inlet of evaporator"
    annotation (Placement(transformation(extent={{-110,-80},{-90,-60}})));
  replaceable Components.Connectors.BaseClasses.PartialMediaConnector
    evaporator_out(final no_components=no_components_liquid_evap)
                                                "Design outlet of evaporator"
    annotation (Placement(transformation(extent={{90,-80},{110,-60}})));

  replaceable Components.Connectors.BaseClasses.PartialMediaConnector
    condenser_in(final no_components=no_components_liquid_cond)
      "Design inlet of condenser"
    annotation (Placement(transformation(extent={{-110,60},{-90,80}})));
  replaceable Components.Connectors.BaseClasses.PartialMediaConnector
    condenser_out(final no_components=no_components_liquid_cond)
      "Design outlet of condenser"
    annotation (Placement(transformation(extent={{90,60},{110,80}})));

  replaceable Components.Connectors.BaseClasses.PartialMediaConnector
    adsorberBedOne_in(final no_components=no_components_liquid_ads)
      "Design inlet of first adsorber bed"
    annotation (Placement(transformation(extent={{-110,-22},{-90,-2}})));
  replaceable Components.Connectors.BaseClasses.PartialMediaConnector
    adsorberBedOne_out(final no_components=no_components_liquid_ads)
      "Design outlet of first adsorber bed"
    annotation (Placement(transformation(extent={{-110,4},{-90,24}})));

  Modelica.Blocks.Interfaces.RealInput statusValveCondenser_adsorberBedOne if
    is_activelyCloseable
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,
                           origin={-50,-110}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={-50,-110},
        rotation=90)),               HideResult=not is_activelyCloseable);
  Modelica.Blocks.Interfaces.RealInput statusValveEvaporator_adsorberBedOne if
    is_activelyCloseable
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,
                           origin={-30,-110}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={-30,-110},
        rotation=90)),               HideResult=not is_activelyCloseable);
  Modelica.Blocks.Interfaces.RealInput statusValveMassRecovery_adsorberBedOne if
    allow_massRecovery
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,
                           origin={-10,-110}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={-10,-110},
        rotation=90)),               HideResult=not allow_massRecovery);

equation
  //
  // Connections of fluid ports
  //
  connect(evaporator_in, evaporator.port_a) annotation (Line(
      points={{-100,-70},{-24,-70}},
      color={28,108,200},
      thickness=1));
  connect(evaporator.port_b, evaporator_out) annotation (Line(
      points={{23.52,-70},{100,-70}},
      color={28,108,200},
      thickness=1));
  connect(condenser_in, condenser.port_a) annotation (Line(
      points={{-100,70},{-24,70}},
      color={28,108,200},
      thickness=1));
  connect(condenser.port_b, condenser_out) annotation (Line(
      points={{23.52,70},{100,70}},
      color={28,108,200},
      thickness=1));
  connect(condenser.liquidPort[1], returnValve.port_b) annotation (Line(
      points={{0,80},{0,8}},
      color={0,140,72},
      thickness=1));
  connect(returnValve.port_a, evaporator.liquidPort[1]) annotation (Line(
      points={{0,-12},{0,-80}},
      color={0,140,72},
      thickness=1));
  connect(adsorberBedOne_in, adsorberBedOne.liquid_a) annotation (Line(
      points={{-100,-12},{-92,-12},{-92,-8},{-80,-8}},
      color={28,108,200},
      thickness=1));
  connect(adsorberBedOne.liquid_b, adsorberBedOne_out) annotation (Line(
      points={{-80,8.4},{-90,8.4},{-90,14},{-100,14}},
      color={28,108,200},
      thickness=1));

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
        Line(
          points={{-100,8},{-18,20},{-78,0},{-18,-20},{-100,-10}},
          color={0,0,0},
          thickness=1),
        Ellipse(
          extent={{-62,-14},{-68,-8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-42,4},{-48,10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-38,-24},{-44,-18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-20,22},{-26,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-54,16},{-60,22}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-64,14},{-70,20}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-88,-10},{-94,-4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-78,-10},{-84,-4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-62,-24},{-68,-18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-88,-18},{-94,-12}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-74,-20},{-80,-14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-32,8},{-38,14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-36,18},{-42,24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-54,-6},{-60,0}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-70,4},{-76,10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-44,18},{-50,24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-74,12},{-80,18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-88,2},{-94,8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-24,-26},{-30,-20}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-88,10},{-94,16}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-34,-12},{-40,-6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-44,-8},{-50,-2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-78,4},{-84,10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-50,-24},{-56,-18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{-80,-76},{80,-92}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Polygon(
          points={{-80,-86},{-80,-66},{-52,-76},{-34,-74},{-4,-68},{16,-76},{44,
              -70},{76,-70},{82,-82},{-80,-86}},
          lineColor={28,108,200},
          lineThickness=0.5,
          smooth=Smooth.Bezier,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Polygon(
          points={{-26,-74},{-26,-74},{-38,-60},{-14,-60},{-26,-74}},
          lineColor={0,0,0},
          lineThickness=0.5),
        Ellipse(
          extent={{-64,-50},{-76,-62}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{22,-60},{10,-72}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-2,-52},{-14,-64}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{12,-50},{0,-62}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{40,-54},{28,-66}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-40,-52},{-52,-64}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-54,-60},{-66,-72}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{58,-56},{46,-68}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{72,-54},{60,-66}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Polygon(
          points={{-80,84},{-80,64},{-52,74},{-34,72},{-4,66},{16,74},{44,68},{78,
              68},{82,82},{-80,84}},
          lineColor={28,108,200},
          lineThickness=0.5,
          smooth=Smooth.Bezier,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{-80,92},{80,76}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{-80,92},{80,48}},
          lineColor={0,0,0},
          lineThickness=1),
        Rectangle(
          extent={{-80,-48},{80,-92}},
          lineColor={0,0,0},
          lineThickness=1),
        Polygon(
          points={{-44,76},{-44,76},{-56,62},{-32,62},{-44,76}},
          lineColor={0,0,0},
          lineThickness=0.5),
        Ellipse(
          extent={{-62,64},{-74,52}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-20,62},{-32,50}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{4,66},{-8,54}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{24,64},{12,52}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{46,66},{34,54}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{72,66},{60,54}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{-100,100},{100,-100}},
          lineColor={0,0,0},
          lineThickness=1),
        Line(
          points={{-54,-46},{-54,-34}},
          color={28,108,200},
          arrow={Arrow.None,Arrow.Filled}),
        Line(
          points={{-54,32},{-54,46}},
          color={28,108,200},
          arrow={Arrow.None,Arrow.Filled}),
        Line(
          points={{0,-20},{0,-40}},
          color={28,108,200},
          arrow={Arrow.None,Arrow.Filled}),
        Line(
          points={{0,40},{0,20}},
          color={28,108,200},
          arrow={Arrow.None,Arrow.Filled}),
        Rectangle(
          extent={{-96,30},{-14,-32}},
          lineColor={0,0,0},
          lineThickness=1),
        Ellipse(
          extent={{-82,16},{-88,22}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-74,20},{-80,26}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-88,22},{-94,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-64,22},{-70,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-50,22},{-56,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-28,20},{-34,26}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-82,-22},{-88,-16}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-88,-28},{-94,-22}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-80,-30},{-86,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-18,-16},{-24,-10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-56,-30},{-62,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-44,-30},{-50,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-32,-30},{-38,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-16,-30},{-22,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-82,-4},{-88,2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-70,-12},{-76,-6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-72,-28},{-78,-22}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-62,6},{-68,12}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-54,-14},{-60,-8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-60,-2},{-66,4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-50,0},{-56,6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-38,-4},{-44,2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-46,-16},{-52,-10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-54,8},{-60,14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-26,-14},{-32,-8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-28,-4},{-34,2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-26,4},{-32,10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-20,10},{-26,16}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-18,2},{-24,8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-18,-6},{-24,0}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Polygon(
          points={{0,0},{0,0},{-12,-14},{12,-14},{0,0}},
          lineColor={0,0,0},
          lineThickness=0.5),
        Polygon(
          points={{0,0},{0,0},{-12,14},{12,14},{0,0}},
          lineColor={0,0,0},
          lineThickness=0.5)}), Diagram(coordinateSystem(preserveAspectRatio=false)),
    Documentation(revisions="<html>
<ul>
  <li>
  January 25, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialOneBedSystem;
