within SorpLib.Applications.BasesClasses;
partial model PartialOneBedSystem_N1_ModelicaMediaLibrary "Base model for all one-bed adsorption systems based on single component
  adsorption and the Modelica.Media library"
  extends PartialOneBedSystem_N1(
    redeclare replaceable model WorkingPair =
      Media.WorkingPair.SingleComponent.Modelica_VLE.H2O_AQSOAZ02_Goldsworthy (
        type_isotherm=Internals.Types.Isotherm.Inverse),
    redeclare
      Components.HeatExchangers.EvaporatorCondenser.ModelicaMediaLibrary.EvaporatorCondenser
      condenser(
        redeclare final package VLE_Medium = Medium_VLE,
        redeclare final package Liquid_Medium = Medium_cond_Liquid,
        redeclare final model Solid = Solid_cond,
      redeclare final model SolidCasing = SolidCasing_cond,
        final TInitial_VLE=TInitial_cond_VLE,
        final rhoInitial_VLE=rhoInitial_cond_VLE,
      nPorts_Vapor=1),
    redeclare
      Components.HeatExchangers.EvaporatorCondenser.ModelicaMediaLibrary.EvaporatorCondenser
      evaporator(
        redeclare final package VLE_Medium = Medium_VLE,
        redeclare final package Liquid_Medium = Medium_evap_Liquid,
        redeclare final model Solid = Solid_evap,
      redeclare final model SolidCasing = SolidCasing_evap,
        final TInitial_VLE=TInitial_evap_VLE,
        final rhoInitial_VLE=rhoInitial_evap_VLE,
      nPorts_Vapor=1),
    redeclare Components.ClosedAdsorbers.ModelicaMediaLibrary.ClosedAdsorber
      adsorberBedOne(
        final is_activelyCloseable=is_activelyCloseable,
        final is_flapValve=is_flapValve,
        final allow_massRecovery=allow_massRecovery,
        redeclare final model MassTransfer_evaporator = MassTransfer_evaporator,
        redeclare final model MassTransfer_condenser = MassTransfer_condenser,
        redeclare final model MassTransfer_massRecovery =
          MassTransfer_massRecovery,
        final xInitial_Wpair=xInitial_Wpair_ads1,
        final m_flowInitial_VLE=m_flowInitial_VLE,
        final pStart_WPair=pStart_WPair,
        redeclare final package Medium_VLE = Medium_VLE,
        redeclare final package Medium_Liquid = Medium_ads_Liquid,
        redeclare final model Solid = Solid_ads,
      redeclare final model SolidCasing = SolidCasing_ads),
    redeclare
      Components.Valves.ModelicaMediaLibrary.VLEvalve_constantFillingLevel
      returnValve(redeclare final package Medium = Medium_VLE),
    redeclare Components.Connectors.ModelicaMediaLibrary.LiquidPort_a
      evaporator_in(redeclare final package Medium = Medium_evap_Liquid),
    redeclare Components.Connectors.ModelicaMediaLibrary.LiquidPort_a
      condenser_in(redeclare final package Medium = Medium_cond_Liquid),
    redeclare Components.Connectors.ModelicaMediaLibrary.LiquidPort_a
      adsorberBedOne_in(redeclare final package Medium = Medium_ads_Liquid),
    redeclare Components.Connectors.ModelicaMediaLibrary.LiquidPort_b
      adsorberBedOne_out(redeclare final package Medium = Medium_ads_Liquid),
    redeclare Components.Connectors.ModelicaMediaLibrary.LiquidPort_b
      evaporator_out(redeclare final package Medium = Medium_evap_Liquid),
    redeclare Components.Connectors.ModelicaMediaLibrary.LiquidPort_b
      condenser_out(redeclare final package Medium = Medium_cond_Liquid));

  //
  // Definition of parameters describing the medium
  //
  replaceable package Medium_VLE = Modelica.Media.Water.WaterIF97_ph
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "VLE media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable package Medium_evap_Liquid =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable package Medium_cond_Liquid =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable package Medium_ads_Liquid =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid_evap =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Copper
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of tubes"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid_cond =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Copper
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of tubes"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid_ads =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of tubes"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model SolidCasing_evap =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing_evap),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model SolidCasing_cond =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing_cond),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model SolidCasing_ads =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing_ads),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

equation
  //
  // Connection of fluid ports
  //
  connect(evaporator.vaporPort[1], adsorberBedOne.VLE_evaporator) annotation (
      Line(
      points={{0,-60},{-60,-60},{-60,-20}},
      color={0,140,72},
      thickness=1));
  connect(adsorberBedOne.VLE_condenser, condenser.vaporPort[1]) annotation (
      Line(
      points={{-60,20},{-60,60},{0,60}},
      color={0,140,72},
      thickness=1));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 25, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialOneBedSystem_N1_ModelicaMediaLibrary;
