within SorpLib.Applications.BasesClasses;
partial model PartialOneBedSystem_N1_TILMediaLibrary "Base model for all one-bed adsorption systems based on single component
   adsorption and the TILMedia library"
  extends PartialOneBedSystem_N1(
    redeclare replaceable model WorkingPair =
      Media.WorkingPair.SingleComponent.Modelica_VLE.H2O_AQSOAZ02_Goldsworthy (
        type_isotherm=Internals.Types.Isotherm.Inverse),
    redeclare
      Components.HeatExchangers.EvaporatorCondenser.TILMediaLibrary.EvaporatorCondenser
      condenser(
      final VLE_Medium=Medium_VLE,
      final Liquid_Medium=Medium_cond_Liquid,
      redeclare final model WallMaterial = Solid_cond,
      redeclare final model CasingMaterial = CasingMaterial_cond,
        final TInitial_VLE=TInitial_cond_VLE,
        final rhoInitial_VLE=rhoInitial_cond_VLE,
      nPorts_Vapor=1),
    redeclare
      Components.HeatExchangers.EvaporatorCondenser.TILMediaLibrary.EvaporatorCondenser
      evaporator(
      final VLE_Medium=Medium_VLE,
      final Liquid_Medium=Medium_evap_Liquid,
      redeclare final model WallMaterial = Solid_evap,
      redeclare final model CasingMaterial = CasingMaterial_evap,
        final TInitial_VLE=TInitial_evap_VLE,
        final rhoInitial_VLE=rhoInitial_evap_VLE,
      nPorts_Vapor=1),
    redeclare Components.ClosedAdsorbers.TILMediaLibrary.ClosedAdsorber
      adsorberBedOne(
        final is_activelyCloseable=is_activelyCloseable,
        final is_flapValve=is_flapValve,
        final allow_massRecovery=allow_massRecovery,
        redeclare final model MassTransfer_evaporator = MassTransfer_evaporator,
        redeclare final model MassTransfer_condenser = MassTransfer_condenser,
        redeclare final model MassTransfer_massRecovery =
          MassTransfer_massRecovery,
        final xInitial_Wpair=xInitial_Wpair_ads1,
        final m_flowInitial_VLE=m_flowInitial_VLE,
        final pStart_WPair=pStart_WPair,
      final Medium_VLE=Medium_VLE,
      final Medium_Liquid=Medium_ads_Liquid,
      redeclare final model Solid = Solid_ads,
      redeclare final model SolidCasing = CasingMaterial_ads),
    redeclare
      Components.Valves.TILMediaLibrary.VLEvalve_constantFillingLevel
      returnValve(final Medium=Medium_VLE),
    redeclare Components.Connectors.TILMediaLibrary.LiquidPort_a
      evaporator_in(final liquidType=Medium_evap_Liquid),
    redeclare Components.Connectors.TILMediaLibrary.LiquidPort_a
      condenser_in(final liquidType=Medium_cond_Liquid),
    redeclare Components.Connectors.TILMediaLibrary.LiquidPort_a
      adsorberBedOne_in(final liquidType=Medium_ads_Liquid),
    redeclare Components.Connectors.TILMediaLibrary.LiquidPort_b
      adsorberBedOne_out(final liquidType=Medium_ads_Liquid),
    redeclare Components.Connectors.TILMediaLibrary.LiquidPort_b
      evaporator_out(final liquidType=Medium_evap_Liquid),
    redeclare Components.Connectors.TILMediaLibrary.LiquidPort_b
      condenser_out(final liquidType=Medium_cond_Liquid));

  //
  // Definition of parameters describing the medium
  //
  replaceable parameter TILMedia.VLEFluidTypes.TILMedia_Water Medium_VLE
    constrainedby TILMedia.VLEFluidTypes.BaseVLEFluid
    "VLE media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable parameter TILMedia.LiquidTypes.TILMedia_Water Medium_evap_Liquid
    constrainedby TILMedia.LiquidTypes.BaseLiquid
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable parameter TILMedia.LiquidTypes.TILMedia_Water Medium_cond_Liquid
    constrainedby TILMedia.LiquidTypes.BaseLiquid
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable parameter TILMedia.LiquidTypes.TILMedia_Water Medium_ads_Liquid
    constrainedby TILMedia.LiquidTypes.BaseLiquid
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid_evap =
    TILMedia.SolidTypes.TILMedia_Copper
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid_cond =
    TILMedia.SolidTypes.TILMedia_Copper
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid_ads =
    TILMedia.SolidTypes.TILMedia_Aluminum
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model CasingMaterial_evap =
    TILMedia.SolidTypes.TILMedia_Aluminum
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing_evap),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model CasingMaterial_cond =
    TILMedia.SolidTypes.TILMedia_Aluminum
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing_cond),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model CasingMaterial_ads =
    TILMedia.SolidTypes.TILMedia_Aluminum
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing_ads),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

equation
  //
  // Connection of fluid ports
  //
  connect(evaporator.vaporPort[1], adsorberBedOne.VLE_evaporator) annotation (
      Line(
      points={{0,-60},{-60,-60},{-60,-20}},
      color={0,140,72},
      thickness=1));
  connect(adsorberBedOne.VLE_condenser, condenser.vaporPort[1]) annotation (
      Line(
      points={{-60,20},{-60,60},{0,60}},
      color={0,140,72},
      thickness=1));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 25, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialOneBedSystem_N1_TILMediaLibrary;
