within SorpLib.Applications.BasesClasses;
partial model PartialTwoBedSystem
  "Base model for all two-bed adsorption systems"
  extends PartialOneBedSystem;

  //
  // Definition of models
  //
  replaceable Components.ClosedAdsorbers.BaseClasses.PartialAdsorber
    adsorberBedTwo(
    final no_cells_liquid=no_ads_cells_liquid,
    final no_cells_wall=no_ads_cells_wall,
    final no_cells_sorbent=no_ads_cells_sorbent,
    final adsorberGeometry=adsorberGeometry,
    final use_casing=use_casing_ads,
    redeclare final model HeatTransfer_WPair_to_TubeWall =
        HeatTransfer_ads_WPair_to_TubeWall,
    final balancingWallElement=balancingWallElement_ads,
    redeclare final model HeatTransferModel_NS = HeatTransferModel_ads_NS,
    redeclare final model HeatTransferModel_WE = HeatTransferModel_ads_WE,
    redeclare final model HeatTransferModel_TubeSide =
        HeatTransferModel_ads_TubeSide,
    redeclare final model HeatTransfer_Casing = HeatTransfer_Casing_ads,
    redeclare final model PressureDropModel = PressureDropModel_ads,
    final no_components_VLE=no_components_VLE,
    final no_components_liquid=no_components_liquid_ads,
    redeclare final model WorkingPair = WorkingPair,
    final m_sorbent=m_sorbent,
    final pInitial_liquidCell_1=pInitial_ads_liquidCell_1,
    final pInitial_liquidCell_N=pInitial_ads_liquidCell_N,
    final TInitial_liquidCell_1=TInitial_ads_liquidCell_1,
    final TInitial_liquidCell_N=TInitial_ads_liquidCell_N,
    final TInitial_wallCell_1=TInitial_ads_wallCell_1,
    final TInitial_wallCell_N=TInitial_ads_wallCell_N,
    final TInitial_WPair=TInitial_ads_WPair,
    final TInitial_casing=TInitial_ads_casing,
    final m_flowInitial_Liquid=m_flowInitial_ads_Liquid,
    final avoid_events=avoid_events)
    "Model of the second adsorber bed"
    annotation (Placement(transformation(extent={{40,-20},{80,20}})));

  //
  // Definition of connectors
  //
public
  replaceable Components.Connectors.BaseClasses.PartialMediaConnector adsorberBedTwo_in(final
      no_components=no_components_liquid_ads)
                                          "Design inlet of second adsorber bed"
    annotation (Placement(transformation(extent={{90,-20},{110,0}})));
  replaceable Components.Connectors.BaseClasses.PartialMediaConnector adsorberBedTwo_out(final
      no_components=no_components_liquid_ads)
    "Design outlet of second adsorber bed"
    annotation (Placement(transformation(extent={{90,6},{110,26}})));

  Modelica.Blocks.Interfaces.RealInput statusValveCondenser_adsorberBedTwo if
    is_activelyCloseable
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                           origin={50,-110}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={50,-110},
        rotation=90)),               HideResult=not is_activelyCloseable);
  Modelica.Blocks.Interfaces.RealInput statusValveEvaporator_adsorberBedTwo if
    is_activelyCloseable
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                           origin={30,-110}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={30,-110},
        rotation=90)),               HideResult=not is_activelyCloseable);
  Modelica.Blocks.Interfaces.RealInput statusValveMassRecovery_adsorberBedTwo if
    allow_massRecovery
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
                rotation=90,
                           origin={10,-110}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={10,-110},
        rotation=90)),               HideResult=not allow_massRecovery);

equation
  //
  // Connection of fluid ports
  //
  connect(adsorberBedTwo_in, adsorberBedTwo.liquid_a) annotation (Line(
      points={{100,-10},{92,-10},{92,-8},{80,-8}},
      color={28,108,200},
      thickness=1));
  connect(adsorberBedTwo.liquid_b, adsorberBedTwo_out) annotation (Line(
      points={{80,8.4},{90,8.4},{90,16},{100,16}},
      color={28,108,200},
      thickness=1));

  //
  // Annotations
  //
  annotation (Icon(graphics={
        Polygon(
          visible = allow_massRecovery,
          points={{0,-7},{0,-7},{-12,7},{12,7},{0,-7}},
          lineColor={0,0,0},
          lineThickness=0.5,
          origin={-6,29},
          rotation=90),
        Polygon(
          visible = allow_massRecovery,
          points={{0,7},{0,7},{-12,-7},{12,-7},{0,7}},
          lineColor={0,0,0},
          lineThickness=0.5,
          origin={6,29},
          rotation=90),
        Line(
          points={{100,8},{18,20},{78,0},{18,-20},{100,-10}},
          color={0,0,0},
          thickness=1),
        Ellipse(
          extent={{68,6},{62,12}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{82,14},{76,20}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{94,10},{88,16}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{42,6},{36,12}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{42,-24},{36,-18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{86,-20},{80,-14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{64,16},{58,22}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{44,18},{38,24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{78,-20},{72,-14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{60,0},{54,6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{78,4},{72,10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{88,4},{82,10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{74,-10},{68,-4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{54,16},{48,22}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{32,20},{26,26}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{82,-12},{76,-6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{90,-10},{84,-4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{24,12},{18,18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{42,-12},{36,-6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{52,-8},{46,-2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{68,-2},{62,4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{64,-22},{58,-16}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{52,-24},{46,-18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{74,14},{68,20}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{96,-8},{90,-2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{30,-26},{24,-20}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{58,-14},{52,-8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Line(
          points={{54,-46},{54,-34}},
          color={28,108,200},
          arrow={Arrow.None,Arrow.Filled}),
        Line(
          points={{54,32},{54,46}},
          color={28,108,200},
          arrow={Arrow.None,Arrow.Filled}),
        Rectangle(
          extent={{14,30},{96,-32}},
          lineColor={0,0,0},
          lineThickness=1),
        Ellipse(
          extent={{92,18},{86,24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{82,22},{76,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{72,22},{66,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{58,22},{52,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{50,22},{44,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{38,22},{32,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{24,22},{18,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{94,0},{88,6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{86,-2},{80,4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{94,-18},{88,-12}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{92,-26},{86,-20}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{86,-30},{80,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{78,-30},{72,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{66,-12},{60,-6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{72,-22},{66,-16}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{70,-30},{64,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{60,-30},{54,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{48,-30},{42,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{38,-30},{32,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{24,-30},{18,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{52,2},{46,8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{58,-6},{52,0}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{44,-2},{38,4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{34,-14},{28,-8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{26,-16},{20,-10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{34,8},{28,14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{28,6},{22,12}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{36,0},{30,6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{36,-8},{30,-2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{26,-8},{20,-2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{24,0},{18,6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{58,8},{52,14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid)}), Documentation(revisions="<html>
<ul>
  <li>
  January 26, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialTwoBedSystem;
