﻿within SorpLib.Applications.BasesClasses;
partial model PartialTwoBedSystem_N1 "Base model for all two-bed adsorption systems based on single-component 
   adsorption"
  extends PartialTwoBedSystem(
    redeclare replaceable Components.ClosedAdsorbers.BaseClasses.PartialAdsorber_N1
      adsorberBedOne,
    redeclare replaceable Components.ClosedAdsorbers.BaseClasses.PartialAdsorber_N1
      adsorberBedTwo);

  //
  // Definition of parameters describing transport phenomena
  //
  replaceable model MassTransfer_evaporator =
    SorpLib.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
    constrainedby
    Components.MassTransfers.TransportPhenomena.BaseClasses.PartiallInternalMassTransfer_dx
    "Mass transfer model for adsorption phase"
    annotation (Dialog(tab="Transport Phenomena",group="Mass Transfers"),
                choices(choice(redeclare model MassTransfer_evaporator =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantCoefficient
                         "Mass Transfer | Constant mass transfer coefficient for loading-driven mass transfer"),
                       choice(redeclare model MassTransfer_evaporator =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantSpecificCoefficient
                         "Mass Transfer | Constant specific mass transfer coefficient for loading-driven mass transfe"),
                       choice(redeclare model MassTransfer_evaporator =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
                         "Mass Transfer | Glückauf-approach for loading-driven mass transfer"),
                       choice(redeclare model MassTransfer_evaporator =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.GlueckaufArrhenius
                         "Mass Transfer | Glückauf-approach with temperature-dependent diffusion coefficient for loading-driven mass transfer")),
                 Evaluate=true,
                 HideResult=true);
  replaceable model MassTransfer_condenser =
    SorpLib.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
    constrainedby
    Components.MassTransfers.TransportPhenomena.BaseClasses.PartiallInternalMassTransfer_dx
    "Mass transfer model for desorption phase"
    annotation (Dialog(tab="Transport Phenomena",group="Mass Transfers"),
                choices(choice(redeclare model MassTransfer_condenser =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantCoefficient
                         "Mass Transfer | Constant mass transfer coefficient for loading-driven mass transfer"),
                       choice(redeclare model MassTransfer_condenser =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantSpecificCoefficient
                         "Mass Transfer | Constant specific mass transfer coefficient for loading-driven mass transfe"),
                       choice(redeclare model MassTransfer_condenser =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
                         "Mass Transfer | Glückauf-approach for loading-driven mass transfer"),
                       choice(redeclare model MassTransfer_condenser =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.GlueckaufArrhenius
                         "Mass Transfer | Glückauf-approach with temperature-dependent diffusion coefficient for loading-driven mass transfer")),
                 Evaluate=true,
                 HideResult=true);
  replaceable model MassTransfer_massRecovery =
    SorpLib.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
    constrainedby
    Components.MassTransfers.TransportPhenomena.BaseClasses.PartiallInternalMassTransfer_dx
    "Mass transfer model for mass recovery phase"
    annotation (Dialog(tab="Transport Phenomena",group="Mass Transfers",
                enable=allow_massRecovery),
                choices(choice(redeclare model TransportPhenomena =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantCoefficient
                         "Mass Transfer | Constant mass transfer coefficient for loading-driven mass transfer"),
                       choice(redeclare model TransportPhenomena =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantSpecificCoefficient
                         "Mass Transfer | Constant specific mass transfer coefficient for loading-driven mass transfe"),
                       choice(redeclare model TransportPhenomena =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
                         "Mass Transfer | Glückauf-approach for loading-driven mass transfer"),
                       choice(redeclare model TransportPhenomena =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.GlueckaufArrhenius
                         "Mass Transfer | Glückauf-approach with temperature-dependent diffusion coefficient for loading-driven mass transfer")),
                 Evaluate=true,
                 HideResult=true);

  //
  // Definition of parameters describing the initialisation
  //
  parameter Modelica.SIunits.Temperature TInitial_evap_VLE = 283.15
    "Initial value for temperature of fluid in phase seperator"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator"),
                HideResult = true);
  parameter Modelica.SIunits.Density rhoInitial_evap_VLE= 200
    "Initial value for density of fluid in phase seperator"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Evaporator"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_cond_VLE = 303.15
    "Initial value for temperature of fluid in phase seperator"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser"),
                HideResult = true);
  parameter Modelica.SIunits.Density rhoInitial_cond_VLE= 350
    "Initial value for density of fluid in phase seperator"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Condenser"),
                HideResult = true);

  parameter Real xInitial_Wpair_ads1(unit="kg/kg") = 0.1
    "Initial value for equilibrium loading of adsorbate"
    annotation (Dialog(group = "Initial Values - Adsorber", tab = "Initialisation"),
                HideResult=true);
  parameter Real xInitial_Wpair_ads2(unit="kg/kg") = 0.2
    "Initial value for equilibrium loading of adsorbate"
    annotation (Dialog(group = "Initial Values - Adsorber", tab = "Initialisation"),
                HideResult=true);

  parameter Modelica.SIunits.MassFlowRate m_flowInitial_VLE = 1e-4
    "Start value for mass flow rate of adsorbate"
    annotation (Dialog(tab="Initialisation", group="Start Values - Adsorber"),
                HideResult = true);
  parameter Modelica.SIunits.Pressure pStart_WPair = 100
    "Start value for equilibrium pressure of adsorbate"
    annotation (Dialog(group = "Start Values - Adsorber", tab = "Initialisation"),
                HideResult=true);

  //
  // Definition of models
  //
protected
  replaceable Components.Cells.BaseClasses.PartialLiquidVLECell
    volumeMassRecovery(
    cellGeometry(volume(displayUnit="l") = 0.0001),
    final no_components=no_components_VLE,
    pInitial(displayUnit="kPa"),
    final avoid_events=avoid_events) if allow_massRecovery
    "Dummy volume to break algebraic loop when allowing mass recovery schemes"
    annotation (Placement(transformation(extent={{-30,-50},{-10,-30}})));

equation
  //
  // Connection of fluid ports
  //
  if allow_massRecovery then
    connect(adsorberBedOne.VLE_massRecovery, volumeMassRecovery.port_a);
    connect(adsorberBedTwo.VLE_massRecovery, volumeMassRecovery.port_b);
  end if;

  //
  // Connections of signals
  //
  if is_activelyCloseable then
    connect(adsorberBedOne.statusValveEvaporator,statusValveEvaporator_adsorberBedOne);
    connect(adsorberBedOne.statusValveCondenser,statusValveCondenser_adsorberBedOne);

    connect(adsorberBedTwo.statusValveEvaporator,statusValveEvaporator_adsorberBedTwo);
    connect(adsorberBedTwo.statusValveCondenser,statusValveCondenser_adsorberBedTwo);
  end if;

  if allow_massRecovery then
    connect(adsorberBedOne.statusValveMassRecovery,statusValveMassRecovery_adsorberBedOne);
    connect(adsorberBedTwo.statusValveMassRecovery,statusValveMassRecovery_adsorberBedTwo);
  end if;

  //
  // Annotations
  //
  annotation (Diagram(graphics={                              Line(
          points={{-26,-40},{-50,-40},{-50,-22}},
          color={0,140,72},
          thickness=1), Line(
          points={{50,-22},{50,-40},{-14,-40}},
          color={0,140,72},
          thickness=1)}), Documentation(revisions="<html>
<ul>
  <li>
  January 26, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialTwoBedSystem_N1;
