within SorpLib.Components.Boundaries.BaseClasses;
partial model PartialBoundaryTester
  "Base model for all test models to test boundaries"
  extends Modelica.Icons.Example;

  //
  // Definition of boundaries
  //
  replaceable SorpLib.Components.Boundaries.BaseClasses.PartialBoundary boundaryA_pConst_hConst(
    final no_components=1,
    final boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    final boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    final use_pInput=false,
    final use_xiInput=false,
    final use_hInput=false)
    "Left boundary A: Constant pressure and constant sprecific enthalpy"
    annotation (Placement(transformation(extent={{-40,60},{-20,80}})));

  replaceable SorpLib.Components.Boundaries.BaseClasses.PartialBoundary boundaryA_mConst_hConst(
    final no_components=1,
    final boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    final boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    final use_mFlowInput=false,
    final use_xiInput=false,
    final use_hInput=false)
    "Right boundary A: Constant mass flow and constant sprecific enthalpy"
    annotation (Placement(transformation(extent={{40,60},{20,80}})));

  replaceable SorpLib.Components.Boundaries.BaseClasses.PartialBoundary boundaryB_pVar_hConst(
    final no_components=1,
    final boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    final boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    final use_pInput=true,
    final use_xiInput=false,
    final use_hInput=false)
    "Left boundary B: Variable pressure and constant sprecific enthalpy"
    annotation (Placement(transformation(extent={{-40,30},{-20,50}})));

  replaceable SorpLib.Components.Boundaries.BaseClasses.PartialBoundary boundaryB_mVar_hVar(
    final no_components=1,
    final boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    final boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    final use_mFlowInput=true,
    final use_xiInput=false,
    final use_hInput=true)
    "Left boundary B: Variable mass flow and variable sprecific enthalpy"
    annotation (Placement(transformation(extent={{40,30},{20,50}})));

  //
  // Definition of input signals
  //
  Modelica.Blocks.Sources.Ramp input_pVar(
    height=1e5 - 1000,
    duration=2500,
    offset=1000,
    startTime=0) "Ramp to simulate input signal of pressure"
    annotation (Placement(transformation(extent={{-80,-10},{-60,10}})),
                HideResult=true);
  Modelica.Blocks.Sources.Ramp input_mVar(
    height=2,
    duration=2500,
    offset=-1,
    startTime=0) "Ramp to simulate input signal of mass flow"
    annotation (Placement(transformation(extent={{80,60},{60,80}})),
                HideResult=true);
  Modelica.Blocks.Sources.Ramp input_hVar(
    height=3e5,
    duration=2500,
    offset=1e5,
    startTime=0) "Ramp to simulate input signal of specific enthalpy"
    annotation (Placement(transformation(extent={{80,-40},{60,-20}})),
                HideResult=true);

equation
  //
  // Connection of boundaries
  //
  connect(boundaryA_pConst_hConst.port, boundaryA_mConst_hConst.port)
    annotation (Line(points={{-30,70},{30,70}}, color={0,0,0}));
  connect(boundaryB_pVar_hConst.port, boundaryB_mVar_hVar.port)
    annotation (Line(points={{-30,40},{30,40}}, color={0,0,0}));

  //
  // Connections of input signals
  //
  connect(input_pVar.y, boundaryB_pVar_hConst.p_input) annotation (Line(points={{-59,0},
          {-50,0},{-50,47},{-31.2,47}},           color={0,0,127}));
  connect(input_mVar.y, boundaryB_mVar_hVar.m_flow_input) annotation (Line(
        points={{59,70},{44,70},{44,44},{31.2,44}}, color={0,0,127}));
  connect(input_hVar.y, boundaryB_mVar_hVar.h_input) annotation (Line(points={{59,
          -30},{56,-30},{56,36},{31.2,36}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=2500), Documentation(revisions="<html>
<ul>
  <li>
  January 11, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialBoundaryTester;
