within SorpLib.Components.Boundaries.BaseClasses;
partial model PartialMediaBoundaryTester
  "Base model for all test models to test boundaries"
  extends PartialBoundaryTester(boundaryA_mConst_hConst);

  //
  // Definition of boundaries
  //
  replaceable SorpLib.Components.Boundaries.BaseClasses.PartialBoundary boundaryC_pConst_TConst(
    final no_components=1,
    final boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    final boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    final use_pInput=false,
    final use_xiInput=false)
    "Left boundary C: Constant pressure and constant temperature"
    annotation (Placement(transformation(extent={{-40,-40},{-20,-20}})));

  replaceable SorpLib.Components.Boundaries.BaseClasses.PartialBoundary boundaryC_VConst_TConst(
    final no_components=1,
    final boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.VolumeFlow,
    final boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    final use_xiInput=false)
    "Right boundary C: Constant volume flow and constant temperature"
    annotation (Placement(transformation(extent={{40,-40},{20,-20}})));

  replaceable SorpLib.Components.Boundaries.BaseClasses.PartialBoundary boundaryD_pVar_TConst(
    final no_components=1,
    final boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    final boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    final use_pInput=true,
    final use_xiInput=false)
    "Left boundary D: Variable pressure and constant temperature"
    annotation (Placement(transformation(extent={{-40,-50},{-20,-70}})));

  replaceable SorpLib.Components.Boundaries.BaseClasses.PartialBoundary boundaryD_VVar_TVar(
    final no_components=1,
    final boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.VolumeFlow,
    final boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    final use_xiInput=false)
    "Left boundary D: Variable volume flow and variable temperature"
    annotation (Placement(transformation(extent={{40,-70},{20,-50}})));

  //
  // Definition of input signals
  //
  Modelica.Blocks.Sources.Ramp input_VVar(
    height=20/1000/60/60,
    duration=2500,
    offset=-10/1000/60/60,
    startTime=0) "Ramp to simulate input signal of volume flow" annotation (
      Placement(transformation(extent={{80,20},{60,40}})), HideResult=true);
  Modelica.Blocks.Sources.Ramp input_TVar(
    height=80,
    duration=2500,
    offset=293.15,
    startTime=0) "Ramp to simulate input signal of temperature" annotation (
      Placement(transformation(extent={{80,-80},{60,-60}})), HideResult=true);

equation
  //
  // Connection of boundaries
  //
  connect(boundaryC_pConst_TConst.port,boundaryC_VConst_TConst. port)
    annotation (Line(points={{-30,-30},{30,-30}}, color={0,0,0}));
  connect(boundaryD_pVar_TConst.port,boundaryD_VVar_TVar. port)
    annotation (Line(points={{-30,-60},{30,-60}}, color={0,0,0}));

  //
  // Connections of input signals
  //
  connect(input_pVar.y,boundaryD_pVar_TConst. p_input) annotation (Line(points={
          {-59,0},{-50,0},{-50,-67},{-31.2,-67}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=2500), Documentation(revisions="<html>
<ul>
  <li>
  January 11, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialMediaBoundaryTester;
