within SorpLib.Components.Boundaries.TILMediaLibrary;
model GasBoundary
  "Boundary model for a gas medium of the TILMedia library"
  extends BaseClasses.PartialMediaLibraryBoundary(
    redeclare final Connectors.TILMediaLibrary.GasPort_a port(
      final no_components=no_components,
      final gasType=Medium),
    xi = Medium.xi_default);

  //
  // Definition of parameters defining the boundary type
  //
  replaceable parameter Media.TILMediaDefinition.Gas.TILMedia_H2O Medium
    constrainedby TILMedia.GasTypes.BaseGas
    "Medium model"
    annotation (Dialog(tab="General", group="Boundary Type"),
                evaluate=true,
                HideResult=true,
                choicesAllMatching=true);

  //
  // Definition of medium model
  //
  TILMedia.Gas_pT medium_out_pT(
    final gasType=Medium,
    final p=port.p,
    final T=T_,
    final xi=xi_) if
    boundaryType_S == Internals.Types.BoundaryStream.Temperature or
    (boundaryType_PF == Internals.Types.BoundaryPotentialFlow.VolumeFlow and
    boundaryType_S == Internals.Types.BoundaryStream.Temperature)
    "Thermodynamic state describing outflowing properties calculated with p, T, 
     and xi at outlet of boundary"
    annotation (Placement(transformation(extent={{-40,2},{-20,22}})));

  TILMedia.Gas_ph medium_out_ph(
    final gasType=Medium,
    final p=port.p,
    final h=h_,
    final xi=xi_) if
    (boundaryType_PF == Internals.Types.BoundaryPotentialFlow.VolumeFlow and
    boundaryType_S == Internals.Types.BoundaryStream.SpecificEnthalpy)
    "Thermodynamic state describing outflowing properties calculated with p, h, 
     and xi at outlet of boundary"
    annotation (Placement(transformation(extent={{-40,-22},{-20,-2}})));

  TILMedia.Gas_ph medium_in_ph(
    final gasType=Medium,
    final p=port.p,
    final h=inStream(port.h_outflow),
    final xi=port.xi_outflow) if
    boundaryType_PF == Internals.Types.BoundaryPotentialFlow.VolumeFlow
    "Thermodynamic state describing inflowing properties calculated with p, h, 
     and xi at inlet of boundary"
    annotation (Placement(transformation(extent={{20,-12},{40,8}})));

  //
  // Definition of connectors
  //
protected
  Modelica.Blocks.Interfaces.RealInput h_pT(final unit="J/kg")=
    medium_out_pT.h if
    boundaryType_S == Internals.Types.BoundaryStream.Temperature
    "Fixed calculated specific enthalpy input";

  Modelica.Blocks.Interfaces.RealInput d_out_pT(final unit="kg/m3")=
   medium_out_pT.d if
   (boundaryType_PF == Internals.Types.BoundaryPotentialFlow.VolumeFlow and
    boundaryType_S == Internals.Types.BoundaryStream.Temperature)
    "Fixed density";
  Modelica.Blocks.Interfaces.RealInput d_out_ph(final unit="kg/m3")=
   medium_out_ph.d if
   (boundaryType_PF == Internals.Types.BoundaryPotentialFlow.VolumeFlow and
    boundaryType_S == Internals.Types.BoundaryStream.SpecificEnthalpy)
    "Fixed density";

  Modelica.Blocks.Interfaces.RealInput d_in_ph(final unit="kg/m3")=
   medium_in_ph.d if
   boundaryType_PF == Internals.Types.BoundaryPotentialFlow.VolumeFlow
    "Fixed density";

equation
  //
  // Connectors
  //
  connect(h_pT,h_calc);

  connect(d_out_pT,d_out);
  connect(d_out_ph,d_out);

  connect(d_in_ph,d_in);

  //
  // Annotations
  //
  annotation (Icon(graphics={Rectangle(
          extent={{-2,80},{2,-80}},
          lineColor={244,125,35},
          lineThickness=0.5,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid)}), Documentation(revisions="<html>
<ul>
  <li>
  January 11, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end GasBoundary;
