within SorpLib.Components.Boundaries.Thermal.Tester;
model TestHeatSource "Tester for heat source model"
  extends Modelica.Icons.Example;

  //
  // Definition of boundary models
  //
  HeatSource TFixed(boundaryType=SorpLib.Internals.Types.BoundaryThermal.Temperature,
      use_TInput=false) "Heat source with fixed temperature"
    annotation (Placement(transformation(extent={{-50,20},{-30,40}})));
  HeatSource TVar(boundaryType=SorpLib.Internals.Types.BoundaryThermal.Temperature,
      use_TInput=true) "Heat source with variable temperature"
    annotation (Placement(transformation(extent={{-50,-40},{-30,-20}})));
  HeatSource QFixed(boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
      use_QFlowInput=false) "Heat source with fixed heat flow rate"
    annotation (Placement(transformation(extent={{50,20},{30,40}})));
  HeatSource QVar(boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
      use_QFlowInput=true) "Heat source with variable heat flow"
    annotation (Placement(transformation(extent={{50,-40},{30,-20}})));

  Modelica.Blocks.Sources.Ramp input_TVar(
    height=80,
    duration=2500,
    offset=293.15,
    startTime=0)
    "Ramp to simulate input signal of temperrature"
    annotation (Placement(transformation(extent={{-80,-40},{-60,-20}})),
                HideResult=true);
  Modelica.Blocks.Sources.Ramp input_QVar(
    height=2000,
    duration=2500,
    offset=-1000,
    startTime=0)
    "Ramp to simulate input signal of heat flow" annotation (
      Placement(transformation(extent={{80,-40},{60,-20}})), HideResult=true);
equation
  //
  // Connections
  //
  connect(TFixed.port, QFixed.port) annotation (Line(
      points={{-40,30},{40,30}},
      color={238,46,47},
      thickness=1));
  connect(TVar.port, QVar.port) annotation (Line(
      points={{-40,-30},{40,-30}},
      color={238,46,47},
      thickness=1));

  connect(input_TVar.y, TVar.T_input) annotation (Line(points={{-59,-30},{-50,-30},
          {-50,-24.8},{-41,-24.8}}, color={0,0,127}));
  connect(input_QVar.y, QVar.Q_flow_input) annotation (Line(points={{59,-30},{50,
          -30},{50,-36},{41,-36},{41,-35}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=2500), Documentation(revisions="<html>
<ul>
  <li>
  January 11, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestHeatSource;
