within SorpLib.Components.Cells.BaseClasses;
partial model PartialLiquidVLECell
  "Base model for all liquid and VLE cell models"
  extends PartialFluidCell;

equation
  //
  // Mass balance
  //
  if type_overallMassBalance ==
    Internals.Types.BalanceEquations.SteadyState_FreeInitial then
    dmass_dtau = 0
      "No change of fluid mass wrt. time";
    port_a.m_flow + port_b.m_flow = 0
      "Steady-state overall mass balance";

  else
    port_a.m_flow + port_b.m_flow = dmass_dtau
      "Transient overall mass balance";

  end if;

  if type_independentMassBalances ==
    Internals.Types.BalanceEquations.SteadyState_FreeInitial then
    if avoid_events then
      zeros(no_components-1) =
        port_a.m_flow*noEvent(actualStream(port_a.xi_outflow)) +
        port_b.m_flow*noEvent(actualStream(port_b.xi_outflow))
        "Steady-state mass balances of independent components";

    else
      zeros(no_components-1) =
        port_a.m_flow*actualStream(port_a.xi_outflow) +
        port_b.m_flow*actualStream(port_b.xi_outflow)
        "Steady-state mass balances of independent components";

    end if;

  else
    if avoid_events then
      der(xi) = 1/mass*(
        port_a.m_flow*(noEvent(actualStream(port_a.xi_outflow))-xi) +
        port_b.m_flow*(noEvent(actualStream(port_b.xi_outflow))-xi))
        "Steady-state mass balances of independent components";

    else
      der(xi) = 1/mass*(
        port_a.m_flow*(actualStream(port_a.xi_outflow)-xi) +
        port_b.m_flow*(actualStream(port_b.xi_outflow)-xi))
        "Steady-state mass balances of independent components";

    end if;

  end if;

  //
  // Energy balance
  //
  if type_energyBalance ==
    Internals.Types.BalanceEquations.SteadyState_FreeInitial then
    dU_dtau = 0
      "No change of internal energy wrt. time";

    if avoid_events then
      0 = heatPort.Q_flow +
        port_a.m_flow*noEvent(actualStream(port_a.h_outflow)) +
        port_b.m_flow*noEvent(actualStream(port_b.h_outflow))
        "Steady-state energy balance";

    else
      0 = heatPort.Q_flow +
        port_a.m_flow*actualStream(port_a.h_outflow) +
        port_b.m_flow*actualStream(port_b.h_outflow)
        "Steady-state energy balance";

    end if;

  else
    if avoid_events then
      dU_dtau = heatPort.Q_flow +
        port_a.m_flow*noEvent(actualStream(port_a.h_outflow)) +
        port_b.m_flow*noEvent(actualStream(port_b.h_outflow))
        "Transient energy balance";

    else
      dU_dtau = heatPort.Q_flow +
        port_a.m_flow*actualStream(port_a.h_outflow) +
        port_b.m_flow*actualStream(port_b.h_outflow)
        "Transient energy balance";

    end if;

  end if;

  //
  // Annotations
  //
  annotation (Diagram(coordinateSystem(preserveAspectRatio=false)),
    Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
  <li>
  May 26, 2021, by Mirko Engelpracht:<br/>
  Introduced new partial model.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialLiquidVLECell;
