within SorpLib.Components.Cells.Geometry;
record FluidCell "Record containing all relevant information of a fluid cell"
  extends Internals.ClassTypes.Record;

  parameter Modelica.SIunits.Diameter hydraulicDiameter = 0.01
    "Hydraulic diameter of cell";
  parameter Modelica.SIunits.Length length = 1
    "Length of cell";

  parameter Modelica.SIunits.Area hydraulicCrossSectionalArea=
    (Modelica.Constants.pi/4 * hydraulicDiameter^2)
    "Cross sectional area of cell";
  parameter Modelica.SIunits.Area heatTransferArea=
    Modelica.Constants.pi * hydraulicDiameter * length
    "Heat transfer area of cell";

  parameter Modelica.SIunits.Volume volume=
    hydraulicCrossSectionalArea * length
    "Volume of cell (e.g., used for calculation of mass)";

  parameter Real nParallelHydraulicFlows(min=1) = 1
    "Number of parallel flows";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end FluidCell;
