within SorpLib.Components.Cells.Geometry;
record WallCell
  "Record containing all relevant information of a wall cell"
  extends Internals.ClassTypes.Record;

  parameter Modelica.SIunits.Length length_WE = 1
    "Length of wall cell (e.g., used for calculation of W-E heat transfer 
    (e.g., in flow direction of a 1D tube))";
  parameter Modelica.SIunits.Length length_NS = 1
    "Length of wall cell (e.g., used for calculation of N-S heat transfer 
    (e.g., perpendicular to flow direction of a 1D tube)";

  parameter Modelica.SIunits.Area crossSectionalArea=
    Modelica.Constants.pi/4 * (0.012^2 - 0.01^2)
    "Cross-sectional area of wall (e.g., used for calculation of W-E heat transfer)";

  parameter Modelica.SIunits.Volume volume = crossSectionalArea*length_WE
    "Volume of wall cell (e.g., used for calculation of mass)";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end WallCell;
