within SorpLib.Components.Cells.ModelicaMediaLibrary.Tester;
model TestCondensingGasCell "Model to test condensing gas cell"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  CondensingGasCell gasCell_phxi(
    state_phxi=false,
    TInitial=383.15,
    xiInitial={0.02},
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.Transient_FixedInitial,
    type_independentMassBalances=SorpLib.Internals.Types.BalanceEquations.Transient_FixedInitial,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.Transient_FixedInitial,
    redeclare package MediumGas = Modelica.Media.Air.MoistAir,
    redeclare package MediumVLE = Modelica.Media.Water.StandardWater)
    "Gas cell with p, h, and xi as state variables: Transient MB and transient EB"
    annotation (Placement(transformation(extent={{40,70},{60,90}})));

  CondensingGasCell gasCell_phxi_MB(
    state_phxi=false,
    TInitial=300.1298,
    xiInitial={0.02},
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    type_independentMassBalances=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.Transient_FixedInitial,
    redeclare package MediumGas = Modelica.Media.Air.MoistAir,
    redeclare package MediumVLE = Modelica.Media.Water.StandardWater)
    "Gas cell with p, h, and xi as state variables: Transient MB and transient EB"
    annotation (Placement(transformation(extent={{56,40},{76,60}})));

  CondensingGasCell gasCell_phxi_MBEB(
    state_phxi=false,
    TInitial=383.15,
    xiInitial={0.02},
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    type_independentMassBalances=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    redeclare package MediumGas = Modelica.Media.Air.MoistAir,
    redeclare package MediumVLE = Modelica.Media.Water.StandardWater)
    "Gas cell with p, h, and xi as state variables: Steady-state MB and steady-state  EB"
    annotation (Placement(transformation(extent={{26,10},{46,30}})));

  //
  // Definition of boundaries
  //
protected
  Modelica.Blocks.Sources.Sine input_massFlow_phxi_1(
    amplitude=0.00001, freqHz=5)
    "Input for mass flow of adsorptiv"
    annotation (Placement(transformation(
        extent={{4,4},{-4,-4}},
        rotation=180,
        origin={30,72})), HideResult=true);

  Boundaries.ModelicaMediaLibrary.GasBoundary
                                         inlet_phxi_1(
    no_components=2,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.00101,
    xi={0.01},
    T=323.15,
    redeclare package Medium = Modelica.Media.Air.MoistAir)
    "Inlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(extent={{10,70},{30,90}})), HideResult=true);

  Boundaries.ModelicaMediaLibrary.GasBoundary
                                         outlet_phxi_1(
    no_components=2,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15,
    redeclare package Medium = Modelica.Media.Air.MoistAir)
    "Outlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(extent={{70,70},{90,90}})), HideResult=true);

  Boundaries.ModelicaMediaLibrary.VLEBoundary
                                         boundary_adsorptiv_phxi_1(
    no_components=1,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    use_mFlowInput=true,
    T=413.15,
    redeclare package Medium = Modelica.Media.Water.StandardWater)
    "Inlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={56,66})), HideResult=true);

  Boundaries.Thermal.HeatSource heatSource_phxi_1(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25) "Heat source for gas cell"
    annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={50,94})), HideResult=true);

  Modelica.Blocks.Sources.Sine input_massFlow_phxi_2(
    amplitude=0.00001,                                                  freqHz=
        5,
    offset=-0.00002)
    "Input for mass flow of adsorptiv"
    annotation (Placement(transformation(
        extent={{4,4},{-4,-4}},
        rotation=180,
        origin={46,42})), HideResult=true);
  Boundaries.ModelicaMediaLibrary.GasBoundary
                                         inlet_phxi_2(
    no_components=2,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.00101,
    xi={0.01},
    T=323.15,
    redeclare package Medium = Modelica.Media.Air.MoistAir)
    "Inlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(extent={{26,40},{46,60}})), HideResult=true);
  Boundaries.ModelicaMediaLibrary.GasBoundary
                                         outlet_phxi_2(
    no_components=2,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15,
    redeclare package Medium = Modelica.Media.Air.MoistAir)
    "Outlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(extent={{86,40},{106,60}})),HideResult=true);
  Boundaries.ModelicaMediaLibrary.VLEBoundary
                                         boundary_adsorptiv_phxi_2(
    no_components=1,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    use_mFlowInput=true,
    T=413.15,
    redeclare package Medium = Modelica.Media.Water.StandardWater)
    "Inlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={66,36})), HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_phxi_2(boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
      Q_flow=-25) "Heat source for gas cell"
    annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={66,64})), HideResult=true);
  Modelica.Blocks.Sources.Sine input_massFlow_phxi_3(
    amplitude=0.00001,                                                  freqHz=5,
    offset=-0.00002)
    "Input for mass flow of adsorptiv"
    annotation (Placement(transformation(
        extent={{4,4},{-4,-4}},
        rotation=180,
        origin={16,12})), HideResult=true);
  Boundaries.ModelicaMediaLibrary.GasBoundary
                                         inlet_phxi_3(
    no_components=2,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.00101,
    xi={0.01},
    T=323.15,
    redeclare package Medium = Modelica.Media.Air.MoistAir)
    "Inlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(extent={{-4,10},{16,30}})), HideResult=true);
  Boundaries.ModelicaMediaLibrary.GasBoundary
                                         outlet_phxi_3(
    no_components=2,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15,
    redeclare package Medium = Modelica.Media.Air.MoistAir)
    "Outlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(extent={{56,10},{76,30}})), HideResult=true);
  Boundaries.ModelicaMediaLibrary.VLEBoundary
                                         boundary_adsorptiv_phxi_3(
    no_components=1,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    use_mFlowInput=true,
    T=413.15,
    redeclare package Medium = Modelica.Media.Water.StandardWater)
    "Inlet for gas cell using p, h, and xi as states" annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={36,6})),  HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_phxi_3(boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
      Q_flow=-25) "Heat source for gas cell"
    annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={36,34})), HideResult=true);

equation
  //
  // Connections
  //
  connect(heatSource_phxi_1.port, gasCell_phxi.heatPort) annotation (Line(
      points={{50,94},{50,86}},
      color={238,46,47},
      thickness=1));
  connect(inlet_phxi_1.port, gasCell_phxi.port_a) annotation (Line(
      points={{20,80},{43,80}},
      color={244,125,35},
      thickness=1));
  connect(gasCell_phxi.port_b, outlet_phxi_1.port) annotation (Line(
      points={{55.2,80},{80,80}},
      color={244,125,35},
      thickness=1));
  connect(input_massFlow_phxi_1.y, boundary_adsorptiv_phxi_1.m_flow_input)
    annotation (Line(points={{34.4,72},{40,72},{40,62},{52,62},{52,64.8}},
        color={0,0,127}));
  connect(boundary_adsorptiv_phxi_1.port, gasCell_phxi.port_adsorptiv)
    annotation (Line(
      points={{56,66},{56,74},{50,74}},
      color={0,140,72},
      thickness=1));
  connect(heatSource_phxi_2.port, gasCell_phxi_MB.heatPort) annotation (Line(
      points={{66,64},{66,56}},
      color={238,46,47},
      thickness=1));
  connect(inlet_phxi_2.port, gasCell_phxi_MB.port_a) annotation (Line(
      points={{36,50},{59,50}},
      color={244,125,35},
      thickness=1));
  connect(gasCell_phxi_MB.port_b, outlet_phxi_2.port) annotation (Line(
      points={{71.2,50},{96,50}},
      color={244,125,35},
      thickness=1));
  connect(input_massFlow_phxi_2.y,boundary_adsorptiv_phxi_2. m_flow_input)
    annotation (Line(points={{50.4,42},{56,42},{56,32},{62,32},{62,34.8}},
        color={0,0,127}));
  connect(boundary_adsorptiv_phxi_2.port, gasCell_phxi_MB.port_adsorptiv)
    annotation (Line(
      points={{66,36},{66,44}},
      color={0,140,72},
      thickness=1));
  connect(heatSource_phxi_3.port, gasCell_phxi_MBEB.heatPort) annotation (Line(
      points={{36,34},{36,26}},
      color={238,46,47},
      thickness=1));
  connect(inlet_phxi_3.port, gasCell_phxi_MBEB.port_a) annotation (Line(
      points={{6,20},{29,20}},
      color={244,125,35},
      thickness=1));
  connect(gasCell_phxi_MBEB.port_b, outlet_phxi_3.port) annotation (Line(
      points={{41.2,20},{66,20}},
      color={244,125,35},
      thickness=1));
  connect(input_massFlow_phxi_3.y,boundary_adsorptiv_phxi_3. m_flow_input)
    annotation (Line(points={{20.4,12},{26,12},{26,2},{32,2},{32,4.8}},
        color={0,0,127}));
  connect(boundary_adsorptiv_phxi_3.port, gasCell_phxi_MBEB.port_adsorptiv)
    annotation (Line(
      points={{36,6},{36,14}},
      color={0,140,72},
      thickness=1));

  //
  // Annotations
  //
  annotation (Diagram(graphics={
        Rectangle(
          extent={{0,120},{100,100}},
          lineColor={28,108,200},
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{100,100},{0,120}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="States: p, h, and xi"),
        Rectangle(
          extent={{-100,90},{0,70}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,70},{-100,90}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Fixed initial values
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-100,60},{0,40}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,40},{-100,60}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Steady-state
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-100,30},{0,10}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,10},{-100,30}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Steady-state
Energy balance: Steady-state"),
        Text(
          extent={{100,60},{140,40}},
          lineColor={0,0,0},
          textString="Not sound because
density can change
as pressure is fixed
but temperature not!"),
        Text(
          extent={{100,30},{140,10}},
          lineColor={0,0,0},
          textString="Not sound because
density can change
as pressure is fixed
but temperature not!")}),         experiment(StopTime=10),
    Documentation(revisions="<html>
<ul>
  <li>
  May 26, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestCondensingGasCell;
