within SorpLib.Components.Cells.ModelicaMediaLibrary.Tester;
model TestLiquidCell "Model to test liquid cell"
  extends Modelica.Icons.Example;

  //
  // Definition of parameters
  //
//   replaceable package Medium_pT =
//     Modelica.Media.Water.ConstantPropertyLiquidWater
//     "Medium model for liquid cells based in states p, T, and xi";

  replaceable package Medium_pT =
    Modelica.Media.Water.WaterIF97_R1pT
    "Medium model for liquid cells based in states p, T, and xi";

//  replaceable package Medium_ph =
//    Modelica.Media.Water.ConstantPropertyLiquidWater
//    "Medium model for liquid cells based in states p, h, and xi";

 replaceable package Medium_ph =
   Modelica.Media.Water.WaterIF97_R1ph
   "Medium model for liquid cells based in states p, h, and xi";

  //
  // Definition of models
  //
  LiquidCell liquidCell_pT
    "Liquid cell with p, T, and xi as state variables: Transient MB and transient EB"
    annotation (Placement(transformation(extent={{-60,100},{-40,120}})));

  LiquidCell liquidCell_pT_MB(
    redeclare package Medium = Medium_pT,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "Liquid cell with p, T, and xi as state variables: Steady-state MB and transient EB"
    annotation (Placement(transformation(extent={{-60,70},{-40,90}})));

  LiquidCell liquidCell_pT_MBEB(
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    redeclare package Medium = Medium_pT,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "Liquid cell with p, T, and xi as state variables: Steady-state MB and steady-state EB"
    annotation (Placement(transformation(extent={{-60,40},{-40,60}})));

  LiquidCell liquidCell_pT_MB_IC(
    redeclare package Medium = Medium_pT,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    use_incompressibleEquations=true)
    "Liquid cell with p, T, and xi as state variables: Steady-state MB and transient EB; explicitly incompressible"
    annotation (Placement(transformation(extent={{-60,10},{-40,30}})));

  LiquidCell liquidCell_pT_nVp(
    neglectTermVp=true)
    "Liquid cell with p, T, and xi as state variables: Transient MB and transient EB; neglect term pv"
    annotation (Placement(transformation(extent={{-60,-30},{-40,-10}})));

  LiquidCell liquidCell_pT_nVp_MB(
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    neglectTermVp=true,
    redeclare package Medium = Medium_pT)
    "Liquid cell with p, T, and xi as state variables: Steady-state MB and transient EB; neglect term pv"
    annotation (Placement(transformation(extent={{-60,-60},{-40,-40}})));

  LiquidCell liquidCell_pT_nVp_MBEB(
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    neglectTermVp=true,
    redeclare package Medium = Medium_pT)
    "Liquid cell with p, T, and xi as state variables: Steady-state MB and steady-state EB; neglect term pv"
    annotation (Placement(transformation(extent={{-60,-90},{-40,-70}})));

  LiquidCell liquidCell_pT_nVp_MB_IC(
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    neglectTermVp=true,
    redeclare package Medium = Medium_pT,
    use_incompressibleEquations=true)
    "Liquid cell with p, T, and xi as state variables: Steady-state MB and transient EB; neglect term pv; explicitly incompressible"
    annotation (Placement(transformation(extent={{-60,-120},{-40,-100}})));

  LiquidCell liquidCell_ph_MB(
    state_phxi=true,
    redeclare package Medium = Medium_ph,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "Liquid cell with p, h, and xi as state variables: Steady-state MB and transient EB"
    annotation (Placement(transformation(extent={{40,70},{60,90}})));

  LiquidCell liquidCell_ph_MBEB(
    state_phxi=true,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    redeclare package Medium = Medium_ph,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "Liquid cell with p, h, and xi as state variables: Steady-state MB and steady-state EB"
    annotation (Placement(transformation(extent={{40,40},{60,60}})));

  LiquidCell liquidCell_ph_nVp_MB(
    state_phxi=true,
    neglectTermVp=true,
    redeclare package Medium = Medium_ph,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "Liquid cell with p, h, and xi as state variables: Steady-state MB and transient EB; neglect term pv"
    annotation (Placement(transformation(extent={{40,-60},{60,-40}})));

  LiquidCell liquidCell_ph_nVp_MBEB(
    state_phxi=true,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    neglectTermVp=true,
    redeclare package Medium = Medium_ph,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "Liquid cell with p, h, and xi as state variables: Steady-state MB and steady-state EB; neglect term pv"
    annotation (Placement(transformation(extent={{40,-90},{60,-70}})));

  //
  // Definition of boundaries
  //
protected
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_pT_1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15)
    "Inlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-90,100},{-70,120}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_pT_1(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-50,124})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_pT_1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=0.001,
    T=323.15)
    "Outlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-30,100},{-10,120}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_pT_2(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15)
    "Inlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-90,70},{-70,90}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_pT_2(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-50,94})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_pT_2(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15)
    "Outlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-30,70},{-10,90}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_pT_3(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15)
    "Inlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-90,40},{-70,60}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_pT_3(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-50,64})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_pT_3(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15)
    "Outlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-30,40},{-10,60}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_pT_4(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15)
    "Inlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-90,10},{-70,30}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_pT_4(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-50,34})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_pT_4(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15)
    "Outlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-30,10},{-10,30}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_pT_5(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15)
    "Inlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-90,-30},{-70,-10}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_pT_5(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-50,-6})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_pT_5(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=0.001,
    T=323.15)
    "Outlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-30,-30},{-10,-10}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_pT_6(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15)
    "Inlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-90,-60},{-70,-40}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_pT_6(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-50,-36})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_pT_6(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15)
    "Outlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-30,-60},{-10,-40}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_pT_7(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15)
    "Inlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-90,-90},{-70,-70}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_pT_7(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-50,-66})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_pT_7(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15)
    "Outlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-30,-90},{-10,-70}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_pT_8(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15)
    "Inlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-90,-120},{-70,-100}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_pT_8(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-50,-96})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_pT_8(
    redeclare package Medium = Medium_pT,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15)
    "Outlet for liquid cell using p, T, and xi as states"
    annotation (Placement(transformation(extent={{-30,-120},{-10,-100}})),
                HideResult=true);

  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_ph_2(
    redeclare package Medium = Medium_ph,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for liquid cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,70},{30,90}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_2(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,94})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_ph_2(
    redeclare package Medium = Medium_ph,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for liquid cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,70},{90,90}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_ph_3(
    redeclare package Medium = Medium_ph,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for liquid cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,40},{30,60}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_3(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,64})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_ph_3(
    redeclare package Medium = Medium_ph,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for liquid cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,40},{90,60}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_ph_5(
    redeclare package Medium = Medium_ph,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for liquid cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,-60},{30,-40}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_5(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,-36})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_ph_5(
    redeclare package Medium = Medium_ph,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for liquid cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,-60},{90,-40}})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inlet_ph_6(
    redeclare package Medium = Medium_ph,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for liquid cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,-90},{30,-70}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_6(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for liquid cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,-66})),
                HideResult=true);
  Boundaries.ModelicaMediaLibrary.LiquidBoundary outlet_ph_6(
    redeclare package Medium = Medium_ph,
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for liquid cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,-90},{90,-70}})),
                HideResult=true);

equation
  //
  // Connections
  //
  connect(inlet_pT_1.port, liquidCell_pT.port_a) annotation (Line(
      points={{-80,110},{-57,110}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_pT.port_b, outlet_pT_1.port) annotation (Line(
      points={{-44.8,110},{-20,110}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_pT_1.port, liquidCell_pT.heatPort) annotation (Line(
      points={{-50,124},{-50,116}},
      color={238,46,47},
      thickness=1));
  connect(inlet_pT_2.port, liquidCell_pT_MB.port_a) annotation (Line(
      points={{-80,80},{-57,80}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_pT_MB.port_b, outlet_pT_2.port) annotation (Line(
      points={{-44.8,80},{-20,80}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_pT_2.port, liquidCell_pT_MB.heatPort) annotation (Line(
      points={{-50,94},{-50,86}},
      color={238,46,47},
      thickness=1));
  connect(inlet_pT_3.port, liquidCell_pT_MBEB.port_a) annotation (Line(
      points={{-80,50},{-57,50}},
      color={28,108,200},
      thickness=1));
  connect(outlet_pT_3.port, liquidCell_pT_MBEB.port_b) annotation (Line(
      points={{-20,50},{-44.8,50}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_pT_3.port, liquidCell_pT_MBEB.heatPort) annotation (Line(
      points={{-50,64},{-50,56}},
      color={238,46,47},
      thickness=1));
  connect(inlet_pT_4.port, liquidCell_pT_MB_IC.port_a) annotation (Line(
      points={{-80,20},{-57,20}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_pT_MB_IC.port_b, outlet_pT_4.port) annotation (Line(
      points={{-44.8,20},{-20,20}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_pT_4.port, liquidCell_pT_MB_IC.heatPort) annotation (Line(
      points={{-50,34},{-50,26}},
      color={238,46,47},
      thickness=1));
  connect(inlet_pT_5.port, liquidCell_pT_nVp.port_a) annotation (Line(
      points={{-80,-20},{-57,-20}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_pT_nVp.port_b, outlet_pT_5.port) annotation (Line(
      points={{-44.8,-20},{-20,-20}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_pT_5.port, liquidCell_pT_nVp.heatPort) annotation (Line(
      points={{-50,-6},{-50,-14}},
      color={238,46,47},
      thickness=1));
  connect(inlet_pT_6.port, liquidCell_pT_nVp_MB.port_a) annotation (Line(
      points={{-80,-50},{-57,-50}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_pT_nVp_MB.port_b, outlet_pT_6.port) annotation (Line(
      points={{-44.8,-50},{-20,-50}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_pT_6.port, liquidCell_pT_nVp_MB.heatPort) annotation (Line(
      points={{-50,-36},{-50,-44}},
      color={238,46,47},
      thickness=1));
  connect(inlet_pT_7.port, liquidCell_pT_nVp_MBEB.port_a) annotation (Line(
      points={{-80,-80},{-57,-80}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_pT_nVp_MBEB.port_b, outlet_pT_7.port) annotation (Line(
      points={{-44.8,-80},{-20,-80}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_pT_7.port, liquidCell_pT_nVp_MBEB.heatPort) annotation (
      Line(
      points={{-50,-66},{-50,-74}},
      color={238,46,47},
      thickness=1));
  connect(inlet_pT_8.port, liquidCell_pT_nVp_MB_IC.port_a) annotation (Line(
      points={{-80,-110},{-57,-110}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_pT_nVp_MB_IC.port_b, outlet_pT_8.port) annotation (Line(
      points={{-44.8,-110},{-20,-110}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_pT_8.port, liquidCell_pT_nVp_MB_IC.heatPort) annotation (
      Line(
      points={{-50,-96},{-50,-104}},
      color={238,46,47},
      thickness=1));
  connect(inlet_ph_2.port, liquidCell_ph_MB.port_a) annotation (Line(
      points={{20,80},{43,80}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_ph_MB.port_b, outlet_ph_2.port) annotation (Line(
      points={{55.2,80},{80,80}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_ph_2.port, liquidCell_ph_MB.heatPort) annotation (Line(
      points={{50,94},{50,86}},
      color={238,46,47},
      thickness=1));
  connect(inlet_ph_3.port, liquidCell_ph_MBEB.port_a) annotation (Line(
      points={{20,50},{43,50}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_ph_MBEB.port_b, outlet_ph_3.port) annotation (Line(
      points={{55.2,50},{80,50}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_ph_3.port, liquidCell_ph_MBEB.heatPort) annotation (Line(
      points={{50,64},{50,56}},
      color={238,46,47},
      thickness=1));
  connect(inlet_ph_5.port, liquidCell_ph_nVp_MB.port_a) annotation (Line(
      points={{20,-50},{43,-50}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_ph_nVp_MB.port_b, outlet_ph_5.port) annotation (Line(
      points={{55.2,-50},{80,-50}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_ph_5.port, liquidCell_ph_nVp_MB.heatPort) annotation (Line(
      points={{50,-36},{50,-44}},
      color={238,46,47},
      thickness=1));
  connect(inlet_ph_6.port, liquidCell_ph_nVp_MBEB.port_a) annotation (Line(
      points={{20,-80},{43,-80}},
      color={28,108,200},
      thickness=1));
  connect(liquidCell_ph_nVp_MBEB.port_b, outlet_ph_6.port) annotation (Line(
      points={{55.2,-80},{80,-80}},
      color={28,108,200},
      thickness=1));
  connect(heatSource_ph_6.port, liquidCell_ph_nVp_MBEB.heatPort) annotation (
      Line(
      points={{50,-66},{50,-74}},
      color={238,46,47},
      thickness=1));

  //
  // Annotations
  //
  annotation (Diagram(graphics={
        Rectangle(
          extent={{-102,150},{-2,130}},
          lineColor={28,108,200},
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-2,130},{-102,150}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textString="States: p, T, and xi",
          textStyle={TextStyle.Bold}),
        Rectangle(
          extent={{2,150},{102,130}},
          lineColor={28,108,200},
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{102,130},{2,150}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="States: p, h, and xi"),
        Rectangle(
          extent={{-204,120},{-104,100}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-104,100},{-204,120}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Fixed initial values
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-204,90},{-104,70}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-104,70},{-204,90}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Steady-state
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-204,60},{-104,40}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-104,40},{-204,60}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Steady-state
Energy balance: Steady-state"),
        Rectangle(
          extent={{-204,32},{-104,12}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-104,12},{-204,32}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Steady-state
Energy balance: Steady-state
Balances explicitly written for incompressible fluid"),
        Rectangle(
          extent={{-204,-10},{-104,-30}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-104,-30},{-204,-10}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Assumption: u = h
Mass balance: Fixed initial values
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-204,-40},{-104,-60}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-104,-60},{-204,-40}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Assumption: u = h
Mass balance: Steady-state
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-204,-70},{-104,-90}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-104,-90},{-204,-70}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Assumption: u = h
Mass balance: Steady-state
Energy balance: Steady-state"),
        Rectangle(
          extent={{-204,-98},{-104,-118}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-104,-118},{-204,-98}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Assumption: u = h
Mass balance: Steady-state
Energy balance: Steady-state
Balances explicitly written for incompressible fluid"),
        Text(
          extent={{100,-40},{140,-60}},
          lineColor={0,0,0},
          textString="Not sound because
density can change
as pressure is fixed
but temperature not!"),
        Text(
          extent={{100,90},{140,70}},
          lineColor={0,0,0},
          textString="Not sound because
density can change
as pressure is fixed
but temperature not!")}),                                 experiment(StopTime=
          10),
    Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestLiquidCell;
