within SorpLib.Components.Cells;
package PropertyRecord
  "Package containing records with thermodynamic properties required for models of transport phenomena"
extends Internals.ClassTypes.RecordPackage;

  record FluidCellProperties
    "Record containing all relevant properties of a fluid cell for model of transport phenomena"
    extends Internals.ClassTypes.Record;

    //
    // Definition of variables
    //
    Modelica.SIunits.Temperature T(min=-1)
      "Temperature of fluid in cell";
    Modelica.SIunits.Density rho(min=-1)
      "Density of fluid in cell";

    Modelica.SIunits.ThermalConductivity lambda(min=-1)
      "Thermal conductivity of fluid in cell";
    Modelica.SIunits.DynamicViscosity eta(min=-1)
      "Dynamic viscosity of fluid in cell";
    Modelica.SIunits.PrandtlNumber Pr(min=-1)
      "Prandtl number of fluid in cell";

    Modelica.SIunits.MassFlowRate m_flow_portA
      "Mass flow rate at port A";
    Modelica.SIunits.MassFlowRate m_flow_portB
      "Mass flow rate at port B";

    //
    // Annotations
    //
    annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>",   info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
  end FluidCellProperties;

  record WallCellProperties
    "Record containing all relevant properties of a wall cell for model of transport phenomena"
    extends Internals.ClassTypes.Record;

    //
    // Definition of variables
    //
    Modelica.SIunits.Temperature T
      "Temperature of wall cell";
    Modelica.SIunits.Density rho
      "Density of wall cell";

    Modelica.SIunits.SpecificHeatCapacity c
      "Heat capacity of wall cell";

    Modelica.SIunits.ThermalConductivity lambda
      "Thermal conductivity of wall cell";

    //
    // Annotations
    //
    annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>",   info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
  end WallCellProperties;
annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PropertyRecord;
