within SorpLib.Components.Cells.TILMediaLibrary.Tester;
model TestSingleVLEWPairCell "Model to test working pair cell describing single-component adsorption and 
   using a VLE fluid"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  SingleVLEWPairCell WPairCell_FixedMB_FixedEB_woPorts(
    m_sorbent=2.5,
    redeclare model SingleWPair =
        SorpLib.Media.WorkingPair.SingleComponent.TIL_VLE.H2O_AQSOAZ02_Goldsworthy
        (type_isotherm=SorpLib.Internals.Types.Isotherm.Inverse,
          type_SpecEnthalpySorptive=SorpLib.Internals.Types.SpecificEnthalpySorptive.Media_VLE),
    xInitial=0.25) "Working pair model"
    annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));

  SingleVLEWPairCell WPairCell_FixedMB_FixedEB_wPorts(
    m_sorbent=2.5,
    TInitial=323.15,
    redeclare model SingleWPair =
        Media.WorkingPair.SingleComponent.TIL_VLE.H2O_AQSOAZ02_Goldsworthy (
         type_isotherm=SorpLib.Internals.Types.Isotherm.Inverse,
          type_SpecEnthalpySorptive=SorpLib.Internals.Types.SpecificEnthalpySorptive.Media_VLE),
    xInitial=0.25) "Working pair model"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}})));

  SingleVLEWPairCell WPairCell_FixedMB_FixedEB_wMultiplePorts(
    m_sorbent=2.5,
    TInitial=323.15,
    redeclare model SingleWPair =
        Media.WorkingPair.SingleComponent.TIL_VLE.H2O_AQSOAZ02_Goldsworthy (
         type_isotherm=SorpLib.Internals.Types.Isotherm.Inverse,
          type_SpecEnthalpySorptive=SorpLib.Internals.Types.SpecificEnthalpySorptive.Media_VLE),
    xInitial=0.25,
    nPorts_B=2) "Working pair model"
    annotation (Placement(transformation(extent={{40,-10},{60,10}})));

  //
  // Definition of boundaries
  //
  Boundaries.TILMediaLibrary.VLEBoundary      VLE_a_1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=750,
    m_flow=-0.0001,
    T=298.15)
    "VLE boundary at port a"
    annotation (Placement(transformation(extent={{-30,-10},{-10,10}})));
  Boundaries.TILMediaLibrary.VLEBoundary      VLE_a_2(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=750,
    m_flow=-0.0001,
    T=298.15)
    "VLE boundary at port a"
    annotation (Placement(transformation(extent={{20,-10},{40,10}})));
  Boundaries.TILMediaLibrary.VLEBoundary      VLE_b_21(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=750,
    m_flow=+0.00005,
    T=298.15)
    "VLE boundary at port b"
    annotation (Placement(transformation(extent={{70,0},{90,20}})));
  Boundaries.TILMediaLibrary.VLEBoundary      VLE_b_22(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=750,
    use_mFlowInput=true,
    m_flow=+0.00005,
    T=298.15)
    "VLE boundary at port b"
    annotation (Placement(transformation(extent={{90,-20},{70,0}})));
  Boundaries.Thermal.HeatSource heatSource_1(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    use_QFlowInput=true)
    "Heat source for working pair cell"
      annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,origin={-70,12})),
                  HideResult=true);
  Modelica.Blocks.Sources.Sine input_heatSource_1(
    amplitude=1500,
    freqHz=1/250)
    "Input for heat source"
    annotation (Placement(transformation(extent={{-4,-4},{4,4}},
                rotation=270,origin={-70,20})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_2(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    use_QFlowInput=true)
    "Heat source for working pair cell"
      annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,origin={0,12})),
                  HideResult=true);
  Modelica.Blocks.Sources.Sine input_heatSource_2(amplitude=1500, freqHz=1/250)
    "Input for heat source"
    annotation (Placement(transformation(extent={{-4,-4},{4,4}},
                rotation=270,origin={0,20})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_3(boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
      use_QFlowInput=true)
    "Heat source for working pair cell"
      annotation (Placement(transformation(extent={{10,-10},{-10,10}},
                  rotation=90,origin={50,12})),
                  HideResult=true);
  Modelica.Blocks.Sources.Sine input_heatSource_3(amplitude=1500, freqHz=1/250)
    "Input for heat source"
    annotation (Placement(transformation(extent={{-4,-4},{4,4}},
                rotation=270,origin={50,20})),
                HideResult=true);
  Modelica.Blocks.Sources.Sine input_massFlow(amplitude=0.0001, freqHz=1/250)
    "Input for mass flow" annotation (Placement(transformation(
        extent={{4,4},{-4,-4}},
        rotation=0,
        origin={92,-10})), HideResult=true);

equation
  //
  // Connections
  //
  connect(heatSource_1.port, WPairCell_FixedMB_FixedEB_woPorts.heatPort_b)
    annotation (Line(
      points={{-70,12},{-70,6}},
      color={238,46,47},
      thickness=1));
  connect(input_heatSource_1.y, heatSource_1.Q_flow_input) annotation (Line(
        points={{-70,15.6},{-68,15.6},{-68,13},{-65,13}}, color={0,0,127}));
  connect(heatSource_2.port, WPairCell_FixedMB_FixedEB_wPorts.heatPort_b)
    annotation (Line(
      points={{0,12},{0,6}},
      color={238,46,47},
      thickness=1));
  connect(input_heatSource_2.y,heatSource_2. Q_flow_input) annotation (Line(
        points={{0,15.6},{2,15.6},{2,13},{5,13}},         color={0,0,127}));
  connect(VLE_a_1.port, WPairCell_FixedMB_FixedEB_wPorts.port_a) annotation (
      Line(
      points={{-20,0},{-7,0}},
      color={0,140,72},
      thickness=1));
  connect(heatSource_3.port, WPairCell_FixedMB_FixedEB_wMultiplePorts.heatPort_b)
    annotation (Line(
      points={{50,12},{50,6}},
      color={238,46,47},
      thickness=1));
  connect(input_heatSource_3.y,heatSource_3. Q_flow_input) annotation (Line(
        points={{50,15.6},{52,15.6},{52,13},{55,13}},     color={0,0,127}));
  connect(VLE_a_2.port, WPairCell_FixedMB_FixedEB_wMultiplePorts.port_a)
    annotation (Line(
      points={{30,0},{43,0}},
      color={0,140,72},
      thickness=1));
  connect(VLE_b_21.port, WPairCell_FixedMB_FixedEB_wMultiplePorts.port_b[1])
    annotation (Line(
      points={{80,10},{70,10},{70,-0.5},{55.2,-0.5}},
      color={0,140,72},
      thickness=1));
  connect(WPairCell_FixedMB_FixedEB_wMultiplePorts.port_b[2], VLE_b_22.port)
    annotation (Line(
      points={{55.2,0.5},{70,0.5},{70,-10},{80,-10}},
      color={0,140,72},
      thickness=1));
  connect(VLE_b_22.m_flow_input, input_massFlow.y) annotation (Line(points={{81.2,
          -6},{84,-6},{84,-10},{87.6,-10}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=1000), Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation after restructuring of the library.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestSingleVLEWPairCell;
