within SorpLib.Components.Cells.TILMediaLibrary.Tester;
model TestVLECell "Model to test VLE cell"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  VLECell vLECell_ph(
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.Transient_FixedInitial)
    "VLE cell with p, h, and xi as state variables: Transient MB and transient EB"
    annotation (Placement(transformation(extent={{40,70},{60,90}})));

  VLECell vLECell_ph_MB(
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "VLE cell with p, h, and xi as state variables: Steady-state MB and transient EB"
    annotation (Placement(transformation(extent={{40,40},{60,60}})));

  VLECell vLECell_ph_MBEB(
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "VLE cell with p, h, and xi as state variables: Steady-state MB and steady-state EB"
    annotation (Placement(transformation(extent={{40,10},{60,30}})));

  VLECell vLECell_ph_nVp(
    neglectTermVp=true,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.Transient_FixedInitial)
    "VLE cell with p, h, and xi as state variables: Transient MB and transient EB; neglect term pv"
    annotation (Placement(transformation(extent={{40,-30},{60,-10}})));

  VLECell vLECell_ph_nVp_MB(
    neglectTermVp=true,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "VLE cell with p, h, and xi as state variables: Steady-state MB and transient EB; neglect term pv"
    annotation (Placement(transformation(extent={{40,-60},{60,-40}})));

  VLECell vLECell_ph_nVp_MBEB(
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    neglectTermVp=true,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial)
    "VLE cell with p, h, and xi as state variables: Steady-state MB and steady-state EB; neglect term pv"
    annotation (Placement(transformation(extent={{40,-90},{60,-70}})));

  //
  // Definition of boundaries
  //
protected
  Boundaries.TILMediaLibrary.VLEBoundary         inlet_ph_2(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,40},{30,60}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_2(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for VLE cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,64})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         outlet_ph_2(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,40},{90,60}})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         inlet_ph_3(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,10},{30,30}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_3(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for VLE cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,34})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         outlet_ph_3(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,10},{90,30}})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         inlet_ph_5(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,-60},{30,-40}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_5(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for VLE cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,-36})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         outlet_ph_5(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,-60},{90,-40}})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         inlet_ph_6(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,-90},{30,-70}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_6(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for VLE cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,-66})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         outlet_ph_6(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,-90},{90,-70}})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         inlet_ph_1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,70},{30,90}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_1(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for VLE cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,94})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         outlet_ph_1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,70},{90,90}})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         inlet_ph_4(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    T=323.15) "Inlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{10,-30},{30,-10}})),
                HideResult=true);
  Boundaries.Thermal.HeatSource heatSource_ph_4(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    Q_flow=-25)
    "Heat source for VLE cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={50,-6})),
                HideResult=true);
  Boundaries.TILMediaLibrary.VLEBoundary         outlet_ph_4(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    m_flow=0.001,
    T=323.15) "Outlet for VLE cell using p, h, and xi as states"
    annotation (Placement(transformation(extent={{70,-30},{90,-10}})),
                HideResult=true);

equation
  //
  // Connections
  //
  connect(heatSource_ph_2.port, vLECell_ph_MB.heatPort) annotation (Line(
      points={{50,64},{50,56}},
      color={238,46,47},
      thickness=1));
  connect(heatSource_ph_3.port, vLECell_ph_MBEB.heatPort) annotation (Line(
      points={{50,34},{50,26}},
      color={238,46,47},
      thickness=1));
  connect(heatSource_ph_5.port, vLECell_ph_nVp_MB.heatPort) annotation (Line(
      points={{50,-36},{50,-44}},
      color={238,46,47},
      thickness=1));
  connect(heatSource_ph_6.port, vLECell_ph_nVp_MBEB.heatPort) annotation (Line(
      points={{50,-66},{50,-74}},
      color={238,46,47},
      thickness=1));
  connect(inlet_ph_2.port, vLECell_ph_MB.port_a) annotation (Line(
      points={{20,50},{43,50}},
      color={0,140,72},
      thickness=1));
  connect(vLECell_ph_MB.port_b, outlet_ph_2.port) annotation (Line(
      points={{55.2,50},{80,50}},
      color={0,140,72},
      thickness=1));
  connect(inlet_ph_3.port, vLECell_ph_MBEB.port_a) annotation (Line(
      points={{20,20},{43,20}},
      color={0,140,72},
      thickness=1));
  connect(vLECell_ph_MBEB.port_b, outlet_ph_3.port) annotation (Line(
      points={{55.2,20},{80,20}},
      color={0,140,72},
      thickness=1));
  connect(inlet_ph_5.port, vLECell_ph_nVp_MB.port_a) annotation (Line(
      points={{20,-50},{43,-50}},
      color={0,140,72},
      thickness=1));
  connect(vLECell_ph_nVp_MB.port_b, outlet_ph_5.port) annotation (Line(
      points={{55.2,-50},{80,-50}},
      color={0,140,72},
      thickness=1));
  connect(inlet_ph_6.port, vLECell_ph_nVp_MBEB.port_a) annotation (Line(
      points={{20,-80},{43,-80}},
      color={0,140,72},
      thickness=1));
  connect(vLECell_ph_nVp_MBEB.port_b, outlet_ph_6.port) annotation (Line(
      points={{55.2,-80},{80,-80}},
      color={0,140,72},
      thickness=1));
  connect(heatSource_ph_1.port, vLECell_ph.heatPort) annotation (Line(
      points={{50,94},{50,86}},
      color={238,46,47},
      thickness=1));
  connect(inlet_ph_1.port, vLECell_ph.port_a) annotation (Line(
      points={{20,80},{43,80}},
      color={0,140,72},
      thickness=1));
  connect(vLECell_ph.port_b, outlet_ph_1.port) annotation (Line(
      points={{55.2,80},{80,80}},
      color={0,140,72},
      thickness=1));
  connect(heatSource_ph_4.port, vLECell_ph_nVp.heatPort) annotation (Line(
      points={{50,-6},{50,-14}},
      color={238,46,47},
      thickness=1));
  connect(inlet_ph_4.port, vLECell_ph_nVp.port_a) annotation (Line(
      points={{20,-20},{43,-20}},
      color={0,140,72},
      thickness=1));
  connect(vLECell_ph_nVp.port_b, outlet_ph_4.port) annotation (Line(
      points={{55.2,-20},{80,-20}},
      color={0,140,72},
      thickness=1));

  //
  // Annotations
  //
  annotation (Diagram(graphics={
        Rectangle(
          extent={{0,120},{100,100}},
          lineColor={28,108,200},
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{100,100},{0,120}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="States: p, h, and xi"),
        Rectangle(
          extent={{-100,90},{0,70}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,70},{-100,90}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Fixed initial values
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-100,60},{0,40}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,40},{-100,60}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Steady-state
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-100,30},{0,10}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,10},{-100,30}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Mass balance: Steady-state
Energy balance: Steady-state"),
        Rectangle(
          extent={{-100,-10},{0,-30}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,-30},{-100,-10}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Assumption: u = h
Mass balance: Fixed initial values
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-100,-40},{0,-60}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,-60},{-100,-40}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Assumption: u = h
Mass balance: Steady-state
Energy balance: Fixed initiel values"),
        Rectangle(
          extent={{-100,-70},{0,-90}},
          lineColor={244,125,35},
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{0,-90},{-100,-70}},
          lineColor={0,0,0},
          fillColor={28,108,200},
          fillPattern=FillPattern.None,
          textStyle={TextStyle.Bold},
          textString="Assumption: u = h
Mass balance: Steady-state
Energy balance: Steady-state"),
        Text(
          extent={{100,60},{140,40}},
          lineColor={0,0,0},
          textString="Not sound because
density can change
as pressure is fixed
but temperature not!"),
        Text(
          extent={{100,-40},{140,-60}},
          lineColor={0,0,0},
          textString="Not sound because
density can change
as pressure is fixed
but temperature not!")}),         experiment(StopTime=10),
    Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestVLECell;
