within SorpLib.Components.Cells.TILMediaLibrary.Tester;
model TestWallCell "Model to test wall cell"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  WallCell wallCell_fixedInitial(
    TInitial=323.15)
    "Model of wall cell: Transient energy balance with fixed initial values"
    annotation (Placement(transformation(extent={{-70,40},{-50,60}})));

  WallCell wallCell_steadyStateInitialisation(
    TInitial=323.15,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.Transient_SteadyStateInitial)
    "Model of wall cell: Transient energy balance with steady-state initialisation"
    annotation (Placement(transformation(extent={{-10,40},{10,60}})));

  WallCell wallCell_fixedInitial_boundaries(
    TInitial=323.15)
    "Model of wall cell: Transient energy balance with fixed initial values"
    annotation (Placement(transformation(extent={{-70,-60},{-50,-40}})));

  WallCell wallCell_steadyStateInitialisation_boundaries(
    TInitial=323.15,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.Transient_SteadyStateInitial)
    "Model of wall cell: Transient energy balance with steady-state initialisation"
    annotation (Placement(transformation(extent={{-10,-60},{10,-40}})));

  WallCell wallCell_steadyStateBalance_boundaries(
    TInitial=323.15,
    type_energyBalance=SorpLib.Internals.Types.BalanceEquations.Transient_SteadyStateInitial)
    "Model of wall cell: Steady-state energy balance"
    annotation (Placement(transformation(extent={{50,-60},{70,-40}})));

  //
  // Definition of boundaries
  //
protected
  Boundaries.Thermal.HeatSource heatSource_south_1(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.Temperature,
    T=348.15)
    "Heat source for heat port in south direction"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-60,-80})),
                HideResult = true);
  Boundaries.Thermal.HeatSource heatSource_north_1(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.Temperature,
    T=313.15) "Heat source for heat port in north direction"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={-60,-20})),
                HideResult = true);
  Boundaries.Thermal.HeatSource heatSource_south_2(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.Temperature,
    T=348.15)
    "Heat source for heat port in south direction"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={0,-80})),
                HideResult = true);
  Boundaries.Thermal.HeatSource heatSource_north_2(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.Temperature,
    T=313.15) "Heat source for heat port in north direction"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={0,-20})),
                HideResult = true);
  Boundaries.Thermal.HeatSource heatSource_south_3(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.Temperature,
    T=348.15)
    "Heat source for heat port in south direction"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={60,-80})),
                HideResult = true);
  Boundaries.Thermal.HeatSource heatSource_north_3(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.Temperature,
    T=313.15) "Heat source for heat port in north direction"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=90,origin={60,-20})),
                HideResult = true);

equation
  //
  // Connections
  //
  connect(heatSource_south_1.port, wallCell_fixedInitial_boundaries.heatPort_S)
    annotation (Line(
      points={{-60,-80},{-60,-60}},
      color={238,46,47},
      thickness=1));
  connect(wallCell_fixedInitial_boundaries.heatPort_N, heatSource_north_1.port)
    annotation (Line(
      points={{-60,-40},{-60,-20}},
      color={238,46,47},
      thickness=1));
  connect(heatSource_south_2.port,
    wallCell_steadyStateInitialisation_boundaries.heatPort_S) annotation (Line(
      points={{0,-80},{0,-60}},
      color={238,46,47},
      thickness=1));
  connect(wallCell_steadyStateInitialisation_boundaries.heatPort_N,
    heatSource_north_2.port) annotation (Line(
      points={{0,-40},{0,-20}},
      color={238,46,47},
      thickness=1));
  connect(heatSource_south_3.port, wallCell_steadyStateBalance_boundaries.heatPort_S)
    annotation (Line(
      points={{60,-80},{60,-60}},
      color={238,46,47},
      thickness=1));
  connect(wallCell_steadyStateBalance_boundaries.heatPort_N, heatSource_north_3.port)
    annotation (Line(
      points={{60,-40},{60,-20}},
      color={238,46,47},
      thickness=1));

  //
  // Annotations
  //
  annotation (experiment(StopTime=1000), Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation after restructuring of the library.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestWallCell;
