within SorpLib.Components.Cells.TILMediaLibrary;
model WallCell
  "Model of homogenous wall cell"

  //
  // Definition of parameters
  //
  replaceable model WallMaterial =
    TILMedia.SolidTypes.TILMedia_Aluminum
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Model calculating properties of wall material"
    annotation (Dialog(tab="Media", group="Media Model"),
                choicesAllMatching = true,
                Evaluate=true,
                HideResult = true);

  //
  // Extensions
  //
  extends BaseClasses.PartialWallCell;

  //
  // Instanziation of models
  //
  TILMedia.Solid solid(
    final T = T,
    redeclare final model SolidType = WallMaterial)
    "Properties of wall material"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}})));

equation
  //
  // Passing through properties of media model
  //
  rho = solid.d
    "Density of wall cell";

  c = solid.cp
    "Specific heat capacity of wall cell";
  lambda = solid.lambda
    "Thermal conductivity of wall cell";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  Revisions (e.g., object-oriented approach) after restructering of the library.
  </li>
  <li>
  November 23, 2017, by Andrej Gibelhaus:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end WallCell;
