within SorpLib.Components.ClosedAdsorbers.BaseClasses;
partial model PartialAdsorber "Base model for all adsorber models"

  //
  // Definition of general parameters
  //
  parameter Integer no_cells_liquid(min=2)=10
    "Discretization number of liquid cells"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);
  parameter Integer no_cells_wall(min=1)=no_cells_liquid
    "Discretization number of wall cells (must be a facotr of no_cells_liquid)"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);
  parameter Integer no_cells_sorbent(min=1)=1
    "Discretization number of sorbent cells (must be a facotr of no_cells_wall)"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);

  replaceable parameter ClosedAdsorbers.Geometry.ClosedAdsorber
    adsorberGeometry constrainedby ClosedAdsorbers.Geometry.ClosedAdsorber
    "Geometry of closed adsorber"
    annotation (Dialog(tab="General", group="Geometry"),
                choicesAllMatching = true);

  //
  // Definition of parameters describing transport phenomena
  //
  parameter Boolean use_casing = false
    " = true, to enable casing; otherwise, no casing is used"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_WPair_to_TubeWall =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
      (constantAlphaA=100) constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer coefficient between heat exchanger
     wall cells and working pair cells"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer"),
               choices(choice(redeclare model HeatTransfer_WPair_to_TubeWall =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_WPair_to_TubeWall =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  parameter Internals.Types.BalancingWallElement balancingWallElement=
   Internals.Types.BalancingWallElement.NS
   "Balancing method for wall cell"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_NS =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
    "Heat transfer model for north-south direction of wall"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_WE =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
     "Heat transder model for west-east direction of wall"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_TubeSide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialExternalHeatTransferCoefficientLiquidTube
    "Heat transfer model for heat transfer coefficient betwenn liquid and wall
     cells"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlpha
                          "Liquid heat exchanger | Constant alpha for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
                          "Liquid heat exchanger | Constant alphaA for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate
                          "Liquid heat exchanger | Sieder-Tate correlation"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.Schmidt
                          "Liquid heat exchanger | Schmidt-Korrelation")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_Casing =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer calculation between casing and
    phase seperator"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer",
               enable = use_casing),
               choices(choice(redeclare model HeatTransfer_Casing =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_Casing =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  replaceable model PressureDropModel =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes
    "Pressure drop model"
    annotation (Dialog(tab="Transport Phenomena", group="Pressure Drop"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
                          "Liquid heat exchanger | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ConstantZeta
                          "Liquid heat exchanger | Constant resistance for each cell (i.e., zeta)"),
                        choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
                          "Liquid heat exchanger | Konakov correlation")));

  //
  // Definition of parameters describing the medium
  //
  parameter Integer no_components_VLE = 1
    "Number of components in VLE medium"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);
  parameter Integer no_components_liquid = 1
    "Number of components in liquid medium"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);

  replaceable model WorkingPair =
    Media.WorkingPair.BaseClasses.PartialWorkingPair
    constrainedby Media.WorkingPair.BaseClasses.PartialWorkingPair
    "Working pair model"
    annotation (Dialog(tab="Media",group="Working Pair"),
                choicesAllMatching = true,
                Evaluate=true,
                HideResult=true);
  parameter Modelica.SIunits.Mass m_sorbent = 2.5
    "Mass of dry sorbent"
    annotation (Dialog(tab="Media",group="Working Pair"),
                HideResult=true);

  //
  // Definition of parameters describing the initialisation
  //
  parameter Modelica.SIunits.MassFraction[no_components_liquid-1] xiInitial_liquidCell=
    fill(1/no_components_liquid, no_components_liquid-1)
    "Initial values for independent mass fractions in liquid cells"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Pressure pInitial_liquidCell_1=1e5+25000
    "Initial value for liquid pressure of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Pressure pInitial_liquidCell_N=1e5
    "Initial value for liquid pressure of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_liquidCell_1=283.15
    "Initial value for liquid temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_liquidCell_N=303.15
    "Initial value for liquid temperature of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_wallCell_1 = 293.15
    "Initial value for wall temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_wallCell_N = 313.15
    "Initial value for wall temperature of cell N"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_WPair = 298.15
    "Initial value for equilibrium temperature of adsorbate"
    annotation (Dialog(group = "Initial Values", tab = "Initialisation"),
                HideResult=true);

  parameter Modelica.SIunits.Temperature TInitial_casing = 313.15
    "Initial value for casing temperature"
    annotation (Dialog(tab="Initialisation", group="Initial Values",
                enable = use_casing),
                HideResult = true);

  parameter Modelica.SIunits.MassFlowRate m_flowInitial_Liquid = 1e-4
    "Start value for mass flow rate"
    annotation (Dialog(tab="Initialisation", group="Start Values"),
                HideResult = true);

  //
  // Definition of parameters describing advanced options
  //
  parameter Boolean avoid_events = true
    "= true, if events are avoid by using noEvent()-operator"
    annotation (Dialog(tab = "Advanced", group = "Numerics"),
                Evaluate=true,
                HideResult = true);

  //
  // Definition of models
  //
  replaceable HeatExchangers.Liquid.BaseClasses.PartialLiquidHeatExchanger
    liquidHeatExchanger(
    final no_components=no_components_liquid,
    final xiInitial=xiInitial_liquidCell,
    final m_flowInitial=m_flowInitial_Liquid,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final avoid_events=avoid_events,
      final no_cells_liquid=no_cells_liquid,
      final no_cells_wall=no_cells_wall,
      final heatExchangerGeometry(
        final roughness=adsorberGeometry.roughness,
        final d_inner=adsorberGeometry.d_inner_hx,
        final d_outer=adsorberGeometry.d_outer_hx,
        final wallThickness=adsorberGeometry.wallThickness_hx,
        final length=adsorberGeometry.length_hx,
        final length_heatTransfer=adsorberGeometry.length_heatTransfer_hx,
        final innerCrossSectionalArea=adsorberGeometry.innerCrossSectionalArea_hx,
        final outerCrossSectionalArea=adsorberGeometry.outerCrossSectionalArea_hx,
        final wallCrossSectionalArea=adsorberGeometry.wallCrossSectionalArea_hx,
        final innerVolume=adsorberGeometry.innerVolume_hx,
        final outerVolume=adsorberGeometry.outerVolume_hx,
        final wallVolume=adsorberGeometry.wallVolume_hx,
        final innerHeatTransferArea=adsorberGeometry.innerHeatTransferArea_hx,
        final outerHeatTransferArea=adsorberGeometry.outerHeatTransferArea_hx,
        final nParallelTubes=adsorberGeometry.nParallelTubes_hx),
    final balancingWallElement=balancingWallElement,
    redeclare final model HeatTransferModel_TubeSide =
        HeatTransferModel_TubeSide,
    redeclare final model HeatTransferModel_NS = HeatTransferModel_NS,
    redeclare final model HeatTransferModel_WE = HeatTransferModel_WE,
    redeclare final model PressureDropModel = PressureDropModel,
    final pInitial_liquidCell_1=pInitial_liquidCell_1,
    final pInitial_liquidCell_N=pInitial_liquidCell_N,
    final TInitial_liquidCell_1=TInitial_liquidCell_1,
    final TInitial_liquidCell_N=TInitial_liquidCell_N,
    final TInitial_wallCell_1=TInitial_wallCell_1,
    final TInitial_wallCell_N=TInitial_wallCell_N)
    "Model of heat exchanger of adsorber"
    annotation (Placement(transformation(extent={{-24,-10},{24,10}},rotation=90,
                origin={70,0})));

  HeatTransfers.HeatTransfer heatTransfer_WPair_to_TubeWall(
    final n_A = no_cells_wall,
    final n_B=no_cells_sorbent,
    redeclare final model HeatTransfer = HeatTransfer_WPair_to_TubeWall)
    "Heat transfer model to calculate heat transfer between working pair cells 
     and wall cells of heat exchanger tube"
    annotation (Placement(transformation(extent={{50,-4},{30,4}})));

  HeatTransfers.HeatTransfer heatTransfer_CasingPhaseSeperator(
    final n_A=1,
    redeclare final model HeatTransfer = HeatTransfer_Casing) if use_casing
    "Heat transfer model between casing and vapor phase or working pair" annotation (
      Placement(transformation(
        extent={{10,-4},{-10,4}},
        rotation=180,
        origin={-60,0})));

  replaceable Cells.BaseClasses.PartialWorkingPairCell[no_cells_sorbent]
    WPairCell(
    each final no_components=no_components_VLE,
    each final m_sorbent=m_sorbent/no_cells_sorbent,
    each final TInitial=TInitial_WPair,
    each final avoid_events=avoid_events)
    "Model of the working pair cell"
    annotation (Placement(transformation(extent={{20,-20},{-20,20}},rotation=90,
                origin={0,0})));

  replaceable Cells.BaseClasses.PartialWallCell casing(
    final cellGeometry(final volume=adsorberGeometry.wallVolume_casing),
    final balancingWallElement=SorpLib.Internals.Types.BalancingWallElement.NoResistances,
    redeclare final model HeatTransferModel_NS =
        HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR,
    redeclare final model HeatTransferModel_WE =
        HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR,
    final TInitial=TInitial_casing,
    final type_energyBalance=SorpLib.Internals.Types.BalanceEquations.Transient_FixedInitial) if
       use_casing "Casing of evaporator or condenser" annotation (Placement(
        transformation(
        extent={{-6,6},{6,-6}},
        rotation=270,
        origin={-80,0})));

  //
  // Definition of connectors
  //
public
  replaceable Connectors.BaseClasses.PartialMediaConnector liquid_a(
    final no_components=no_components_liquid,
    m_flow(start = m_flowInitial_Liquid))
    "Inlet liquid port at design direction"
    annotation (Placement(transformation(extent={{90,-50},{110,-30}}),
        iconTransformation(extent={{90,-50},{110,-30}})));
  replaceable Connectors.BaseClasses.PartialMediaConnector liquid_b(
    final no_components=no_components_liquid,
    m_flow(start = -m_flowInitial_Liquid))
    "Outlet liquid port at design direction"
    annotation (Placement(transformation(extent={{90,32},{110,52}}),
        iconTransformation(extent={{90,32},{110,52}})));

  Connectors.Thermal.Port_a heatPort if use_casing
    "Heat port to environment of adsorber"
    annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));

equation
  //
  // Connection of fluid ports
  //
  connect(liquid_a, liquidHeatExchanger.port_a) annotation (Line(
      points={{100,-40},{70,-40},{70,-24}},
      color={28,108,200},
      thickness=1));
  connect(liquidHeatExchanger.port_b, liquid_b) annotation (Line(
      points={{70,23.52},{70,42},{100,42}},
      color={28,108,200},
      thickness=1));

  //
  // Connection of heat ports
  //
  connect(liquidHeatExchanger.heatPort, heatTransfer_WPair_to_TubeWall.heatPort_a)
    annotation (Line(
      points={{60,0},{50,0}},
      color={238,46,47},
      thickness=1));
  connect(heatTransfer_WPair_to_TubeWall.heatPort_b, WPairCell.heatPort_a)
    annotation (Line(
      points={{30,0},{12,0}},
      color={238,46,47},
      thickness=1));
  connect(heatPort, casing.heatPort_N) annotation (Line(
      points={{-100,0},{-86,0}},
      color={238,46,47},
      thickness=1));
  connect(casing.heatPort_S, heatTransfer_CasingPhaseSeperator.heatPort_a[1])
    annotation (Line(
      points={{-74,0},{-70,0}},
      color={238,46,47},
      thickness=1));

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
        Rectangle(
          extent={{-100,60},{100,-60}},
          lineColor={0,0,0},
          lineThickness=1),
        Line(
          points={{100,40},{-80,40},{80,0},{-80,-40},{100,-40}},
          color={0,0,0},
          thickness=1),
        Ellipse(
          extent={{-74,42},{-80,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-14,42},{-20,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-26,42},{-32,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-38,42},{-44,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-50,42},{-56,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-62,42},{-68,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{58,42},{52,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{46,42},{40,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{34,42},{28,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{22,42},{16,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{10,42},{4,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-2,42},{-8,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{70,42},{64,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{82,42},{76,48}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{82,-48},{76,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{70,-48},{64,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{58,-48},{52,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{46,-48},{40,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{34,-48},{28,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{22,-48},{16,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{10,-48},{4,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-2,-48},{-8,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-14,-48},{-20,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-26,-48},{-32,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-38,-48},{-44,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-50,-48},{-56,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-62,-48},{-68,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-74,-48},{-80,-42}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{88,-38},{82,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{76,-38},{70,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{64,-38},{58,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{52,-38},{46,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{40,-38},{34,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{28,-38},{22,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{16,-38},{10,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{4,-38},{-2,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-8,-38},{-14,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-20,-38},{-26,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-32,-38},{-38,-32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-44,-40},{-50,-34}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-44,34},{-50,40}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-32,32},{-38,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-20,32},{-26,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-8,32},{-14,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{4,32},{-2,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{16,32},{10,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{28,32},{22,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{40,32},{34,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{52,32},{46,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{64,32},{58,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{76,32},{70,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{88,32},{82,38}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-66,30},{-72,36}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-52,26},{-58,32}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-36,22},{-42,28}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-18,18},{-24,24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-4,14},{-10,20}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{12,10},{6,16}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{30,6},{24,12}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{44,2},{38,8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{60,-2},{54,4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-8,24},{-14,30}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{6,20},{0,26}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{22,16},{16,22}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{38,12},{32,18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{52,8},{46,14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{68,4},{62,10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-66,-36},{-72,-30}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-52,-32},{-58,-26}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-36,-28},{-42,-22}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-18,-24},{-24,-18}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-4,-20},{-10,-14}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{12,-16},{6,-10}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{30,-12},{24,-6}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{44,-8},{38,-2}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{68,-10},{62,-4}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{52,-14},{46,-8}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{38,-18},{32,-12}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{24,-22},{18,-16}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{6,-26},{0,-20}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-8,-30},{-14,-24}},
          lineColor={244,125,35},
          lineThickness=1,
          fillColor={244,125,35},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-44,24},{-50,30}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-54,34},{-60,40}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-76,34},{-82,40}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-8,42},{-14,48}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-14,26},{-20,32}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{4,12},{-2,18}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{30,14},{24,20}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{52,0},{46,6}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{34,32},{28,38}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{76,42},{70,48}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{82,32},{76,38}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{20,-14},{14,-8}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-28,-26},{-34,-20}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-52,-40},{-58,-34}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-78,-42},{-84,-36}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-32,-48},{-38,-42}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{10,-38},{4,-32}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{40,-48},{34,-42}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{70,-38},{64,-32}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{46,-16},{40,-10}},
          lineColor={0,140,72},
          lineThickness=1,
          fillColor={0,140,72},
          fillPattern=FillPattern.Solid)}),                      Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialAdsorber;
