﻿within SorpLib.Components.ClosedAdsorbers.BaseClasses;
partial model PartialAdsorber_N1
  "Base model for all closed adsorbers modelling pure component adsorption"
  extends PartialAdsorber;

  //
  // Definition of general parameters
  //
  parameter Boolean is_activelyCloseable = false
    "= true, if valve is actively closeable; otherwise, valve cannot be closed
     actively"
    annotation (Dialog(tab="General",group="Valve Setup"),
                Evaluate = true,
                HideResult=true);
  parameter Boolean is_flapValve = false
    "= true, if valve is flap valve; otherwise, valve is not a flap valve"
    annotation (Dialog(tab="General",group="Valve Setup"),
                Evaluate = true,
                HideResult=true);
  parameter Boolean allow_massRecovery = false
    "= true, if models for mass recovery are introduced"
    annotation (Dialog(tab="General",group="Valve Setup"),
                Evaluate = true,
                HideResult=true);

  //
  // Definition of parameters describing transport phenomena
  //
  replaceable model MassTransfer_evaporator =
    SorpLib.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
    constrainedby
    MassTransfers.TransportPhenomena.BaseClasses.PartiallInternalMassTransfer_dx
    "Mass transfer model for adsorption phase"
    annotation (Dialog(tab="Transport Phenomena",group="Mass Transfer"),
                choices(choice(redeclare model MassTransfer_evaporator =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantCoefficient
                         "Mass Transfer | Constant mass transfer coefficient for loading-driven mass transfer"),
                       choice(redeclare model MassTransfer_evaporator =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantSpecificCoefficient
                         "Mass Transfer | Constant specific mass transfer coefficient for loading-driven mass transfe"),
                       choice(redeclare model MassTransfer_evaporator =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
                         "Mass Transfer | Glückauf-approach for loading-driven mass transfer"),
                       choice(redeclare model MassTransfer_evaporator =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.GlueckaufArrhenius
                         "Mass Transfer | Glückauf-approach with temperature-dependent diffusion coefficient for loading-driven mass transfer")),
                 Evaluate=true,
                 HideResult=true);
  replaceable model MassTransfer_condenser =
    SorpLib.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
    constrainedby
    MassTransfers.TransportPhenomena.BaseClasses.PartiallInternalMassTransfer_dx
    "Mass transfer model for desorption phase"
    annotation (Dialog(tab="Transport Phenomena",group="Mass Transfer"),
                choices(choice(redeclare model MassTransfer_condenser =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantCoefficient
                         "Mass Transfer | Constant mass transfer coefficient for loading-driven mass transfer"),
                       choice(redeclare model MassTransfer_condenser =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantSpecificCoefficient
                         "Mass Transfer | Constant specific mass transfer coefficient for loading-driven mass transfe"),
                       choice(redeclare model MassTransfer_condenser =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
                         "Mass Transfer | Glückauf-approach for loading-driven mass transfer"),
                       choice(redeclare model MassTransfer_condenser =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.GlueckaufArrhenius
                         "Mass Transfer | Glückauf-approach with temperature-dependent diffusion coefficient for loading-driven mass transfer")),
                 Evaluate=true,
                 HideResult=true);
  replaceable model MassTransfer_massRecovery =
    SorpLib.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
    constrainedby
    MassTransfers.TransportPhenomena.BaseClasses.PartiallInternalMassTransfer_dx
    "Mass transfer model for mass recovery phase"
    annotation (Dialog(tab="Transport Phenomena",group="Mass Transfer",
                enable=allow_massRecovery),
                choices(choice(redeclare model TransportPhenomena =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantCoefficient
                         "Mass Transfer | Constant mass transfer coefficient for loading-driven mass transfer"),
                       choice(redeclare model TransportPhenomena =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.ConstantSpecificCoefficient
                         "Mass Transfer | Constant specific mass transfer coefficient for loading-driven mass transfe"),
                       choice(redeclare model TransportPhenomena =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf
                         "Mass Transfer | Glückauf-approach for loading-driven mass transfer"),
                       choice(redeclare model TransportPhenomena =
            TransHeat.Components.MassTransfers.TransportPhenomena.LoadingDriven.GlueckaufArrhenius
                         "Mass Transfer | Glückauf-approach with temperature-dependent diffusion coefficient for loading-driven mass transfer")),
                 Evaluate=true,
                 HideResult=true);

  //
  // Definition of parameters describing the initialisation
  //
  parameter Real xInitial_Wpair(unit="kg/kg") = 0.2
    "Initial value for equilibrium loading of adsorbate"
    annotation (Dialog(group = "Initial Values", tab = "Initialisation"),
                HideResult=true);

  parameter Modelica.SIunits.MassFlowRate m_flowInitial_VLE = 1e-4
    "Start value for mass flow rate of adsorbate"
    annotation (Dialog(tab="Initialisation", group="Start Values"),
                HideResult = true);
  parameter Modelica.SIunits.Pressure pStart_WPair = 100
    "Start value for equilibrium pressure of adsorbate"
    annotation (Dialog(group = "Start Values", tab = "Initialisation"),
                HideResult=true);

  //
  // Definition of models
  //
protected
  replaceable Fittings.SplitterJunctions.BaseClasses.PartialSplitterJunction
    splitterJunction_evaporator(
      final no_ports_b=no_cells_sorbent,
      final no_components=no_components_VLE)
    "Splitter / Junction model for evaporator port"
    annotation (Placement(transformation(extent={{-6,-10},{6,10}},
                rotation=270,origin={0,-78})));
  replaceable Fittings.SplitterJunctions.BaseClasses.PartialSplitterJunction
    splitterJunction_condenser(
      final no_ports_b=no_cells_sorbent,
      final no_components=no_components_VLE)
    "Splitter / Junction model for condenser port"
    annotation (Placement(transformation(extent={{6,-10},{-6,10}},
                rotation=270, origin={0,78})));
  replaceable Fittings.SplitterJunctions.BaseClasses.PartialSplitterJunction
    splitterJunction_massRecovery(
      final no_ports_b=no_cells_sorbent,
      final no_components=no_components_VLE) if
    allow_massRecovery
    "Splitter / Junction model for mass recovery port"
    annotation (Placement(transformation(
        extent={{-6,-10},{6,10}},
        rotation=270,
        origin={-50,-78})));

public
  replaceable MassTransfers.BaseClasses.PartialSingleMassTransfer[no_cells_sorbent]
    massTransfer_evap_to_WPair(
      each final is_activelyCloseable=is_activelyCloseable,
      each final is_flapValve=is_flapValve,
      each final is_flowAB=true,
      each final no_cells=no_cells_sorbent,
      each final no_components=no_components_VLE,
      each final avoid_events=avoid_events,
      each final pInitial=pStart_WPair,
      each final m_flowInitial=m_flowInitial_VLE)
    "Mass transfer model to calculate mass transfer between evaporator and adsorber model"
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={0,-50})));
  replaceable MassTransfers.BaseClasses.PartialSingleMassTransfer[no_cells_sorbent]
    massTransfer_cond_to_WPair(
      each final is_activelyCloseable=is_activelyCloseable,
      each final is_flapValve=is_flapValve,
      each final is_flowAB=false,
      each final no_cells=no_cells_sorbent,
      each final no_components=no_components_VLE,
      each final avoid_events=avoid_events,
      each final pInitial=pStart_WPair,
      each final m_flowInitial=m_flowInitial_VLE)
    "Mass transfer model to calculate mass transfer between condenser and adsorber model"
    annotation (Placement(transformation(
        extent={{10,10},{-10,-10}},
        rotation=90,
        origin={0,50})));

  replaceable MassTransfers.BaseClasses.PartialSingleMassTransfer[no_cells_sorbent]
    massTransfer_massRecovery(
      each final is_activelyCloseable=true,
      each final is_flapValve=false,
      each final is_flowAB=true,
      each final no_cells=no_cells_sorbent,
      each final no_components=no_components_VLE,
      each final avoid_events=avoid_events,
      each final pInitial=pStart_WPair,
      each final m_flowInitial=m_flowInitial_VLE) if allow_massRecovery
    "Mass transfer model to calculate mass transfer between adsorber beds"
    annotation (Placement(transformation(
        extent={{-10,10},{10,-10}},
        rotation=90,
        origin={-50,-50})));

  //
  // Definition of connectors
  //
  replaceable Connectors.BaseClasses.PartialMediaConnector VLE_evaporator(
    final no_components=no_components_VLE,
    m_flow(start = m_flowInitial_VLE)) "Inlet fluid from evaporator"
    annotation (Placement(transformation(extent={{-10,-110},{10,-90}}),
        iconTransformation(extent={{-10,-110},{10,-90}})));
  replaceable Connectors.BaseClasses.PartialMediaConnector VLE_condenser(
    each final no_components=no_components_VLE,
    each m_flow(start = -m_flowInitial_VLE)) "Inlet fluid port from condenser"
    annotation (Placement(transformation(extent={{-10,90},{10,110}})));
  replaceable Connectors.BaseClasses.PartialMediaConnector VLE_massRecovery(
    final no_components=no_components_VLE,
    m_flow(start=m_flowInitial_VLE)) if allow_massRecovery
    "VLE port for mass recovery between adsorber beds"
    annotation (Placement(transformation(extent={{-60,-110},{-40,-90}}),
        iconTransformation(extent={{-60,-110},{-40,-90}})));

  Modelica.Blocks.Interfaces.RealInput statusValveCondenser if
    is_activelyCloseable
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,origin={-100,-20}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={-100,-20})), HideResult=not is_activelyCloseable);
  Modelica.Blocks.Interfaces.RealInput statusValveMassRecovery if
    allow_massRecovery
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,origin={-100,-34}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={-100,-34})), HideResult=not is_activelyCloseable);

  Modelica.Blocks.Interfaces.RealInput statusValveEvaporator if
    is_activelyCloseable
    "> 0, if valve is open; otherwise, valve is actively closed"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
                rotation=0,origin={-100,-50}),
                iconTransformation(extent={{-10,-10},{10,10}},
                origin={-100,-50})), HideResult=not is_activelyCloseable);

equation
  //
  // Connection of fluid ports
  //
  connect(VLE_evaporator, splitterJunction_evaporator.port_a)
    annotation (Line(points={{0,-100},{0,-84}}, color={0,140,72},
      thickness=1));
  connect(splitterJunction_evaporator.port_b, massTransfer_evap_to_WPair.port_a)
    annotation (Line(points={{0,-72},{0,-60}}, color={0,140,72},
      thickness=1));
  connect(VLE_condenser, splitterJunction_condenser.port_a)
    annotation (Line(points={{0,100},{0,84}}, color={0,140,72},
      thickness=1));
  connect(splitterJunction_condenser.port_b, massTransfer_cond_to_WPair.port_a)
    annotation (Line(points={{0,72},{0,60}}, color={0,140,72},
      thickness=1));
  connect(VLE_massRecovery, splitterJunction_massRecovery.port_a)
    annotation (Line(points={{-50,-100},{-50,-84}}, color={0,140,72},
      thickness=1));
  connect(splitterJunction_massRecovery.port_b, massTransfer_massRecovery.port_a)
    annotation (Line(points={{-50,-72},{-50,-60}}, color={0,140,72},
      thickness=1));

  //
  // Conenction of signals
  //
  if is_activelyCloseable then
    for i in 1:no_cells_sorbent loop
      connect(statusValveCondenser, massTransfer_cond_to_WPair[i].open_input);
      connect(statusValveEvaporator, massTransfer_evap_to_WPair[i].open_input);
    end for;
  end if;

  if allow_massRecovery then
    for i in 1:no_cells_sorbent loop
      connect(statusValveMassRecovery, massTransfer_massRecovery[i].open_input);
    end for;
  end if;

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialAdsorber_N1;
