within SorpLib.Components.ClosedAdsorbers.Geometry;
record ClosedAdsorber
  "Record minimum number of geometric definitions of closed adsorber"
  extends Internals.ClassTypes.Record;

  parameter Modelica.SIunits.Length wallThickness_casing = 0.01
    "Thickness of adsorber casing";
  parameter Modelica.SIunits.Area innerHeatTransferArea_casing = 1
    "Inner heat transfer area of adsorber casing";
  parameter Modelica.SIunits.Area outerHeatTransferArea_casing = 1
    "Outer heat transfer area of adsorber casing";
  parameter Modelica.SIunits.Volume wallVolume_casing = 0.02
    "Wall volume of adsorber";

  parameter Modelica.SIunits.Length roughness = 7.5e-7
    "Roughness of heat exchanger tube";

  parameter Modelica.SIunits.Diameter d_inner_hx = 0.01
    "Inner diameter of circular heat exchanger tube";
  parameter Modelica.SIunits.Diameter d_outer_hx = 0.012
    "Outer diameter of circular heat exchanger tube";
  parameter Modelica.SIunits.Length wallThickness_hx=
    (d_outer_hx-d_inner_hx)/2
    "Thickness of heat exchanger tube";

  parameter Modelica.SIunits.Length length_hx = 1
    "Total length of circular heat exchanger tube";
  parameter Modelica.SIunits.Length length_heatTransfer_hx = length_hx
    "Length of circular tube available for heat transfer on liquid-side 
     and for wall N-S direction";

  parameter Modelica.SIunits.Area innerCrossSectionalArea_hx=
    Modelica.Constants.pi/4 * d_inner_hx^2
    "Inner cross-sectional heat exchanger area";
  parameter Modelica.SIunits.Area outerCrossSectionalArea_hx=
    Modelica.Constants.pi/4 * d_outer_hx^2
    "Outer cross-sectional heat exchanger area";
  parameter Modelica.SIunits.Area wallCrossSectionalArea_hx=
    outerCrossSectionalArea_hx-innerCrossSectionalArea_hx
    "Cross-sectional area of heat exchanger wall";

  parameter Modelica.SIunits.Volume innerVolume_hx=
    innerCrossSectionalArea_hx * length_hx
    "Inner heat exchanger tube volume";
  parameter Modelica.SIunits.Volume outerVolume_hx=
    outerCrossSectionalArea_hx * length_hx
    "Outer heat exchanger tube volume";
  parameter Modelica.SIunits.Volume wallVolume_hx=
    wallCrossSectionalArea_hx * length_hx
    "Wall volume of heat exchanger";

  parameter Modelica.SIunits.Area innerHeatTransferArea_hx=
    Modelica.Constants.pi * d_inner_hx * length_heatTransfer_hx
    "Inner heat transfer area of heat exchanger";
  parameter Modelica.SIunits.Area outerHeatTransferArea_hx=
    Modelica.Constants.pi * d_outer_hx * length_heatTransfer_hx
    "Outer heat transfer area of heat exchanger";

  parameter Real nParallelTubes_hx(min=1) = 1
    "Number of parallel heat exchanger tubes";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation including major revisions after restructuring of the library.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end ClosedAdsorber;
