within SorpLib.Components.ClosedAdsorbers.ModelicaMediaLibrary;
model ClosedAdsorber
  "Closed adsorber model based on the Modelica.Media library"
  extends BaseClasses.PartialAdsorber_N1(
    redeclare replaceable model WorkingPair =
      Media.WorkingPair.SingleComponent.Modelica_VLE.H2O_AQSOAZ02_Goldsworthy (
        type_isotherm=Internals.Types.Isotherm.Inverse),
    redeclare Connectors.ModelicaMediaLibrary.LiquidPort_a liquid_a(
      redeclare final package Medium = Medium_Liquid),
    redeclare Connectors.ModelicaMediaLibrary.LiquidPort_b liquid_b(
      redeclare final package Medium = Medium_Liquid),
    redeclare Connectors.ModelicaMediaLibrary.VLEPort_a VLE_evaporator(
        redeclare final package Medium = Medium_VLE),
    redeclare Connectors.ModelicaMediaLibrary.VLEPort_a VLE_condenser(
        redeclare final package Medium = Medium_VLE),
    redeclare HeatExchangers.Liquid.ModelicaMediaLibrary.LiquidHeatExchanger
      liquidHeatExchanger(
        redeclare final package Medium = Medium_Liquid,
        redeclare final model Solid = Solid),
    redeclare Cells.ModelicaMediaLibrary.SingleVLEWPairCell WPairCell(
        redeclare each final model SingleWPair = WorkingPair,
        each final xInitial=xInitial_Wpair,
        each final m_flowInitial=m_flowInitial_VLE,
        each final pStart=pStart_WPair,
        redeclare each final package Medium = Medium_VLE,
        each final nPorts_B= if allow_massRecovery then 2 else 1),
    redeclare
      Fittings.SplitterJunctions.ModelicaMediaLibrary.VLESplitterJunction
      splitterJunction_evaporator(
        redeclare each final package Medium = Medium_VLE),
    redeclare
      Fittings.SplitterJunctions.ModelicaMediaLibrary.VLESplitterJunction
      splitterJunction_condenser(
        redeclare each final package Medium = Medium_VLE),
    redeclare MassTransfers.ModelicaMediaLibrary.MassTransfer_VLE_dx
      massTransfer_evap_to_WPair(
      each propertiesPosition=SorpLib.Internals.Types.PositionProperties.PortA,
      redeclare each model MassTransfer_dx = MassTransfer_evaporator,
      redeclare each final model WorkingPair = WorkingPair,
      redeclare each final package Medium = Medium_VLE,
      final T_B_theoEqu=WPairCell.T,
      final x_B_act=WPairCell.x),
    redeclare MassTransfers.ModelicaMediaLibrary.MassTransfer_VLE_dx
      massTransfer_massRecovery(
      each propertiesPosition=SorpLib.Internals.Types.PositionProperties.ActualInlet,
      redeclare each final model MassTransfer_dx = MassTransfer_massRecovery,
      redeclare each final model WorkingPair = WorkingPair,
      redeclare each final package Medium = Medium_VLE,
      final T_B_theoEqu=WPairCell.T,
      final x_B_act=WPairCell.x),
    redeclare MassTransfers.ModelicaMediaLibrary.MassTransfer_VLE_dx
      massTransfer_cond_to_WPair(
      each propertiesPosition=SorpLib.Internals.Types.PositionProperties.PortB,
      redeclare each final model MassTransfer_dx = MassTransfer_condenser,
      redeclare each final model WorkingPair = WorkingPair,
      redeclare each final package Medium = Medium_VLE,
      final T_B_theoEqu=WPairCell.T,
      final x_B_act=WPairCell.x),
    redeclare
      Fittings.SplitterJunctions.ModelicaMediaLibrary.VLESplitterJunction
      splitterJunction_massRecovery(
        redeclare each final package Medium = Medium_VLE),
    redeclare Connectors.ModelicaMediaLibrary.VLEPort_a VLE_massRecovery(
        redeclare final package Medium = Medium_VLE),
    heatTransfer_CasingPhaseSeperator(final n_B=no_cells_sorbent),
    redeclare Cells.ModelicaMediaLibrary.WallCell casing(
        redeclare final model Solid = SolidCasing));

  //
  // Definition of parameters describing the medium
  //
  replaceable package Medium_VLE = Modelica.Media.Water.WaterIF97_ph
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "VLE media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable package Medium_Liquid =
      Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of tubes"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model SolidCasing =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

  //
  // Definition of variables
  //
  SummaryRecords.SingleAdsorptionAdsorber summary(
    final p_adsorpt_avg=sum(WPairCell.p)/no_cells_sorbent,
    final T_adsorpt_avg=sum(WPairCell.T)/no_cells_sorbent,
    final x_adsorpt_avg=sum(WPairCell.x)/no_cells_sorbent,
    final mass=summary.x_adsorpt_avg*m_sorbent,
    final p_liq_inlet=liquidHeatExchanger.stateProperties_portA.p,
    final p_liq_outlet=liquidHeatExchanger.stateProperties_portB.p,
    final p_liq_avg=sum(liquidHeatExchanger.liquidCellls.stateProperties.p)/
        no_cells_liquid,
    final T_liq_inlet=liquidHeatExchanger.stateProperties_portA.T,
    final T_liq_outlet=liquidHeatExchanger.stateProperties_portB.T,
    final T_liq_avg=sum(liquidHeatExchanger.liquidCellls.stateProperties.T)/
        no_cells_liquid,
    final T_wall_avg=sum(liquidHeatExchanger.wallCells.T)/no_cells_wall,
    final m_flow_evapTwpair=sum(WPairCell.port_b[1].m_flow),
    final m_flow_wpairTcond=sum(WPairCell.port_a.m_flow),
    final m_flow_massRecovery=
      if allow_massRecovery then sum(WPairCell.port_b[2].m_flow) else 0,
    final m_flow_liq_inlet=liquidHeatExchanger.m_flow_A,
    final m_flow_liq_outlet=liquidHeatExchanger.m_flow_B,
    final Q_flow_wallTwpair=sum(WPairCell.heatPort_a.Q_flow),
    final DH_liquid=liquidHeatExchanger.DH_flow)
    "Record containing most relevant variables of closed adsorber"
    annotation (Placement(transformation(extent={{60,-100},{100,-60}})));

equation
  //
  // Connection of fluid ports
  //
  connect(massTransfer_evap_to_WPair.port_b, WPairCell.port_b[1])
    annotation (Line(points={{0,-40},{0,-10.4}}, color={0,140,72},
      thickness=1));
  connect(massTransfer_cond_to_WPair.port_b, WPairCell.port_a)
    annotation (Line(points={{0,40},{0,14}}, color={0,140,72},
      thickness=1));
  connect(massTransfer_massRecovery.port_b,  WPairCell.port_b[2])
    annotation (Line(points={{-50,-40},{-50,-26},{0,-26},{0,-10.4}},color={0,140,72},
      thickness=1));
  connect(heatTransfer_CasingPhaseSeperator.heatPort_b, WPairCell.heatPort_b)
    annotation (Line(
      points={{-50,0},{-12,0}},
      color={238,46,47},
      thickness=1));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end ClosedAdsorber;
