within SorpLib.Components.ClosedAdsorbers.ModelicaMediaLibrary.Tester;
model TestClosedAdsorber "Model to test closed adsorber"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  ClosedAdsorber closedAdsorber(
    no_cells_liquid=20,
    adsorberGeometry(length_hx=10),
    use_casing=true,
    redeclare model HeatTransfer_WPair_to_TubeWall =
        HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA (
          constantAlphaA=150),
    redeclare model HeatTransferModel_NS =
        HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased,
    redeclare model HeatTransferModel_WE =
        HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR (constantR=
            1e12),
    redeclare model HeatTransferModel_TubeSide =
        HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate,
    redeclare model PressureDropModel =
        Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov,
    pInitial_liquidCell_1=1025000,
    pInitial_liquidCell_N=1000000,
    TInitial_liquidCell_1=293.15,
    TInitial_liquidCell_N=293.15,
    TInitial_wallCell_1=293.15,
    TInitial_wallCell_N=293.15,
    TInitial_WPair=313.15,
    is_activelyCloseable=false,
    is_flapValve=true,
    redeclare model MassTransfer_evaporator =
        MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf (r_sorbent=
            0.0007),
    redeclare model MassTransfer_condenser =
        MassTransfers.TransportPhenomena.LoadingDriven.Glueckauf (r_sorbent=
            0.0007),
    xInitial_Wpair=0.1) "Model of the closed adsorber"
    annotation (Placement(transformation(extent={{-20,-20},{20,20}})));

  //
  // Definition of boundaries
  //
protected
  Boundaries.ModelicaMediaLibrary.VLEBoundary evaporatorBoundary(
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p(displayUnit="kPa") = 1227.6,
    h=2.5e6,
    T=283.15) "Dummy boundary of evaporator" annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={0,-40})));
  Boundaries.ModelicaMediaLibrary.VLEBoundary condenserBoundary(
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    use_pInput=false,
    p(displayUnit="kPa") = 4246,
    T=303.15) "Dummy boundary of condenser" annotation (Placement(
        transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={0,40})));
  Boundaries.ModelicaMediaLibrary.LiquidBoundary liquidBoundary(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.VolumeFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.1,
    V_flow(displayUnit="l/min") = -0.00016666666666667,
    use_TInput=true,
    T=313.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{70,-30},{50,-10}})));
  Boundaries.ModelicaMediaLibrary.LiquidBoundary liquidBoundary1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    p=1000000,
    m_flow=-0.1,
    T=313.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{50,10},{70,30}})));
  Modelica.Blocks.Sources.Pulse temperatureInput(
    amplitude=60,
    period=1000,
    offset=273.15 + 30) "Temperature input for adsorber heat exchanger"
    annotation (Placement(transformation(extent={{100,-10},{80,10}})));

equation
  //
  // Connections
  //
  connect(evaporatorBoundary.port, closedAdsorber.VLE_evaporator) annotation (
      Line(
      points={{0,-40},{0,-20}},
      color={0,140,72},
      thickness=1));
  connect(condenserBoundary.port, closedAdsorber.VLE_condenser) annotation (
      Line(
      points={{0,40},{0,20}},
      color={0,140,72},
      thickness=1));
  connect(closedAdsorber.liquid_a, liquidBoundary.port) annotation (Line(
      points={{20,-8},{40,-8},{40,-20},{60,-20}},
      color={28,108,200},
      thickness=1));
  connect(liquidBoundary1.port, closedAdsorber.liquid_b) annotation (Line(
      points={{60,20},{40,20},{40,8.4},{20,8.4}},
      color={28,108,200},
      thickness=1));
  connect(liquidBoundary.T_input, temperatureInput.y) annotation (Line(points={{
          61.2,-27},{61.2,-13.5},{79,-13.5},{79,0}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=5000), Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestClosedAdsorber;
