within SorpLib.Components.ClosedAdsorbers.SummaryRecords;
record SingleAdsorptionAdsorber
  "Record containing most import variables of a closed adsorber based on 
   pure-component adsorption"
  extends Internals.ClassTypes.Record;

  //
  // Variables describing the adsorbate
  //
  Modelica.SIunits.Pressure p_adsorpt_avg
    "Average pressure of adsorpt (i.e., averaged over all working pair cells)"
    annotation (Dialog(tab="General", group="Adsorbate"));
  Modelica.SIunits.Temperature T_adsorpt_avg
    "Average temperature of adsorpt (i.e., averaged over all working pair cells)"
    annotation (Dialog(tab="General", group="Adsorbate"));
  Real x_adsorpt_avg(final unit="kg/kg")
    "Average loading of adsorpt (i.e., averaged over all working pair cells)"
    annotation (Dialog(tab="General", group="Adsorbate"));

  Modelica.SIunits.Mass mass
    "Overall mass of fluid"
    annotation (Dialog(tab="General", group="Adsorbate"));

  //
  // Variables describing the heat exchanger
  //
  Modelica.SIunits.Pressure p_liq_inlet
    "Pressure of liquid at heat exchanger inlet"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.Pressure p_liq_outlet
    "Pressure of liquid at heat exchanger outlet"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.Pressure p_liq_avg
    "Average pressure of liquid in heat exchanger"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.PressureDifference dp_liq = p_liq_inlet - p_liq_outlet
    "Pressure difference of liquid in heat exchanger";

  Modelica.SIunits.Temperature T_liq_inlet
    "Temperature of liquid at heat exchanger inlet"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.Temperature T_liq_outlet
    "Temperature of liquid at heat exchanger outlet"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.Temperature T_liq_avg
    "Average temperature of liquid in heat exchanger"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));

  Modelica.SIunits.Temperature T_wall_avg
    "Average wall temperature of heat exchanger"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));

  //
  // Variables required for balance equations
  //
  Modelica.SIunits.MassFlowRate m_flow_evapTwpair
    "Mass flow rate of vapor from evaporator to working pair cells"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.MassFlowRate m_flow_wpairTcond
    "Mass flow rate of vapor from working pair cells to condenser"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.MassFlowRate m_flow_massRecovery
    "Mass flow rate of vapor from working pair cells to mass recovery port"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.MassFlowRate m_flow_liq_inlet
    "Mass flow rate of liquid at inlet of heat exchanger"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.MassFlowRate m_flow_liq_outlet
    "Mass flow rate of liquid at outlet of heat exchanger"
    annotation (Dialog(tab="General", group="Balance Equations"));

  Modelica.SIunits.HeatFlowRate Q_flow_wallTwpair
    "Heat flow rate from heat exchanger walls to working pair cells"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.HeatFlowRate DH_liquid
    "Difference enthalpy flow of liquid in heat exchanger"
    annotation (Dialog(tab="General", group="Balance Equations"));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end SingleAdsorptionAdsorber;
