within SorpLib.Components.Connectors.BaseClasses;
partial model PartialConverter "Base model for all converter models"

  //
  // Definition of parameters
  //
  parameter Integer no_components = 1
    "Number of components"
    annotation (Dialog(tab="General", group="Medium"),
                evaluate=true,
                HideResult=true);

  //
  // Definition of connectors
  //
  replaceable PartialMediaConnector port_mediaLibraryA(final no_components=
        no_components) constrainedby PartialMediaConnector
    "Port of media library A" annotation (Dialog(tab="General", group=
          "Connectors"), Placement(transformation(extent={{-84,-4},{-76,4}})));

  replaceable PartialMediaConnector port_mediaLibraryB(final no_components=
        no_components) constrainedby PartialMediaConnector
    "Port of media library B" annotation (Dialog(tab="General", group=
          "Connectors"), Placement(transformation(extent={{76,4},{84,-4}})));

equation
  //
  // Momentum balance
  //
  0 = port_mediaLibraryA.p - port_mediaLibraryB.p
    "No pressure loss occurs in converter model";

  //
  // Mass balance
  //
  0 = port_mediaLibraryA.m_flow + port_mediaLibraryB.m_flow
    "No storage of mass in converter model";

  port_mediaLibraryA.xi_outflow = inStream(port_mediaLibraryB.xi_outflow)
    "No storage of mass in converter model";
  port_mediaLibraryB.xi_outflow = inStream(port_mediaLibraryA.xi_outflow)
    "No storage of mass in converter model";

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-80,-40},
            {80,40}}),                                          graphics={
        Rectangle(
          extent={{-80,40},{80,-40}},
          lineColor={0,0,0},
          fillColor={228,228,228},
          fillPattern=FillPattern.Sphere),
        Line(
          points={{60,0},{-60,0}},
          color={0,0,0},
          arrow={Arrow.Filled,Arrow.Filled},
          thickness=1)}),                                        Diagram(
        coordinateSystem(preserveAspectRatio=false, extent={{-80,-40},{80,40}}),
        graphics={
        Text(
          extent={{-80,28},{-42,24}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillPattern=FillPattern.Sphere,
          fillColor={228,228,228},
          textString="Use p and h"),
        Line(
          points={{-80,16},{-80,24},{-42,24}},
          color={0,0,0},
          arrow={Arrow.None,Arrow.Filled},
          thickness=0.5),
        Line(
          points={{18,24},{-18,24}},
          color={0,0,0},
          thickness=0.5,
          arrow={Arrow.Filled,Arrow.None}),
        Text(
          extent={{42,28},{80,24}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillPattern=FillPattern.Sphere,
          fillColor={228,228,228},
          textString="Pass p and h"),
        Line(
          points={{80,16},{80,24},{42,24}},
          color={0,0,0},
          arrow={Arrow.Filled,Arrow.None},
          thickness=0.5),
        Text(
          extent={{42,-24},{80,-28}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillPattern=FillPattern.Sphere,
          fillColor={228,228,228},
          textString="Use p and h"),
        Line(
          points={{-19,-4},{-19,4},{19,4}},
          color={0,0,0},
          arrow={Arrow.None,Arrow.Filled},
          thickness=0.5,
          origin={61,-20},
          rotation=180),
        Line(
          points={{19,-4},{19,4},{-19,4}},
          color={0,0,0},
          arrow={Arrow.Filled,Arrow.None},
          thickness=0.5,
          origin={-61,-20},
          rotation=180),
        Text(
          extent={{-80,-24},{-42,-28}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillPattern=FillPattern.Sphere,
          fillColor={228,228,228},
          textString="Pass p and h"),
        Line(
          points={{-18,-24},{18,-24}},
          color={0,0,0},
          thickness=0.5,
          arrow={Arrow.Filled,Arrow.None}),
        Text(
          extent={{-60,12},{60,-12}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillPattern=FillPattern.Sphere,
          fillColor={228,228,228},
          textString="Conversion is necessary because reference
states of the two media models may be different!

For this purpose, thermal properties are calculated using the first medium.
Then, the thermal properties are used to calculate the specific enthalpy of the second medium.")}),
    Documentation(revisions="<html>
<ul>
  <li>
  January 11, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialConverter;
