﻿within SorpLib.Components.Connectors.BaseClasses;
partial model PartialTestConverter
  "Base model for testers of converter models: Generic<->Media and Media <-> Media"
  extends Modelica.Icons.Example;

  //
  // Definition of converter models
  //
  replaceable PartialConverter converterA_GenericVLE
    "Converts generic media model to VLE model of Modelica.Media library"
    annotation (Placement(transformation(extent={{-58,66},{-42,74}})));
  replaceable PartialConverter converterA_VLEGas
    "Converts VLE model of Modelica.Media library to gas model of Modelica.Media library"
    annotation (Placement(transformation(extent={{-28,66},{-12,74}})));
  replaceable PartialConverter converterA_GasVLE
    "Converts gas model of Modelica.Media library to VLE model of Modelica.Media library"
    annotation (Placement(transformation(extent={{28,66},{12,74}})));
  replaceable PartialConverter converterA_VLEGeneric
    "Converts VLE model of Modelica.Media library to generic media model"
    annotation (Placement(transformation(extent={{58,66},{42,74}})));

  replaceable PartialConverter converterB_GenericVLE
    "Converts generic media model to VLE model of Modelica.Media library"
    annotation (Placement(transformation(extent={{-58,26},{-42,34}})));
  replaceable PartialConverter converterB_VLELiquid
    "Converts VLE model of Modelica.Media library to liquid model of Modelica.Media library"
    annotation (Placement(transformation(extent={{-28,26},{-12,34}})));
  replaceable PartialConverter converterB_LiquidVLE
    "Converts liquid model of Modelica.Media library to VLE model of Modelica.Media library"
    annotation (Placement(transformation(extent={{28,26},{12,34}})));
  replaceable PartialConverter converterB_VLEGeneric
    "Converts VLE model of Modelica.Media library to generic media model"
    annotation (Placement(transformation(extent={{58,26},{42,34}})));

  replaceable PartialConverter converterC_GenericGas
    "Converts generic media model to gas model of Modelica.Media library"
    annotation (Placement(transformation(extent={{-8,-34},{8,-26}})));

  replaceable PartialConverter converterD_GenericLiquid
    "Converts generic media model to öiquid model of Modelica.Media library"
    annotation (Placement(transformation(extent={{-8,-74},{8,-66}})));

  //
  // Definition of boundaries
  //
  Modelica.Blocks.Sources.Ramp input_mVar(
    height=2,
    duration=2500,
    offset=-1,
    startTime=0)
    "Ramp to simulate input signal of mass flow"
    annotation (Placement(transformation(extent={{-110,-10},{-90,10}})),
                HideResult=true);

  replaceable Boundaries.BaseClasses.PartialBoundary converterA_designInput(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    use_mFlowInput=true,
    h=2750e3)
    "Boundary at design input of converter A"
    annotation (Placement(transformation(extent={{-90,60},{-70,80}})));
  replaceable Boundaries.BaseClasses.PartialBoundary converterA_designOutput(
    h=2900e3)
    "Boundary at design output of converter A"
    annotation (Placement(transformation(extent={{70,60},{90,80}})));

  replaceable Boundaries.BaseClasses.PartialBoundary converterB_designInput(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    use_mFlowInput=true,
    h=100e3)
    "Boundary at design input of converter B"
    annotation (Placement(transformation(extent={{-90,20},{-70,40}})));
  replaceable Boundaries.BaseClasses.PartialBoundary converterB_designOutput
    "Boundary at design output of converter B"
    annotation (Placement(transformation(extent={{70,20},{90,40}})));

  replaceable Boundaries.BaseClasses.PartialBoundary converterC_designInput(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    use_mFlowInput=true,
    h=2750e3)
    "Boundary at design input of converter C"
    annotation (Placement(transformation(extent={{-40,-40},{-20,-20}})));
  replaceable Boundaries.BaseClasses.PartialBoundary converterC_designOutlet
    "Boundary at design outlet of converter C"
    annotation (Placement(transformation(extent={{20,-40},{40,-20}})));

  replaceable Boundaries.BaseClasses.PartialBoundary converterD_designInput(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    use_mFlowInput=true,
    h=100e3)
    "Boundary at design input of converter D"
    annotation (Placement(transformation(extent={{-40,-80},{-20,-60}})));
  replaceable Boundaries.BaseClasses.PartialBoundary converterD_designOutlet
    "Boundary at design outlet of converter D"
    annotation (Placement(transformation(extent={{20,-80},{40,-60}})));

equation
  //
  // Connections of converter line A
  //
  connect(converterA_designInput.port, converterA_GenericVLE.port_mediaLibraryA)
    annotation (Line(
      points={{-80,70},{-58,70}},
      color={0,0,0},
      thickness=1));
  connect(converterA_GenericVLE.port_mediaLibraryB, converterA_VLEGas.port_mediaLibraryA)
    annotation (Line(
      points={{-42,70},{-28,70}},
      color={0,140,72},
      thickness=1));
  connect(converterA_VLEGas.port_mediaLibraryB, converterA_GasVLE.port_mediaLibraryB)
    annotation (Line(
      points={{-12,70},{12,70}},
      color={244,125,35},
      thickness=1));
  connect(converterA_GasVLE.port_mediaLibraryA, converterA_VLEGeneric.port_mediaLibraryB)
    annotation (Line(
      points={{28,70},{42,70}},
      color={0,140,72},
      thickness=1));
  connect(converterA_VLEGeneric.port_mediaLibraryA, converterA_designOutput.port)
    annotation (Line(
      points={{58,70},{80,70}},
      color={0,0,0},
      thickness=1));

  //
  // Connections of converter line B
  //
  connect(converterB_designInput.port, converterB_GenericVLE.port_mediaLibraryA)
    annotation (Line(
      points={{-80,30},{-58,30}},
      color={0,0,0},
      thickness=1));
  connect(converterB_GenericVLE.port_mediaLibraryB, converterB_VLELiquid.port_mediaLibraryA)
    annotation (Line(
      points={{-42,30},{-28,30}},
      color={0,140,72},
      thickness=1));
  connect(converterB_VLELiquid.port_mediaLibraryB, converterB_LiquidVLE.port_mediaLibraryB)
    annotation (Line(
      points={{-12,30},{12,30}},
      color={28,108,200},
      thickness=1));
  connect(converterB_LiquidVLE.port_mediaLibraryA, converterB_VLEGeneric.port_mediaLibraryB)
    annotation (Line(
      points={{28,30},{42,30}},
      color={0,140,72},
      thickness=1));
  connect(converterB_VLEGeneric.port_mediaLibraryA, converterB_designOutput.port)
    annotation (Line(
      points={{58,30},{80,30}},
      color={0,0,0},
      thickness=1));

  //
  // Connections of converter line C
  //
  connect(converterC_designInput.port, converterC_GenericGas.port_mediaLibraryA)
    annotation (Line(
      points={{-30,-30},{-8,-30}},
      color={0,0,0},
      thickness=1));
  connect(converterC_GenericGas.port_mediaLibraryB, converterC_designOutlet.port)
    annotation (Line(
      points={{8,-30},{30,-30}},
      color={244,125,35},
      thickness=1));

  //
  // Connections of converter line D
  //
  connect(converterD_designInput.port, converterD_GenericLiquid.port_mediaLibraryA)
    annotation (Line(
      points={{-30,-70},{-8,-70}},
      color={0,0,0},
      thickness=1));
  connect(converterD_GenericLiquid.port_mediaLibraryB, converterD_designOutlet.port)
    annotation (Line(
      points={{8,-70},{30,-70}},
      color={28,108,200},
      thickness=1));

  //
  // Definition of input signals
  //
  connect(input_mVar.y, converterA_designInput.m_flow_input) annotation (Line(
        points={{-89,0},{-86,0},{-86,74},{-81.2,74}}, color={0,0,127}));
  connect(converterB_designInput.m_flow_input, converterA_designInput.m_flow_input)
    annotation (Line(points={{-81.2,34},{-86,34},{-86,74},{-81.2,74}}, color={0,
          0,127}));
  connect(input_mVar.y, converterD_designInput.m_flow_input) annotation (Line(
        points={{-89,0},{-86,0},{-86,-66},{-31.2,-66}}, color={0,0,127}));
  connect(converterC_designInput.m_flow_input, converterD_designInput.m_flow_input)
    annotation (Line(points={{-31.2,-26},{-86,-26},{-86,-66},{-31.2,-66}},
        color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=2500), Documentation(revisions="<html>
<ul>
  <li>
  January 11, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialTestConverter;
