within SorpLib.Components.Connectors.Converter.TILLibrary;
model VLE "Converter between fluid ports: Internal TILMedia VLE port to 
  official TILMedia VLE port"

  //
  // Definition of parameters
  //
  parameter Integer no_components = 1
    "Number of components"
    annotation (Dialog(tab="General", group="Medium"),
                evaluate=true,
                HideResult=true);

  replaceable parameter TILMedia.VLEFluidTypes.TILMedia_Water Medium_internal
    constrainedby TILMedia.VLEFluidTypes.BaseVLEFluid
    "Medium model required for internal port (i.e., TIL VLE medium)"
    annotation (Dialog(tab="General", group="Medium"),
                evaluate=true,
                HideResult=true,
                choicesAllMatching=true);

  replaceable parameter TILMedia.VLEFluidTypes.TILMedia_Water Medium_external=
    sim.vleFluidType1
    constrainedby TILMedia.VLEFluidTypes.BaseVLEFluid
    "Medium model required for internal port (i.e., TIL VLE medium)"
    annotation (Dialog(tab="General", group="Medium"),
                evaluate=true,
                HideResult=true,
                choicesAllMatching=true);

  //
  // Definition of connectors
  //
protected
  outer TIL.SystemInformationManager sim "System information manage"
    annotation (Placement(transformation(extent={{60,20},{80,40}})));

public
  TIL.Connectors.VLEFluidPort externalPort(
    final vleFluidType= Medium_external)
    "Official TILMedia VLE port"
    annotation (Placement(transformation(extent={{70,-10},{90,10}})));
  Components.Connectors.TILMediaLibrary.VLEPort_a internalPort(final
      no_components=no_components, final vleFluidType=Medium_internal)
    "Internal TILMedia VLE port"
    annotation (Placement(transformation(extent={{-90,-10},{-70,10}})));

equation
  //
  // Momentum balance
  //
  0 = externalPort.p - internalPort.p
    "No pressure loss occurs in converter model";

  //
  // Mass balance
  //
  0 = externalPort.m_flow + internalPort.m_flow
    "No storage of mass in converter model";

  externalPort.xi_outflow = inStream(internalPort.xi_outflow)
    "No storage of mass in converter model";
  internalPort.xi_outflow = inStream(externalPort.xi_outflow)
    "No storage of mass in converter model";

  //
  // Energy balance
  //
  externalPort.h_outflow = inStream(internalPort.h_outflow)
    "No storage of energy in converter model";
  internalPort.h_outflow = inStream(externalPort.h_outflow)
    "No storage of energy in converter model";

  externalPort.h_limit = 1e6
    "Limiter not used";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  June 28, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"),
    Diagram(coordinateSystem(extent={{-80,-40},{80,40}})),
    Icon(coordinateSystem(extent={{-80,-40},{80,40}}), graphics={
        Rectangle(
          extent={{-80,40},{80,-40}},
          lineColor={0,0,0},
          fillColor={228,228,228},
          fillPattern=FillPattern.Sphere),
        Line(
          points={{60,0},{-60,0}},
          color={0,0,0},
          arrow={Arrow.Filled,Arrow.Filled},
          thickness=1)}));
end VLE;
