within SorpLib.Components.Connectors.Converter;
model TIL_VLE__TIL_Gas
  "Converter between fluid ports: TIL VLE medium to TIL gas medium"
  extends BaseClasses.PartialConverter(
    redeclare final TILMediaLibrary.VLEPort_a port_mediaLibraryA(
      final no_components=no_components,
      final vleFluidType=Medium_LibraryA),
    redeclare final TILMediaLibrary.GasPort_a port_mediaLibraryB(
      final no_components=no_components,
      final gasType=Medium_LibraryB));

  //
  // Definition of parameters
  //
  replaceable parameter TILMedia.VLEFluidTypes.TILMedia_Water Medium_LibraryA
    constrainedby TILMedia.VLEFluidTypes.BaseVLEFluid
    "Medium model A (i.e., VLE medium)"
    annotation (Dialog(tab="General", group="Medium"),
                evaluate=true,
                HideResult=true,
                choicesAllMatching=true);

  replaceable parameter Media.TILMediaDefinition.Gas.TILMedia_H2O Medium_LibraryB
    constrainedby TILMedia.GasTypes.BaseGas
    "Medium model B (i.e., gas medium)"
    annotation (Dialog(tab="General", group="Medium"),
                evaluate=true,
                HideResult=true,
                choicesAllMatching=true);

  //
  // Definition of media models
  //
  TILMedia.VLEFluid_ph mediumA_ph(
    final vleFluidType=Medium_LibraryA,
    final p=port_mediaLibraryA.p,
    final h=inStream(port_mediaLibraryA.h_outflow),
    final xi=inStream(port_mediaLibraryA.xi_outflow),
    final computeSurfaceTension=false,
    final deactivateDensityDerivatives=true)
    "Thermodynamic state according to instreaming properties at port port_mediaLibraryA"
    annotation (Placement(transformation(extent={{-40,16},{-20,36}})));

  TILMedia.Gas_pT mediumB_pT(
    final gasType=Medium_LibraryB,
    final p=mediumA_ph.p,
    final T=mediumA_ph.T,
    final xi=mediumA_ph.xi)
    "Thermodynamic state according to outstreaming properties at port port_mediaLibraryB"
    annotation (Placement(transformation(extent={{20,16},{40,36}})));

  TILMedia.Gas_ph mediumB_ph(
    final gasType=Medium_LibraryB,
    final p=port_mediaLibraryB.p,
    final h=inStream(port_mediaLibraryB.h_outflow),
    final xi=inStream(port_mediaLibraryB.xi_outflow))
    "Thermodynamic state according to instreaming properties at port port_mediaLibraryB"
    annotation (Placement(transformation(extent={{20,-36},{40,-16}})));

 TILMedia.VLEFluid_pT mediumA_pT(
    final vleFluidType=Medium_LibraryA,
    final p=mediumB_ph.p,
    final T=mediumB_ph.T,
    final xi=mediumB_ph.xi,
    final computeSurfaceTension=false,
    final deactivateDensityDerivatives=true)
    "Thermodynamic state according to outstreaming properties at port port_mediaLibraryA"
    annotation (Placement(transformation(extent={{-40,-36},{-20,-16}})));

equation
  //
  // Energy balance
  //
  port_mediaLibraryA.h_outflow = mediumA_pT.h
    "No change in energy in converter model";
  port_mediaLibraryB.h_outflow = mediumB_pT.h
    "No change in energy in converter model";

  //
  // Annotations
  //
  annotation (Diagram(graphics={Text(
          extent={{-18,28},{18,24}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillPattern=FillPattern.Sphere,
          fillColor={228,228,228},
          textString="Use p and T"), Text(
          extent={{-18,-24},{18,-28}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillPattern=FillPattern.Sphere,
          fillColor={228,228,228},
          textString="Use p and T")}), Documentation(revisions="<html>
<ul>
  <li>
  January 11, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TIL_VLE__TIL_Gas;
