within SorpLib.Components.Connectors.Converter.Tester;
model TestConverter_ModelicaAndTil
  "Base model for testers of converter models: TILMedia<->Modelica.Media"
  extends Modelica.Icons.Example;

  //
  // Definition of converter models
  //
  Modelica_VLE__TIL_VLE converterA_modelica_VLE__TIL_VLE
    "Converts VLE model of Modelica.Media library to VLE model of TILMedia library"
    annotation (Placement(transformation(extent={{-68,36},{-52,44}})));
  Modelica_Gas__TIL_VLE converterA_modelica_Gas__TIL_VLE
    "Converts VLE model of TILMedia library to gas model of Modelica.Media library"
    annotation (Placement(transformation(extent={{-22,36},{-38,44}})));
  Modelica_Gas__TIL_Gas converterA_modelica_Gas__TIL_Gas
    "Converts gas model of Modelica.Media library to VLE model of TILMedia library"
    annotation (Placement(transformation(extent={{22,36},{38,44}})));
  Modelica_VLE__TIL_Gas converterA_modelica_VLE__TIL_Gas
    "Converts VLE model of TILMedia library to VLE model of Modelica.Media library"
    annotation (Placement(transformation(extent={{68,36},{52,44}})));

  Modelica_VLE__TIL_VLE converterB_modelica_VLE__TIL_VLE
    "Converts VLE model of Modelica.Media library to VLE model of TILMedia library"
    annotation (Placement(transformation(extent={{-68,-44},{-52,-36}})));
  Modelica_Liquid__TIL_VLE converterB_modelica_Liquid__TIL_VLE
    "Converts VLE model of TILMedia library to liquid model of Modelica.Media library"
    annotation (Placement(transformation(extent={{-22,-44},{-38,-36}})));
  Modelica_Liquid__TIL_Liquid converterB_modelica_Liquid__TIL_Liquid
    "Converts liquid model of Modelica.Media library to VLE model of TILMedia library"
    annotation (Placement(transformation(extent={{22,-44},{38,-36}})));
  Modelica_VLE__TIL_Liquid converterB_modelica_VLE__TIL_Liquid
    "Converts VLE model of TILMedia library to VLE model of Modelica.Media library"
    annotation (Placement(transformation(extent={{68,-44},{52,-36}})));

  //
  // Definition of boundaries
  //
  Modelica.Blocks.Sources.Ramp input_mVar(
    height=2,
    duration=2500,
    offset=-1,
    startTime=0)
    "Ramp to simulate input signal of mass flow"
    annotation (Placement(transformation(extent={{-110,-10},{-90,10}})),
                HideResult=true);

  Boundaries.ModelicaMediaLibrary.VLEBoundary converterA_designInput(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    use_mFlowInput=true,
    h=2750e3) "Boundary at design input of converter A"
    annotation (Placement(transformation(extent={{-90,30},{-70,50}})));
  Boundaries.ModelicaMediaLibrary.VLEBoundary converterB_designInput(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    use_mFlowInput=true,
    h=2750e3) "Boundary at design input of converter B"
    annotation (Placement(transformation(extent={{-90,-50},{-70,-30}})));
  Boundaries.ModelicaMediaLibrary.VLEBoundary converterA_designoutlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    h=2750e3) "Boundary at design outlet of converter A"
    annotation (Placement(transformation(extent={{70,30},{90,50}})));
  Boundaries.ModelicaMediaLibrary.VLEBoundary converterB_designoutlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    h=2750e3) "Boundary at design outlet of converter B"
    annotation (Placement(transformation(extent={{70,-50},{90,-30}})));

equation
  //
  // Connections of converter line A
  //
  connect(converterA_designInput.port, converterA_modelica_VLE__TIL_VLE.port_mediaLibraryA)
    annotation (Line(
      points={{-80,40},{-68,40}},
      color={0,140,72},
      thickness=1));
  connect(converterA_modelica_VLE__TIL_VLE.port_mediaLibraryB,
    converterA_modelica_Gas__TIL_VLE.port_mediaLibraryB) annotation (Line(
      points={{-52,40},{-38,40}},
      color={0,140,72},
      thickness=1));
  connect(converterA_modelica_Gas__TIL_VLE.port_mediaLibraryA,
    converterA_modelica_Gas__TIL_Gas.port_mediaLibraryA) annotation (Line(
      points={{-22,40},{22,40}},
      color={244,125,35},
      thickness=1));
  connect(converterA_modelica_Gas__TIL_Gas.port_mediaLibraryB,
    converterA_modelica_VLE__TIL_Gas.port_mediaLibraryB) annotation (Line(
      points={{38,40},{52,40}},
      color={244,125,35},
      thickness=1));
  connect(converterA_modelica_VLE__TIL_Gas.port_mediaLibraryA,
    converterA_designoutlet.port) annotation (Line(
      points={{68,40},{80,40}},
      color={0,140,72},
      thickness=1));

  //
  // Connections of converter line B
  //
  connect(converterB_designInput.port, converterB_modelica_VLE__TIL_VLE.port_mediaLibraryA)
    annotation (Line(
      points={{-80,-40},{-68,-40}},
      color={0,140,72},
      thickness=1));
  connect(converterB_modelica_VLE__TIL_VLE.port_mediaLibraryB,
    converterB_modelica_Liquid__TIL_VLE.port_mediaLibraryB) annotation (Line(
      points={{-52,-40},{-38,-40}},
      color={0,140,72},
      thickness=1));
  connect(converterB_modelica_Liquid__TIL_VLE.port_mediaLibraryA,
    converterB_modelica_Liquid__TIL_Liquid.port_mediaLibraryA) annotation (Line(
      points={{-22,-40},{22,-40}},
      color={28,108,200},
      thickness=1));
  connect(converterB_modelica_Liquid__TIL_Liquid.port_mediaLibraryB,
    converterB_modelica_VLE__TIL_Liquid.port_mediaLibraryB) annotation (Line(
      points={{38,-40},{52,-40}},
      color={28,108,200},
      thickness=1));
  connect(converterB_modelica_VLE__TIL_Liquid.port_mediaLibraryA,
    converterB_designoutlet.port) annotation (Line(
      points={{68,-40},{80,-40}},
      color={0,140,72},
      thickness=1));

  //
  // Connections of input signals
  //
  connect(input_mVar.y, converterA_designInput.m_flow_input) annotation (Line(
        points={{-89,0},{-84,0},{-84,44},{-81.2,44}}, color={0,0,127}));
  connect(input_mVar.y, converterB_designInput.m_flow_input) annotation (Line(
        points={{-89,0},{-84,0},{-84,-36},{-81.2,-36}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=2500), Documentation(revisions="<html>
<ul>
  <li>
  January 11, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestConverter_ModelicaAndTil;
