within SorpLib.Components.Controller.PhaseTimeController.AdsorptionChiller;
model TwoBedAdsorptionChiller_CycleCount
  "Phase time controller for two-bed adsorption chiller"

  //
  // Definition of parameters
  //
  parameter Modelica.SIunits.Temperature T_low = 273.15 + 10
    "Fixed value for low temperature"
    annotation (Dialog(tab="General", group="Settings"));
  parameter Modelica.SIunits.Temperature T_med = 273.15 + 30
    "Fixed value for medium temperature"
    annotation (Dialog(tab="General", group="Settings"));
  parameter Modelica.SIunits.Temperature T_hot = 273.15 + 90
    "Fixed value for hot temperature"
    annotation (Dialog(tab="General", group="Settings"));

  parameter Modelica.SIunits.Time t_firstHalfe = 500
    "Cycle time of first half cycle"
    annotation (Dialog(tab="General", group="Control"));
  parameter Modelica.SIunits.Time t_secondHalfe = 500
    "Cycle time of second half cycle"
    annotation (Dialog(tab="General", group="Control"));
  final parameter Modelica.SIunits.Time t_cycle = t_firstHalfe+t_secondHalfe
    "Cycle time"
    annotation (Dialog(tab="General", group="Control"));

  //
  // Definition of variables
  //
  Integer phase(start=0, fixed=true)
    "Integer indicating phase: 0->first halfe | 1->second halfe";
  Integer cou(start=0, fixed=true)
    "Integer indicating cycle number";

  //
  // Definition of outputs
  //
  output Modelica.SIunits.Temperature T_input_ads1
    "Input temperature of adsorber 1"
    annotation(Dialog(tab="General",group="Outputs",enable=false));
  output Modelica.SIunits.Temperature T_input_ads2
    "Input temperature of adsorber 2"
    annotation(Dialog(tab="General",group="Outputs",enable=false));
  output Integer cycle(start=0, fixed=true)
    "Actual cycle"
    annotation(Dialog(tab="General",group="Outputs",enable=false));

algorithm
  //
  // Identify current phase and cycle
  //
  when time > cou*t_cycle then
    phase := 0
      "First half cycle";
    cycle := if cou >= 1 then cycle+1 else cycle
      "Increase cycle number";
  end when;

  when time > cou*t_cycle + t_firstHalfe then
    phase := 1
      "Second half cycle";
    cou := cou+1
      "Increase cycle number";
  end when;

equation
  //
  // Define outputs depending on phase
  //
  if phase==0 then
    //
    // First half cycle
    //
    T_input_ads1 = T_med;
    T_input_ads2 = T_hot;

  else
    //
    // Second half cycle
    //
    T_input_ads1 = T_hot;
    T_input_ads2 = T_med;

  end if;

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
      Rectangle(
        origin={0.0,35.1488},
        fillColor={255,255,255},
        extent={{-30.0,-20.1488},{30.0,20.1488}}),
      Rectangle(
        origin={0.0,-34.8512},
        fillColor={255,255,255},
        extent={{-30.0,-20.1488},{30.0,20.1488}}),
      Line(
        origin={-51.25,0.0},
        points={{21.25,-35.0},{-13.75,-35.0},{-13.75,35.0},{6.25,35.0}}),
      Polygon(
        origin={-40.0,35.0},
        pattern=LinePattern.None,
        fillPattern=FillPattern.Solid,
        points={{10.0,0.0},{-5.0,5.0},{-5.0,-5.0}}),
      Line(
        origin={51.25,0.0},
        points={{-21.25,35.0},{13.75,35.0},{13.75,-35.0},{-6.25,-35.0}}),
      Polygon(
        origin={40.0,-35.0},
        pattern=LinePattern.None,
        fillPattern=FillPattern.Solid,
        points={{-10.0,0.0},{5.0,5.0},{5.0,-5.0}})}), Diagram(coordinateSystem(
          preserveAspectRatio=false)),
    Documentation(revisions="<html>
<ul>
  <li>
  January 20, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TwoBedAdsorptionChiller_CycleCount;
