within SorpLib.Components.Fittings.HydraulicResistors.BaseClasses;
partial model PartialHydraulicResistorLiquidTubes
  "Base model of all hydraulic resistors for liquid tubes"
  extends PartialHydraulicResistor(
    redeclare final model PressureDropModel = PressureDropModelLiquid);

  //
  // Definition of parameters describing the pressure drop model
  //
  parameter Integer no_cells(min=1)=2
    "Discretization number of cells"
    annotation (Dialog(tab="General", group="Pressure Drop Correlation"),
                Evaluate=true,
                HideResult=true);

  replaceable model PressureDropModelLiquid =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes(
    final cellGeometry=cellGeometry,
    final fluidProperties=actualFluidProperties,
    final m_flow=abs(port_a.m_flow),
    final no_cells=no_cells)
    "Pressure drop model"
    annotation (Dialog(tab="General", group="Pressure Drop Correlation"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropModelLiquid =
          TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
                          "Liquid heat exchanger | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropModelLiquid =
          TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ConstantZeta
                          "Liquid heat exchanger | Constant resistance for each cell (i.e., zeta)"),
                        choice(redeclare model PressureDropModelLiquid =
          TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
                          "Liquid heat exchanger | Konakov correlation")));

  //
  // Definition of inputs
  //
input
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.Geometry.LiquidTubes
    cellGeometry "Record containing geometric data of liquid heat exchanger"
    annotation (Dialog(tab="General", group="Inputs"));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialHydraulicResistorLiquidTubes;
