within SorpLib.Components.Fittings.HydraulicResistors.BaseClasses;
partial model PartialHydraulicResistorOpenAdsorbers
  "Base model of all hydraulic resistors for open adsorbers"
  extends PartialHydraulicResistor(
    redeclare final model PressureDropModel = PressureDropOpenAdsorber);

  //
  // Definition of parameters describing the pressure drop model
  //
  replaceable model PressureDropOpenAdsorber =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.OpenAdsorber.ZeroPressureDrop
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropOpenAdsorbers(
    final cellGeometry=cellGeometry,
    final fluidProperties=actualFluidProperties,
    final m_flow=abs(port_a.m_flow))
    "Pressure drop model"
    annotation (Dialog(tab="General", group="Pressure Drop Correlation"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropOpenAdsorber =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.OpenAdsorber.ZeroPressureDrop
                          "Open adsorber | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropOpenAdsorber =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.OpenAdsorber.PackedBed_Kast1988
                          "Open adsorber | Packed bed according to Kast")));

  //
  // Definition of inputs
  //
  input
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.Geometry.OpenAdsorbers
    cellGeometry "Record containing geometric data of open adsorber"
    annotation (Dialog(tab="General", group="Inputs"));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialHydraulicResistorOpenAdsorbers;
