within SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.Geometry;
record LiquidTubes "Record containing all relevant geometric properties to calculate pressure
  losses and heat transfer coefficients of a liquid tube (e.g., heat exchanger)"
  extends Internals.ClassTypes.Record;

  parameter Modelica.SIunits.Length roughness = 7.5e-7
    "Roughness of heat exchanger tube";

  parameter Modelica.SIunits.Diameter d_inner = 0.01
    "Inner diameter of circular tube";

  parameter Modelica.SIunits.Length length = 1
    "Total length of circular tube";
  parameter Modelica.SIunits.Length length_heatTransfer = length
    "Length of circular tube available for heat transfer on liquid-side and 
     for wall N-S direction";

  parameter Modelica.SIunits.Area innerCrossSectionalArea=
    Modelica.Constants.pi/4 * d_inner^2
    "Inner cross sectional area (e.g., used for pressure drop calculation)";
  parameter Modelica.SIunits.Area innerHeatTransferArea=
    Modelica.Constants.pi * d_inner * length_heatTransfer
    "Inner heat transfer area";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end LiquidTubes;
