within SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube;
model ConstantZeta
  "Liquid heat exchanger | Constant resistance (i.e., zeta)"
  extends
    Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes(
      final calc_propertyRecord = true);

  //
  // Definition of parameters
  //
  parameter Real zeta(unit="1") = 1
    "Constant zeta"
    annotation (Dialog(tab="General", group="Pressure Drop Correlation"));

equation
  //
  // Calculation of pressure drop
  //
  pressureDrop = zeta/(2*no_cells*fluidProperties.rho*cellGeometry.innerCrossSectionalArea
    ^2)*SorpLib.Internals.Numerics.squareFunction_noEvent(m_flow, 1e-4)
    "Correct zeta according to number of cells";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end ConstantZeta;
