within SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube;
model Konakov "Liquid heat exchanger | Konakov correlation"
  extends
    Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes(
      final calc_propertyRecord = true);

  //
  // Definition of variables
  //
  Modelica.SIunits.Velocity v
    "Velocity";
  Modelica.SIunits.ReynoldsNumber Re
    "Reynolds-Number";
  Real lambda
    "Pipe friction number";

protected
  Real weightingFactor=
    SorpLib.Internals.Numerics.smoothTransition_noEvent(  Re, 2300, 100)
    "Transition factor for change between laminar and turbulent zone";

equation
  //
  // Calculation of characteristic numbers
  //
  v = m_flow / (fluidProperties.rho * cellGeometry.innerCrossSectionalArea)
    "Velocity of fluid";

  Re = abs(v) * cellGeometry.d_inner / fluidProperties.eta * fluidProperties.rho
    "Reynolds number of fluid";

  lambda = weightingFactor * 64 / max(Re,1e-12) +
    (1-weightingFactor) / (1.8 * Modelica.Math.log10(max(Re,1e-12)) - 1.5)^2
    "Friction number of pipe";

  //
  // Calculation of pressure drop
  //
  pressureDrop = lambda/cellGeometry.d_inner*cellGeometry.length*
    fluidProperties.rho/2*SorpLib.Internals.Numerics.squareFunction_noEvent(v,
    0.001) "Pressure drop according to Konakov correlation";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end Konakov;
