within SorpLib.Components.Fittings.SplitterJunctions.BaseClasses;
partial model PartialSplitterJunction "Spliter and junction model"

  //
  // Definition of parameters
  //
  parameter Integer no_ports_b = 2
    "Number of ports (i.e., port_b)"
    annotation (Dialog(tab="General", group="Port Setup"),
                Evaluate=true,
                HideResult=true);

  parameter Integer no_components = 1
    "Number of components"
    annotation (Dialog(tab="General", group="Medium Model"),
                evaluate=true,
                HideResult=true);

  //
  // Definition of constants
  //
protected
  constant Internals.Types.MediaModel type_Media=
    Internals.Types.MediaModel.Modelica_VLE
    "Type required to check consistency of media models"
    annotation (HideResult=true);

  //
  // Connectors
  //
public
  replaceable Connectors.BaseClasses.PartialMediaConnector port_a(
    final  no_components=no_components) "Single port"
    annotation (Placement(transformation(extent={{50,-10},{70,10}})));
  replaceable Connectors.BaseClasses.PartialMediaConnector[no_ports_b] port_b(
    each final no_components=no_components) "Multiple ports"
    annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));

equation
  //
  // Momentum balance
  //
  port_b.p = port_a.p * ones(no_ports_b)
    "Conservation of pressure";

  //
  // Mass balance
  //
  0 = port_a.m_flow + sum(port_b.m_flow)
    "Mass balance";

  //
  // Energy balance
  //
  port_b.h_outflow = inStream(port_a.h_outflow) * ones(no_ports_b)
    "Trivial equation: Flow direction A->B";

  port_a.h_outflow = sum({max(abs(port_b[i].m_flow),1e-10) *
    inStream(port_b[i].h_outflow) for i in 1:no_ports_b}) /
    sum({max(abs(port_b[i].m_flow),1e-10) for i in 1:no_ports_b})
    "Calculating mixing enthalpy: Flow direction B->A";

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-60,
            -100},{60,100}}),                                   graphics={
        Rectangle(
          extent={{-60,100},{60,-100}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid),
        Line(
          points={{-40,80},{-20,80}},
          color={0,0,0},
          thickness=0.5),
        Line(
          points={{-40,40},{-20,40}},
          color={0,0,0},
          thickness=0.5),
        Line(
          points={{-40,0},{-20,0}},
          color={0,0,0},
          thickness=0.5),
        Line(
          points={{-40,-80},{-20,-80}},
          color={0,0,0},
          thickness=0.5),
        Line(
          points={{-20,80},{20,0},{-20,-80}},
          color={0,0,0},
          thickness=0.5),
        Line(
          points={{20,0},{40,0}},
          color={0,0,0},
          thickness=0.5),
        Line(
          points={{-40,-40},{-20,-40}},
          color={0,0,0},
          thickness=0.5)}), Diagram(
        coordinateSystem(preserveAspectRatio=false, extent={{-60,-100},{60,100}})),
    Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialSplitterJunction;
