within SorpLib.Components.Fittings.SplitterJunctions.ModelicaMediaLibrary.Tester;
model TestVLESplitterJunction
  "Model to test splitter and junction model for VLE fluids"
  extends Modelica.Icons.Example;

  //
  // Definition of system information manager
  //

  //
  // Definition of models
  //
  VLESplitterJunction vLESplitterJunction_AB(no_ports_b=5)
    "Splitter and junction model for flow direction A->B"
    annotation (Placement(transformation(extent={{6,40},{-6,60}})));
  VLESplitterJunction vLESplitterJunction_BA(no_ports_b=5)
    "Splitter and junction mode for flow direction B->A"
    annotation (Placement(transformation(extent={{-6,-20},{6,-40}})));

  //
  // Definition of boundaries
  //
protected
  Boundaries.ModelicaMediaLibrary.VLEBoundary
                            vLeBoundary_AB_A(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    p=100000)
    "Boundar A for flow direction A->B"
    annotation (Placement(transformation(extent={{-50,40},{-30,60}})));
  Boundaries.ModelicaMediaLibrary.VLEBoundary
                            vLeBoundary_AB_B[5](
    each boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    each boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
      each m_flow=0.001) "Boundar B for flow direction A->B"
    annotation (Placement(transformation(extent={{50,40},{30,60}})));

  Boundaries.ModelicaMediaLibrary.VLEBoundary
                            vLeBoundary_BA_B(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    p=100000)
    "Boundar B for flow direction B->A"
    annotation (Placement(transformation(extent={{30,-40},{50,-20}})));
  Boundaries.ModelicaMediaLibrary.VLEBoundary
                            vLeBoundary_BA_A[5](
    each boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    each boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    each m_flow=-0.001,
    h={100e3,200e3,300e3,400e3,500e3}) "Boundar A for flow direction B->A"
    annotation (Placement(transformation(extent={{-50,-40},{-30,-20}})));

equation
  //
  // Connections
  //
  connect(vLeBoundary_AB_B.port, vLESplitterJunction_AB.port_b) annotation (
      Line(
      points={{40,50},{6,50}},
      color={0,140,72},
      thickness=1));
  connect(vLESplitterJunction_AB.port_a, vLeBoundary_AB_A.port) annotation (
      Line(
      points={{-6,50},{-40,50}},
      color={0,140,72},
      thickness=1));
  connect(vLeBoundary_BA_A.port, vLESplitterJunction_BA.port_b) annotation (
      Line(
      points={{-40,-30},{-6,-30}},
      color={0,140,72},
      thickness=1));
  connect(vLeBoundary_BA_B.port, vLESplitterJunction_BA.port_a) annotation (
      Line(
      points={{40,-30},{6,-30}},
      color={0,140,72},
      thickness=1));

  //
  // Annotations
  //
  annotation (experiment(StopTime=500), Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestVLESplitterJunction;
