within SorpLib.Components.HeatExchangers.BaseClasses;
partial model PartialHeatExchanger "Base model for all heat exchanger models"

  //
  // Definition of parameters describing the medium
  //
  parameter Integer no_components = 1
    "Number of components in the heat transfer fluid (i.e., secondary side)"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);

  //
  // Definition of parameters describing the initialisation
  //
  parameter Modelica.SIunits.Pressure pInitial= 1e5
    "Initial value for pressure"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.MassFraction[no_components-1] xiInitial=
    fill(1/no_components, no_components-1)
    "Initial values for independent mass fractions"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.MassFlowRate m_flowInitial = 1e-4
    "Start value for mass flow rate"
    annotation (Dialog(tab="Initialisation", group="Start Values"),
                HideResult = true);

  //
  // Definition of parameters describing advanced options
  //
  parameter Internals.Types.BalanceEquations type_overallMassBalance=
    Internals.Types.BalanceEquations.Transient_FixedInitial
    "Handling of the overall mass equation and corresponding initialisation"
    annotation(Dialog(tab = "Advanced", group = "Conservation Equations"),
                Evaluate=true,
                HideResult = true);
  parameter Internals.Types.BalanceEquations type_independentMassBalances=
    Internals.Types.BalanceEquations.SteadyState_FreeInitial
    "Handling of the independent mass equations and corresponding initialisations"
    annotation(Dialog(tab = "Advanced", group = "Conservation Equations"),
                Evaluate=true,
                HideResult = true);
  parameter Internals.Types.BalanceEquations type_energyBalance=
    Internals.Types.BalanceEquations.Transient_FixedInitial
    "Handling of the energy equation and corresponding initialisation"
    annotation(Dialog(tab = "Advanced", group = "Conservation Equations"),
                Evaluate=true,
                HideResult = true);

  parameter Boolean avoid_events = true
    "= true, if events are avoid by using noEvent()-operator"
    annotation (Dialog(tab = "Advanced", group = "Numerics"),
                Evaluate=true,
                HideResult = true);

  //
  // Definition of constants
  //
protected
  constant Internals.Types.MediaModel type_Media=
    Internals.Types.MediaModel.Modelica_VLE
    "Type required to check consistency of media models"
    annotation (HideResult=true);

  //
  // Definition of connectors
  //
public
  replaceable Connectors.BaseClasses.PartialMediaConnector port_a(
    final no_components=no_components,
    m_flow(start = m_flowInitial))
    "Inlet fluid port at design direction"
    annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));
  replaceable Connectors.BaseClasses.PartialMediaConnector port_b(
    final no_components=no_components,
    m_flow(start = -m_flowInitial))
    "Outlet fluid port at design direction"
    annotation (Placement(transformation(extent={{88,-10},{108,10}})));

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-40},
            {100,40}})), Diagram(coordinateSystem(preserveAspectRatio=false,
          extent={{-100,-40},{100,40}})),
    Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialHeatExchanger;
