within SorpLib.Components.HeatExchangers.EvaporatorCondenser.BaseClasses;
partial model PartialEvaporatorCondenser
  "Partial model for all condenser or evaporator models"
  extends SorpLib.Components.HeatExchangers.BaseClasses.PartialHeatExchanger(
      final pInitial=pInitial_liquidCell_1);

  //
  // Definition of general parameters
  //
  parameter Integer nPorts_Vapor = 0
    "Number of vapor ports"
    annotation (Dialog(connectorSizing=true),
                HideResult = true);
  parameter Integer nPorts_Liquid = 0
    "Number of liquid ports"
    annotation (Dialog(connectorSizing=true),
                HideResult = true);

  parameter Integer no_cells_liquid(min=2)=2
    "Discretization number of liquid cells"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);
  parameter Integer no_cells_wall(min=1)=no_cells_liquid
    "Discretization number of wall cells (must be a facotr of no_cells_liquid)"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);

  replaceable parameter HeatExchangers.Geometry.EvaporatorCondenser
    heatExchangerGeometry constrainedby
    HeatExchangers.Geometry.EvaporatorCondenser
    "Geometry of evaporator or condenser"
    annotation (Dialog(tab="General", group="Geometry"),
                choicesAllMatching = true);

  parameter Boolean use_casing = false
    " = true, to enable casing; otherwise, no casing is used"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                Evaluate=true,
                HideResult = true);

  parameter Internals.Types.BalancingWallElement balancingWallElement=
   Internals.Types.BalancingWallElement.NS
   "Balancing method for wall cell"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_VLESide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer calculation between wall cells and
    phase seperator"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
               choices(choice(redeclare model HeatTransfer_VLESide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_VLESide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  replaceable model HeatTransferModel_TubeSide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialExternalHeatTransferCoefficientLiquidTube
    "Heat transfer model for heat transfer coefficient betwenn liquid and wall
     cells"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlpha
                          "Liquid heat exchanger | Constant alpha for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
                          "Liquid heat exchanger | Constant alphaA for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate
                          "Liquid heat exchanger | Sieder-Tate correlation"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.Schmidt
                          "Liquid heat exchanger | Schmidt-Korrelation")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_NS =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
    "Heat transfer model for north-south direction of wall"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_WE =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
     "Heat transder model for west-east direction of wall"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransfer_Casing =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer
    "Heat transfer model for heat transfer calculation between casing and
    phase seperator"
    annotation (Dialog(tab = "General", group = "Heat Transfer",
               enable = use_casing),
               choices(choice(redeclare model HeatTransfer_Casing =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlpha
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"),
                       choice(redeclare model HeatTransfer_Casing =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
                         "Heat transfer | Heat transfer model with constant heat transfer coefficient alphaA")),
                Evaluate=true,
                HideResulte=true);

  replaceable model PressureDropModel =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes
    "Pressure drop model"
    annotation (Dialog(tab="General", group="Pressure Drop"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
                          "Liquid heat exchanger | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ConstantZeta
                          "Liquid heat exchanger | Constant resistance for each cell (i.e., zeta)"),
                        choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
                          "Liquid heat exchanger | Konakov correlation")));

  //
  // Definition of parameters describing the medium
  //
  parameter Integer no_components_phaseSeperator = 1
    "Number of components in the phase seperator (i.e., primary side)"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);

  //
  // Definition of parameters describing the initialisation
  //
  parameter Modelica.SIunits.Pressure pInitial_liquidCell_1=1e5+25000
    "Initial value for liquid pressure of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Pressure pInitial_liquidCell_N=1e5
    "Initial value for liquid pressure of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_liquidCell_1=283.15
    "Initial value for liquid temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_liquidCell_N=303.15
    "Initial value for liquid temperature of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_wallCell_1 = 293.15
    "Initial value for wall temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_wallCell_N = 313.15
    "Initial value for wall temperature of cell N"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_casing = 313.15
    "Initial value for casing temperature"
    annotation (Dialog(tab="Initialisation", group="Initial Values",
                enable = use_casing),
                HideResult = true);

  //
  // Definition of models
  //
  replaceable Liquid.BaseClasses.PartialLiquidHeatExchanger heatExchangerTubes(
    final no_components=no_components,
    final xiInitial=xiInitial,
    final m_flowInitial=m_flowInitial,
    final type_overallMassBalance=type_overallMassBalance,
    final type_energyBalance=type_energyBalance,
    final avoid_events=avoid_events,
    final no_cells_liquid=no_cells_liquid,
    final no_cells_wall=no_cells_wall,
    final heatExchangerGeometry(
      roughness=heatExchangerGeometry.roughness,
      d_inner=heatExchangerGeometry.d_inner,
      d_outer=heatExchangerGeometry.d_outer,
      wallThickness=heatExchangerGeometry.wallThickness,
      length=heatExchangerGeometry.length,
      length_heatTransfer=heatExchangerGeometry.length_heatTransfer,
      innerCrossSectionalArea=heatExchangerGeometry.innerCrossSectionalArea,
      outerCrossSectionalArea=heatExchangerGeometry.outerCrossSectionalArea,
      wallCrossSectionalArea=heatExchangerGeometry.wallCrossSectionalArea,
      innerVolume=heatExchangerGeometry.innerVolume,
      outerVolume=heatExchangerGeometry.outerVolume,
      wallVolume=heatExchangerGeometry.wallVolume,
      innerHeatTransferArea=heatExchangerGeometry.innerHeatTransferArea,
      outerHeatTransferArea=heatExchangerGeometry.outerHeatTransferArea,
      nParallelTubes=heatExchangerGeometry.nParallelTubes),
    final balancingWallElement=balancingWallElement,
    redeclare final model HeatTransferModel_TubeSide =
        HeatTransferModel_TubeSide,
    redeclare final model HeatTransferModel_NS = HeatTransferModel_NS,
    redeclare final model HeatTransferModel_WE = HeatTransferModel_WE,
    redeclare final model PressureDropModel = PressureDropModel,
    final pInitial_liquidCell_1=pInitial_liquidCell_1,
    final pInitial_liquidCell_N=pInitial_liquidCell_N,
    final TInitial_liquidCell_1=TInitial_liquidCell_1,
    final TInitial_liquidCell_N=TInitial_liquidCell_N,
    final TInitial_wallCell_1=TInitial_wallCell_1,
    final TInitial_wallCell_N=TInitial_wallCell_N)
    "Model of heat exchanger tubes (i.e., liquid and wall)"
    annotation (Placement(transformation(extent={{30,-24},{50,-16}})));

  HeatTransfers.HeatTransfer heatTransfer_TubePhaseSeperator(
    final n_A= no_cells_wall,
    final n_B=1,
    redeclare final model HeatTransfer = HeatTransfer_VLESide)
    "Heat transfer model between heat exchanger tubes and phase seperator"
    annotation (Placement(transformation(
        extent={{-10,-4},{10,4}},
        rotation=90,
        origin={40,0})));

  HeatTransfers.HeatTransfer heatTransfer_CasingPhaseSeperator(
    final n_A=1,
    final n_B=1,
    redeclare final model HeatTransfer = HeatTransfer_Casing) if use_casing
    "Heat transfer model between casing and phase seperator" annotation (
      Placement(transformation(
        extent={{-10,-4},{10,4}},
        rotation=180,
        origin={50,20})));

  replaceable PhaseSeperators.BaseClasses.PartialPhaseSeperator phaseSeperator(
    final V=heatExchangerGeometry.refrigerantVolume,
    final A=heatExchangerGeometry.refrigerantArea,
    final no_components=no_components_phaseSeperator,
    final m_flowInitial=m_flowInitial,
    final avoid_events=avoid_events,
    nPorts_Liquid=nPorts_Liquid,
    nPorts_Vapor=nPorts_Vapor)
    "Phase seperator model"
    annotation (Placement(transformation(extent={{-10,0},{10,20}})));

  replaceable Cells.BaseClasses.PartialWallCell casing(
    final cellGeometry(final volume=heatExchangerGeometry.casingVolume),
    final balancingWallElement=SorpLib.Internals.Types.BalancingWallElement.NoResistances,
    redeclare final model HeatTransferModel_NS =
        HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR,
    redeclare final model HeatTransferModel_WE =
        HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR,
    final TInitial=TInitial_casing,
    final type_energyBalance=SorpLib.Internals.Types.BalanceEquations.Transient_FixedInitial) if
       use_casing "Casing of evaporator or condenser" annotation (Placement(
        transformation(
        extent={{-6,-6},{6,6}},
        rotation=270,
        origin={70,20})));

  //
  // Definition of connectors
  //
  replaceable Connectors.BaseClasses.PartialMediaConnector[nPorts_Liquid] liquidPort(
    each no_components=no_components_phaseSeperator,
    each m_flow(start = m_flowInitial))
    "Liquid VLE port"
    annotation (Placement(transformation(extent={{-10,-50},{10,-30}})));
  replaceable Connectors.BaseClasses.PartialMediaConnector[nPorts_Vapor] vaporPort(
    each no_components=no_components_phaseSeperator,
    each m_flow(start = -m_flowInitial))
    "Vapor VLE port"
    annotation (Placement(transformation(extent={{-10,30},{10,50}})));
  Connectors.Thermal.Port_a heatPort if use_casing
    "Heat port at outside of casing"
    annotation (Placement(transformation(extent={{80,30},{100,50}})));

equation
  //
  // Assertions
  //
  if no_cells_wall < no_cells_liquid then
    assert(rem(no_cells_liquid, no_cells_wall) == 0,
      "Number of wall cells must be factor of number of liquid cells!");

  elseif no_cells_wall > no_cells_liquid then
    assert(rem(no_cells_wall, no_cells_liquid) == 0,
      "Number of wall cells must be factor of number of liquid cells!");

  end if;

  //
  // Connection of fluid ports
  //
  connect(port_a, heatExchangerTubes.port_a) annotation (Line(points={{-100,0},{
          -80,0},{-80,-20},{30,-20}}, color={28,108,200},
      thickness=1));
  connect(heatExchangerTubes.port_b, port_b) annotation (Line(points={{49.8,-20},
          {80,-20},{80,0},{98,0}}, color={28,108,200},
      thickness=1));
  connect(liquidPort, phaseSeperator.liquidPort)
    annotation (Line(points={{0,-40},{0,1}}, color={0,140,72},
      thickness=1));
  connect(phaseSeperator.vaporPort, vaporPort)
    annotation (Line(points={{0,18.8},{0,40}}, color={0,140,72},
      thickness=1));

  //
  // Connection of heat ports
  //
  connect(heatExchangerTubes.heatPort, heatTransfer_TubePhaseSeperator.heatPort_a)
    annotation (Line(
      points={{40,-16},{40,-10}},
      color={238,46,47},
      thickness=1));
  connect(heatTransfer_TubePhaseSeperator.heatPort_b[1], phaseSeperator.heatPort)
    annotation (Line(
      points={{40,10},{6,10}},
      color={238,46,47},
      thickness=1));
  connect(casing.heatPort_N, heatPort) annotation (Line(
      points={{76,20},{90,20},{90,40}},
      color={238,46,47},
      thickness=1));
  connect(phaseSeperator.heatPort, heatTransfer_CasingPhaseSeperator.heatPort_b[
    1]) annotation (Line(
      points={{6,10},{40,10},{40,20}},
      color={238,46,47},
      thickness=1));
  connect(heatTransfer_CasingPhaseSeperator.heatPort_a[1], casing.heatPort_S)
    annotation (Line(
      points={{60,20},{64,20}},
      color={238,46,47},
      thickness=1));

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-40},
            {100,40}}),                                         graphics={
        Text(
          extent={{-60,30},{-40,10}},
          lineColor={0,0,0},
          lineThickness=1,
          fillColor={255,255,255},
          fillPattern=FillPattern.None,
          fontSize=20,
          textString="1"),
        Text(
          extent={{40,30},{60,10}},
          lineColor={0,0,0},
          lineThickness=1,
          fillColor={255,255,255},
          fillPattern=FillPattern.None,
          fontSize=20,
          textString="n"),
        Line(
          points={{0,40},{0,22},{-2,14},{2,0},{-2,-14},{2,-24},{0,-40}},
          color={0,0,0},
          smooth=Smooth.Bezier),
        Rectangle(
          extent={{-100,-2},{100,-40}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Polygon(
          points={{-100,-10},{-80,8},{-54,-2},{-36,0},{-6,6},{14,-2},{42,4},{74,
              4},{94,-6},{-100,-10}},
          lineColor={28,108,200},
          lineThickness=0.5,
          smooth=Smooth.Bezier,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Rectangle(
          extent={{-100,40},{100,-40}},
          lineColor={0,0,0},
          lineThickness=1),
        Polygon(
          points={{-20,4},{-20,4},{-32,18},{-8,18},{-20,4}},
          lineColor={0,0,0},
          lineThickness=0.5),
        Ellipse(
          extent={{-66,38},{-78,26}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-28,38},{-40,26}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-12,38},{-24,26}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{16,22},{4,10}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{28,38},{16,26}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{36,22},{24,10}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-58,24},{-70,12}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{74,38},{62,26}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{48,38},{36,26}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{86,24},{74,12}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-84,34},{-96,22}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid)}),                      Diagram(
        coordinateSystem(preserveAspectRatio=false, extent={{-100,-40},{100,40}})),
    Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation, including major revisions, after restructuring of the library.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialEvaporatorCondenser;
