within SorpLib.Components.HeatExchangers.EvaporatorCondenser.ModelicaMediaLibrary;
model EvaporatorCondenser "Evaporator or condenser model"
  extends BaseClasses.PartialEvaporatorCondenser(
    no_components = 1,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final type_independentMassBalances=
      Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final type_Media=Internals.Types.MediaModel.Modelica_VLE,
    redeclare Connectors.ModelicaMediaLibrary.LiquidPort_a port_a(
        redeclare each final package Medium = Liquid_Medium),
    redeclare Connectors.ModelicaMediaLibrary.LiquidPort_b port_b(
        redeclare each final package Medium = Liquid_Medium),
    redeclare Connectors.ModelicaMediaLibrary.VLEPort_a liquidPort(
      redeclare each final package Medium = VLE_Medium,
      each final no_components=1),
    redeclare Connectors.ModelicaMediaLibrary.VLEPort_a vaporPort(
      redeclare each final package Medium = VLE_Medium,
      each final no_components=1),
    redeclare PhaseSeperators.ModelicaMediaLibrary.SinglePhaseSeperator
      phaseSeperator(
      final TInitial=TInitial_VLE,
      final rhoInitial=rhoInitial_VLE,
      redeclare each final package Medium = VLE_Medium),
    redeclare Liquid.ModelicaMediaLibrary.LiquidHeatExchanger
      heatExchangerTubes(
        redeclare final model Solid = Solid,
        redeclare final package Medium = Liquid_Medium),
    redeclare Cells.ModelicaMediaLibrary.WallCell casing(
        redeclare final model Solid = SolidCasing));

  //
  // Definition of parameters
  //
  replaceable package VLE_Medium =
    Modelica.Media.Water.WaterIF97_ph
    constrainedby Modelica.Media.Interfaces.PartialMedium(
      smoothModel = avoidEvents)
    "VLE media (i.e., used within phase seperator)"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable package Liquid_Medium =
    Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Liquid media (i.e., used within heat exchanger tube)"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of tubes"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model SolidCasing =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

  parameter Modelica.SIunits.Temperature TInitial_VLE = 293.15
    "Initial value for temperature of fluid in phase seperator"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Density rhoInitial_VLE= 500
    "Initial value for density of fluid in phase seperator"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  //
  // Definition of variables
  //
  SummaryRecords.SingleEvaporatorCondenser summary(
    final p_VLE=phaseSeperator.p,
    final rho_VLE=phaseSeperator.rho,
    final T_VLE=phaseSeperator.T,
    final mass=phaseSeperator.mass,
    final p_liq_inlet=heatExchangerTubes.stateProperties_portA.p,
    final p_liq_outlet=heatExchangerTubes.stateProperties_portB.p,
    final p_liq_avg=sum(heatExchangerTubes.liquidCellls.stateProperties.p)/
        heatExchangerTubes.no_cells_liquid,
    final T_liq_inlet=heatExchangerTubes.stateProperties_portA.T,
    final T_liq_outlet=heatExchangerTubes.stateProperties_portB.T,
    final T_liq_avg=sum(heatExchangerTubes.liquidCellls.stateProperties.T)/
        heatExchangerTubes.no_cells_liquid,
    final T_wall_avg=sum(heatExchangerTubes.wallCells.T)/heatExchangerTubes.no_cells_wall,
    final m_flow_hxTwpair=sum(vaporPort.m_flow),
    final m_flow_hxThx=sum(liquidPort.m_flow),
    final m_flow_liq_inlet=port_a.m_flow,
    final m_flow_liq_outlet=port_b.m_flow,
    final Q_flow_wallTVLE=heatExchangerTubes.Q_flow,
    final DH_liquid=heatExchangerTubes.DH_flow)
    "Summary record containing most import variables of model"
    annotation (Placement(transformation(extent={{-100,20},{-60,60}})));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end EvaporatorCondenser;
