within SorpLib.Components.HeatExchangers.EvaporatorCondenser.ModelicaMediaLibrary.Tester;
model TestEvaporatorCondenser_MSL
  "Example model to check evaporator and condenser model"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  Components.HeatExchangers.EvaporatorCondenser.ModelicaMediaLibrary.EvaporatorCondenser
    evaporatorCondenser(
    no_cells_liquid=10,
    redeclare model HeatTransfer_VLESide =
        Components.HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA
        (constantAlphaA=300),
    redeclare model HeatTransferModel_TubeSide =
        Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate,
    pInitial_liquidCell_1=100000,
    pInitial_liquidCell_N=100000,
    TInitial_liquidCell_1=293.15,
    TInitial_liquidCell_N=293.15,
    TInitial_wallCell_1=293.15,
    TInitial_wallCell_N=293.15,
    redeclare package VLE_Medium = Modelica.Media.Water.StandardWater,
    redeclare package Liquid_Medium =
        Modelica.Media.Water.ConstantPropertyLiquidWater,
    TInitial_VLE=293.15,
    rhoInitial_VLE(displayUnit="g/cm3") = 500,
    nPorts_Liquid=1,
    nPorts_Vapor=1,
    phaseSeperator(type_energyBalance=Internals.Types.BalanceEquations.Transient_FreeInitial))
    "Model of an evaporatoror condenser"
    annotation (Placement(transformation(extent={{-10,-4},{10,4}})));

  //
  // Definition of boundaries
  //
  Modelica.Fluid.Sources.MassFlowSource_T inletBoundary(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    m_flow=0.05,
    T=288.15,
    nPorts=1) "Inlet boundary of heat exchanger"
    annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));

  Modelica.Fluid.Sources.Boundary_ph outletBoundary(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    p=100000,
    nPorts=1) "Outlet boundary of heat exchanger"
    annotation (Placement(transformation(extent={{80,-10},{60,10}})));

  Modelica.Fluid.Sources.MassFlowSource_h liquidBoundary(
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    m_flow=0,
    nPorts=1)
    "Liquid boundary of heat exchanger (i.e., liquid refrigerant port)"
    annotation (Placement(transformation(extent={{-40,-50},{-20,-30}})));

  Modelica.Fluid.Sources.Boundary_ph vaporBoundary(
    redeclare package Medium = Modelica.Media.Water.StandardWater,
    p=1200,
    nPorts=1) "Vapor boundary of heat exchanger (i.e., vapor refrigerant port)"
    annotation (Placement(transformation(extent={{-40,30},{-20,50}})));

  Components.Connectors.Converter.MSL.Liquid inletConverter(
      no_components=1, redeclare package Medium_Library =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Media converter for inlet of heat exchanger"
    annotation (Placement(transformation(extent={{-22,-4},{-38,4}})));

  Components.Connectors.Converter.MSL.Liquid outletConverter(
      no_components=1, redeclare package Medium_Library =
        Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Media converter for outlet of heat exchanger"
    annotation (Placement(transformation(extent={{22,-4},{38,4}})));

  Components.Connectors.Converter.MSL.VLE liquidConverter(
      no_components=1, redeclare package Medium_Library =
        Modelica.Media.Water.StandardWater)
    "Media converter for liquid port of heat exchanger (i.e., liquid refrigerant port)"
    annotation (Placement(transformation(
        extent={{8,-4},{-8,4}},
        rotation=90,
        origin={0,-20})));

  Components.Connectors.Converter.MSL.VLE vaporConverter(
      no_components=1, redeclare package Medium_Library =
        Modelica.Media.Water.StandardWater)
    "Media converter for vapor port of heat exchanger (i.e., vapor refrigerant port)"
    annotation (Placement(transformation(
        extent={{-8,-4},{8,4}},
        rotation=90,
        origin={0,20})));

equation
  //
  // Connections
  //
  connect(inletConverter.internalPort, evaporatorCondenser.port_a) annotation (
      Line(
      points={{-22,0},{-10,0}},
      color={28,108,200},
      thickness=1));
  connect(inletBoundary.ports[1], inletConverter.externalPort)
    annotation (Line(points={{-60,0},{-38,0}}, color={0,127,255}));
  connect(evaporatorCondenser.port_b, outletConverter.internalPort) annotation (
     Line(
      points={{9.8,0},{22,0}},
      color={28,108,200},
      thickness=1));
  connect(outletConverter.externalPort, outletBoundary.ports[1])
    annotation (Line(points={{38,0},{60,0}}, color={0,127,255}));
  connect(liquidBoundary.ports[1], liquidConverter.externalPort)
    annotation (Line(points={{-20,-40},{0,-40},{0,-28}}, color={0,127,255}));
  connect(liquidConverter.internalPort, evaporatorCondenser.liquidPort[1])
    annotation (Line(
      points={{0,-12},{0,-4}},
      color={0,140,72},
      thickness=1));
  connect(vaporBoundary.ports[1], vaporConverter.externalPort)
    annotation (Line(points={{-20,40},{0,40},{0,28}}, color={0,127,255}));
  connect(vaporConverter.internalPort, evaporatorCondenser.vaporPort[1])
    annotation (Line(
      points={{0,12},{0,4}},
      color={0,140,72},
      thickness=1));

  //
  // Annotations
  //
  annotation (experiment(StopTime=1000), Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestEvaporatorCondenser_MSL;
