within SorpLib.Components.HeatExchangers.EvaporatorCondenser.TILMediaLibrary;
model EvaporatorCondenser "Evaporator or condenser model"
  extends BaseClasses.PartialEvaporatorCondenser(
    no_components = 1,
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final type_independentMassBalances=
      Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final type_Media=Internals.Types.MediaModel.TIL_VLE,
    redeclare Connectors.TILMediaLibrary.LiquidPort_a port_a(
      final liquidType=Liquid_Medium),
    redeclare Connectors.TILMediaLibrary.LiquidPort_b port_b(
      final liquidType=Liquid_Medium),
    redeclare Connectors.TILMediaLibrary.VLEPort_a liquidPort(
      each final vleFluidType= VLE_Medium,
      each final no_components=1),
    redeclare Connectors.TILMediaLibrary.VLEPort_a vaporPort(
      each final vleFluidType= VLE_Medium,
      each final no_components=1),
    redeclare PhaseSeperators.TILMediaLibrary.SinglePhaseSeperator
      phaseSeperator(
      final TInitial=TInitial_VLE,
      final rhoInitial=rhoInitial_VLE,
      each final vleFluidType= VLE_Medium),
    redeclare Liquid.TILMediaLibrary.LiquidHeatExchanger
      heatExchangerTubes(
        redeclare final model WallMaterial = WallMaterial,
        final liquidType=Liquid_Medium),
    redeclare Cells.TILMediaLibrary.WallCell casing(
        redeclare final model WallMaterial = CasingMaterial));

  //
  // Definition of parameters
  //
  replaceable parameter TILMedia.VLEFluidTypes.TILMedia_Water VLE_Medium
    constrainedby TILMedia.VLEFluidTypes.BaseVLEFluid
    "VLE media (i.e., used within phase seperator)"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable parameter TILMedia.LiquidTypes.TILMedia_Water Liquid_Medium
    constrainedby TILMedia.LiquidTypes.BaseLiquid
    "Liquid media (i.e., used within heat exchanger tube)"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model WallMaterial =
    TILMedia.SolidTypes.TILMedia_Aluminum
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media of tubes"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model CasingMaterial =
    TILMedia.SolidTypes.TILMedia_Aluminum
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media of casing"
    annotation (Dialog(tab = "Media", group = "Media Model",
                enable = use_casing),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

  parameter Modelica.SIunits.Temperature TInitial_VLE = 293.15
    "Initial value for temperature of fluid in phase seperator"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Density rhoInitial_VLE= 500
    "Initial value for density of fluid in phase seperator"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  //
  // Definition of variables
  //
  SummaryRecords.SingleEvaporatorCondenser summary(
    final p_VLE=phaseSeperator.p,
    final rho_VLE=phaseSeperator.rho,
    final T_VLE=phaseSeperator.T,
    final mass=phaseSeperator.mass,
    final p_liq_inlet=heatExchangerTubes.stateProperties_portA.p,
    final p_liq_outlet=heatExchangerTubes.stateProperties_portB.p,
    final p_liq_avg=sum(heatExchangerTubes.liquidCellls.liquid_pT.p)/
        heatExchangerTubes.no_cells_liquid,
    final T_liq_inlet=heatExchangerTubes.stateProperties_portA.T,
    final T_liq_outlet=heatExchangerTubes.stateProperties_portB.T,
    final T_liq_avg=sum(heatExchangerTubes.liquidCellls.liquid_pT.T)/
        heatExchangerTubes.no_cells_liquid,
    final T_wall_avg=sum(heatExchangerTubes.wallCells.T)/heatExchangerTubes.no_cells_wall,
    final m_flow_hxTwpair=sum(vaporPort.m_flow),
    final m_flow_hxThx=sum(liquidPort.m_flow),
    final m_flow_liq_inlet=port_a.m_flow,
    final m_flow_liq_outlet=port_b.m_flow,
    final Q_flow_wallTVLE=heatExchangerTubes.Q_flow,
    final DH_liquid=heatExchangerTubes.DH_flow)
    "Summary record containing most import variables of model"
    annotation (Placement(transformation(extent={{-100,20},{-60,60}})));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation after restructuring of the library.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end EvaporatorCondenser;
