within SorpLib.Components.HeatExchangers.EvaporatorCondenser.TILMediaLibrary.Tester;
model TestEvaporatorCondenser
  "Example model to check evaporator and condenser model"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  EvaporatorCondenser evaporatorCondenser(
    no_cells_liquid=20,
    heatExchangerGeometry(length=7),
    use_casing=true,
    redeclare model HeatTransfer_VLESide =
        HeatTransfers.TransportPhenomena.Internal.General.ConstantAlphaA (
          constantAlphaA=300),
    redeclare model HeatTransferModel_TubeSide =
        HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate,
    redeclare model PressureDropModel =
        Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov,
    TInitial_liquidCell_1=363.15,
    TInitial_liquidCell_N=348.15,
    TInitial_wallCell_1=358.15,
    TInitial_wallCell_N=338.15,
    redeclare model CasingMaterial =
        TILMedia.SolidTypes.TILMedia_StainlessSteel,
    TInitial_VLE=323.15,
    rhoInitial_VLE(displayUnit="g/cm3") = 500,
    nPorts_Liquid=1,
    nPorts_Vapor=1) "Model of an evaporator"
    annotation (Placement(transformation(extent={{-10,-4},{10,4}})));

  //
  // Definition of boundaries
  //
protected
  Boundaries.TILMediaLibrary.LiquidBoundary      liquidBoundary_inlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.VolumeFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    use_VFlowInput=true,
    T=363.15)
    "Inlet of evaporator"
    annotation (Placement(transformation(extent={{-50,-10},{-30,10}})));

  Boundaries.TILMediaLibrary.LiquidBoundary      liquidBoundary_inlet1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    p=100000,
    T=363.15)
    "Inlet of evaporator"
    annotation (Placement(transformation(extent={{50,-10},{30,10}})));

  Boundaries.TILMediaLibrary.VLEBoundary      liquidBoundary(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    use_mFlowInput=true,
    T=308.15) "Inlet boundary for liquid" annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={0,-20})));

  Boundaries.TILMediaLibrary.VLEBoundary      vaporBoundary(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    use_mFlowInput=true,
    T=363.15) "Inlet boundary for vapor" annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=90,
        origin={0,20})));

  Modelica.Blocks.Sources.Sine input_VolumeFlow(
    amplitude=5/1000/60,
    freqHz=1/250,
    offset=-10/1000/60)
    "Input for volume flow rate" annotation (Placement(transformation(
        extent={{4,-4},{-4,4}},
        rotation=180,
        origin={-60,0})), HideResult=true);

  Modelica.Blocks.Sources.Step stepVLEBounday_vapour1(
    height=-0.001,
    offset=0.001,
    startTime=50)
    "Vapour boundary"
    annotation (Placement(transformation(extent={{-6,-6},{6,6}},
        rotation=270,origin={0,40})));

  Modelica.Blocks.Sources.Step stepVLEBounday_liquid1(
    height=0.001,
    offset=-0.001,
    startTime=100)
    "Liquid boundary"
    annotation (Placement(transformation(extent={{-6,-6},{6,6}},
        rotation=90,origin={0,-40})));

equation
  //
  // Connections
  //
  connect(input_VolumeFlow.y, liquidBoundary_inlet.V_flow_input) annotation (
      Line(points={{-55.6,0},{-48,0},{-48,1},{-41.2,1}}, color={0,0,127}));
  connect(evaporatorCondenser.port_a, liquidBoundary_inlet.port) annotation (
      Line(
      points={{-10,0},{-26,0},{-26,0},{-40,0}},
      color={28,108,200},
      thickness=1));
  connect(evaporatorCondenser.port_b, liquidBoundary_inlet1.port) annotation (
      Line(
      points={{9.8,0},{40,0}},
      color={28,108,200},
      thickness=1));
  connect(liquidBoundary.port, evaporatorCondenser.liquidPort[1]) annotation (
      Line(
      points={{0,-20},{0,-20},{0,-4}},
      color={0,140,72},
      thickness=1));
  connect(liquidBoundary.m_flow_input, stepVLEBounday_liquid1.y) annotation (
      Line(points={{-4,-21.2},{-2,-21.2},{-2,-33.4},{4.44089e-16,-33.4}}, color=
         {0,0,127}));
  connect(vaporBoundary.port, evaporatorCondenser.vaporPort[1]) annotation (
      Line(
      points={{0,20},{0,4}},
      color={0,140,72},
      thickness=1));
  connect(vaporBoundary.m_flow_input, stepVLEBounday_vapour1.y) annotation (
      Line(points={{-4,21.2},{-2,21.2},{-2,33.4},{0,33.4}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=1000), Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestEvaporatorCondenser;
