within SorpLib.Components.HeatExchangers.Liquid.BaseClasses;
partial model PartialLiquidHeatExchanger
  "Base model of liquid heat exchangers allowing for variable discretization"
  extends SorpLib.Components.HeatExchangers.BaseClasses.PartialHeatExchanger(
      final pInitial=pInitial_liquidCell_1);

  //
  // Definition of general parameters
  //
  parameter Integer no_cells_liquid(min=2)=2
    "Discretization number of liquid cells"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);
  parameter Integer no_cells_wall(min=1)=no_cells_liquid
    "Discretization number of wall cells (must be a facotr of no_cells_liquid)"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);

  replaceable parameter HeatExchangers.Geometry.LiquidHeatExchanger
    heatExchangerGeometry constrainedby
    HeatExchangers.Geometry.LiquidHeatExchanger
    "Geometry of liquid heat exchanger"
    annotation (Dialog(tab="General", group="Geometry"),
                choicesAllMatching = true);

  parameter Internals.Types.BalancingWallElement balancingWallElement=
   Internals.Types.BalancingWallElement.NS
   "Balancing method for wall cell"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_TubeSide =
    SorpLib.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialExternalHeatTransferCoefficientLiquidTube
    "Heat transfer model for heat transfer coefficient betwenn liquid and wall
     cells"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlpha
                          "Liquid heat exchanger | Constant alpha for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.ConstantAlphaA
                          "Liquid heat exchanger | Constant alphaA for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate
                          "Liquid heat exchanger | Sieder-Tate correlation"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.LiquidTube.Schmidt
                          "Liquid heat exchanger | Schmidt-Korrelation")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_NS =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
    "Heat transfer model for north-south direction of wall"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_NS =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferModel_WE =
    SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
    constrainedby
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer
     "Heat transder model for west-east direction of wall"
    annotation (Dialog(tab = "General", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR
                         "Wall cell | Constant heat transfer resistance of cell"),
                       choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaPlain_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"),
                       choice(redeclare model HeatTransferModel_WE =
            TransHeat.Components.HeatTransfers.TransportPhenomena.Internal.Wall.LambdaCircular_GeometryBased
                         "Wall cell | Geometry-based heat transfer coefficient for circular heat flow")),
                Evaluate=true,
                HideResult = true);

  replaceable model PressureDropModel =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropLiquidTubes
    "Pressure drop model"
    annotation (Dialog(tab="General", group="Pressure Drop"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ZeroPressureDrop
                          "Liquid heat exchanger | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.ConstantZeta
                          "Liquid heat exchanger | Constant resistance for each cell (i.e., zeta)"),
                        choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov
                          "Liquid heat exchanger | Konakov correlation")));

  //
  // Definition of parameters describing the initialisation
  //
  parameter Modelica.SIunits.Pressure pInitial_liquidCell_1=1e5+25000
    "Initial value for liquid pressure of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Pressure pInitial_liquidCell_N=1e5
    "Initial value for liquid pressure of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_liquidCell_1=283.15
    "Initial value for liquid temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_liquidCell_N=303.15
    "Initial value for liquid temperature of cell n"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  parameter Modelica.SIunits.Temperature TInitial_wallCell_1 = 293.15
    "Initial value for wall temperature of cell 1"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);
  parameter Modelica.SIunits.Temperature TInitial_wallCell_N = 313.15
    "Initial value for wall temperature of cell N"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                HideResult = true);

  //
  // Definition of final parameters and constants
  //
protected
  final parameter Real dl_wall[no_cells_wall]=
    {1/no_cells_wall for i in 1:no_cells_wall}
    "Length portions of wall cells"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);
  final parameter Real dl_liquid[no_cells_liquid]=
    {1/no_cells_liquid for i in 1:no_cells_liquid}
    "Length portions of liquid cells"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);

  final parameter Modelica.SIunits.Pressure[no_cells_liquid] pInitial_wallCell=
    linspace(pInitial_liquidCell_1,pInitial_liquidCell_N,no_cells_liquid)
    "Initial value for wall temperature of each fluid cell"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                Evaluate=true,
                HideResult = true);
  final parameter Modelica.SIunits.Temperature[no_cells_liquid] TInitial_liquidCell=
    linspace(TInitial_liquidCell_1,TInitial_liquidCell_N,no_cells_liquid)
    "Initial value for liquid temperature of each fluid cell"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                Evaluate=true,
                HideResult = true);
  final parameter Modelica.SIunits.Temperature[no_cells_wall] TInitial_wallCell=
    linspace(TInitial_wallCell_1,TInitial_wallCell_N,no_cells_wall)
    "Initial value for wall temperature of each fluid cell"
    annotation (Dialog(tab="Initialisation", group="Initial Values"),
                Evaluate=true,
                HideResult = true);

  final parameter Boolean calc_propertyRecord = Modelica.Math.BooleanVectors.anyTrue(
    heatTransferCoefficient_tubeSide.calc_propertyRecord) or
    Modelica.Math.BooleanVectors.anyTrue(
    hydraulicResistors.calc_propertyRecord) or
    hydraulicResistor_portA.calc_propertyRecord or
    hydraulicResistor_portB.calc_propertyRecord
    " = true, if fluid property record is required";

  //
  // Definition of models
  //
public
  replaceable Cells.BaseClasses.PartialWallCell[no_cells_wall] wallCells(
    final cellGeometry(
      final length_WE=heatExchangerGeometry.length*dl_wall,
      final length_NS=heatExchangerGeometry.length_heatTransfer*dl_wall,
      each final crossSectionalArea=heatExchangerGeometry.wallCrossSectionalArea,
      final volume=heatExchangerGeometry.wallVolume*dl_wall),
    each final balancingWallElement=balancingWallElement,
    redeclare each final model HeatTransferModel_NS = HeatTransferModel_NS,
    redeclare each final model HeatTransferModel_WE = HeatTransferModel_WE,
    final TInitial=TInitial_wallCell,
    each final type_energyBalance=type_energyBalance)
    "Discretized wall of liquid heat exchanger"
    annotation (Placement(transformation(extent={{-6,20},{6,32}})));

  replaceable Cells.BaseClasses.PartialLiquidVLECell[no_cells_liquid]
    liquidCellls(
    final cellGeometry(
      each final hydraulicDiameter=heatExchangerGeometry.d_inner,
      final length=heatExchangerGeometry.length*dl_liquid,
      each final hydraulicCrossSectionalArea=heatExchangerGeometry.innerCrossSectionalArea,
      final heatTransferArea=heatExchangerGeometry.innerHeatTransferArea*
          dl_liquid,
      final volume=heatExchangerGeometry.innerVolume*dl_liquid,
      each final nParallelHydraulicFlows=heatExchangerGeometry.nParallelTubes),
    each final no_components=no_components,
    each final calc_propertyRecord=calc_propertyRecord,
    final pInitial=pInitial_wallCell,
    final TInitial=TInitial_liquidCell,
    each final xiInitial=xiInitial,
    each final m_flowInitial=m_flowInitial,
    each final type_overallMassBalance=type_overallMassBalance,
    each final type_energyBalance=type_energyBalance,
    each final avoid_events=avoid_events)
    "Discretized fluid cells of liquid heat exchanger"
    annotation (Placement(transformation(extent={{-6,-16},{6,-4}})));

  HeatTransferModel_TubeSide[no_cells_liquid] heatTransferCoefficient_tubeSide(
    each final no_cells_liquid=no_cells_liquid,
    final cellGeometry(
      each final roughness = heatExchangerGeometry.roughness,
      each final d_inner=heatExchangerGeometry.d_inner,
      final length=heatExchangerGeometry.length*dl_liquid,
      final length_heatTransfer=heatExchangerGeometry.length_heatTransfer*dl_liquid,
      each final innerCrossSectionalArea=heatExchangerGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=heatExchangerGeometry.innerHeatTransferArea*dl_liquid))
    "Models calculating the heat transfer coefficients between the wall and
    liquid cells"
    annotation (Placement(transformation(extent={{-16,4},{-8,12}})));

  HeatTransfers.HeatTransfer[no_cells_liquid] heatTransfers_liquidToWall(
    each final n_A=1,
    each final n_B=1,
    each final use_alphaA_input=true)
    "Models calculating heat transfers between liquid and wall cells"
    annotation (Placement(transformation(extent={{6,2},{-6,-2}},
                rotation=270, origin={0,8})));

  replaceable Fittings.HydraulicResistors.BaseClasses.PartialHydraulicResistorLiquidTubes
    hydraulicResistor_portA(
    final no_cells=no_cells_liquid,
    redeclare final model PressureDropModelLiquid = PressureDropModel,
    final cellGeometry(
      final roughness=heatExchangerGeometry.roughness,
      final d_inner=heatExchangerGeometry.d_inner,
      final length=heatExchangerGeometry.length*dl_liquid[1]/2,
      final length_heatTransfer=heatExchangerGeometry.length_heatTransfer*
          dl_liquid[1]/2,
      final innerCrossSectionalArea=heatExchangerGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=heatExchangerGeometry.innerHeatTransferArea*
          dl_liquid[1]/2)) "Hydraulic resistor at port A: 1/2 + dp_cell"
    annotation (Placement(transformation(extent={{-60,-6},{-40,-14}})));

  replaceable Fittings.HydraulicResistors.BaseClasses.PartialHydraulicResistorLiquidTubes[
    no_cells_liquid - 1] hydraulicResistors(
    each final no_cells=no_cells_liquid,
    redeclare each final model PressureDropModelLiquid = PressureDropModel,
    final cellGeometry(
      each final roughness=heatExchangerGeometry.roughness,
      each final d_inner=heatExchangerGeometry.d_inner,
      final length=heatExchangerGeometry.length*dl_liquid[1:no_cells_liquid - 1],
      final length_heatTransfer=heatExchangerGeometry.length_heatTransfer*
          dl_liquid[1:no_cells_liquid - 1],
      each final innerCrossSectionalArea=heatExchangerGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=heatExchangerGeometry.innerHeatTransferArea*
          dl_liquid[1:no_cells_liquid - 1]))
    "Hydraulic resistors between liquid cells"
    annotation (Placement(transformation(extent={{10,-26},{-10,-34}})));

  replaceable Fittings.HydraulicResistors.BaseClasses.PartialHydraulicResistorLiquidTubes
    hydraulicResistor_portB(
    final no_cells=no_cells_liquid,
    redeclare final model PressureDropModelLiquid = PressureDropModel,
    final cellGeometry(
      final roughness=heatExchangerGeometry.roughness,
      final d_inner=heatExchangerGeometry.d_inner,
      final length=heatExchangerGeometry.length*dl_liquid[1]/2,
      final length_heatTransfer=heatExchangerGeometry.length_heatTransfer*
          dl_liquid[1]/2,
      final innerCrossSectionalArea=heatExchangerGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=heatExchangerGeometry.innerHeatTransferArea*
          dl_liquid[1]/2)) "Hydraulic resistor at port B: 1/2 + dp_cell"
    annotation (Placement(transformation(extent={{40,-6},{60,-14}})));

  //
  // Definition of variables
  //
  Modelica.SIunits.PressureDifference dp = port_a.p - port_b.p
    "Pressure difference between port A and B";

  Modelica.SIunits.MassFlowRate m_flow_A = port_a.m_flow
    "Mass flow rate at port A";
  Modelica.SIunits.MassFlowRate m_flow_B = port_b.m_flow
    "Mass flow rate at port B";

  Modelica.SIunits.HeatFlowRate DH_flow
    "Difference enthalpy flow rate between port A and port B";
  Modelica.SIunits.HeatFlowRate Q_flow = sum(heatPort.Q_flow)
    "Heat flow rate";

  //
  // Definition of connectors
  //
  Components.Connectors.Thermal.Port_a[no_cells_wall] heatPort
    "Heat port between heat heat exchanger wall and sorbent"
    annotation(Placement(transformation(extent={{-10,30},{10,50}},rotation=0),
               iconTransformation(extent={{-10,30},{10,50}})));

equation
  //
  // Assertions
  //
  if no_cells_wall < no_cells_liquid then
    assert(rem(no_cells_liquid, no_cells_wall) == 0,
      "Number of wall cells must be factor of number of liquid cells!");

  elseif no_cells_wall > no_cells_liquid then
    assert(rem(no_cells_wall, no_cells_liquid) == 0,
      "Number of wall cells must be factor of number of liquid cells!");

  end if;

  //
  // Connection of fluid ports
  //
  connect(port_a, hydraulicResistor_portA.port_a)
    annotation (Line(points={{-100,0},{-80,0},{-80,-10},{-60,-10}},   color={28,108,
          200},
      thickness=1));
  connect(hydraulicResistor_portA.port_b, liquidCellls[1].port_a)
    annotation (Line(points={{-40.2,-10},{-4.2,-10}},
                                                    color={28,108,200},
      thickness=1));

  for i in 1:(no_cells_liquid-1) loop
    connect(liquidCellls[i].port_b, hydraulicResistors[i].port_a)
      annotation (Line(points={{3.12,-10},{16,-10},{16,-30},{10,-30}}, color={28,108,
            200},
        thickness=1));
    connect(hydraulicResistors[i].port_b, liquidCellls[i+1].port_a)
      annotation (Line(points={{-9.8,-30},{-16,-30},{-16,-10},{-4.2,-10}}, color={28,108,
            200},
        thickness=1));
  end for;

  connect(liquidCellls[no_cells_liquid].port_b, hydraulicResistor_portB.port_a)
    annotation (Line(points={{3.12,-10},{40,-10}},   color={28,108,200},
      thickness=1));
  connect(hydraulicResistor_portB.port_b, port_b)
    annotation (Line(points={{59.8,-10},{80,-10},{80,0},{98,0}},
                                                               color={28,108,200},
      thickness=1));

  //
  // Connection of heat ports
  //
  connect(liquidCellls.heatPort, heatTransfers_liquidToWall.heatPort_a[1])
    annotation (Line(
      points={{0,-6.4},{0,2}},
      color={238,46,47},
      thickness=1));

  if no_cells_wall < no_cells_liquid then
    //
    // Number of wall cells is less than number of fluid cells:
    // Connect multiple liquid cells with one wall cell!
    //
    for i in 1:no_cells_wall loop
      for j in 1:integer(no_cells_liquid/no_cells_wall) loop
        connect(heatTransfers_liquidToWall[integer(no_cells_liquid/no_cells_wall)*(i-1)+j].heatPort_b[1],
          wallCells[i].heatPort_S)
          annotation (Line(points={{0,14},{0,20}},color={238,46,47},thickness=1));
      end for;
    end for;

  elseif no_cells_wall > no_cells_liquid then
    //
    // Number of wall cells is greater than number of fluid cells:
    // Connect multiple wall cells with one liquid cell!
    //
    for i in 1:no_cells_liquid loop
      for j in 1:integer(no_cells_wall/no_cells_liquid) loop
        connect(heatTransfers_liquidToWall[i].heatPort_b[1],
          wallCells[integer(no_cells_wall/no_cells_liquid)*(i-1)+j].heatPort_S)
          annotation (Line(points={{0,14},{0,20}},color={238,46,47},thickness=1));
      end for;
    end for;

  else
    //
    // Number of wall cells equals number of fluid cells:
    // Connect one liquid cell with one wall cell!
    //
    for i in 1:no_cells_liquid loop
      connect(heatTransfers_liquidToWall[i].heatPort_b[1], wallCells[i].heatPort_S)
        annotation (Line(points={{0,14},{0,20}},color={238,46,47},thickness=1));
    end for;

  end if;

  if ((balancingWallElement == Internals.Types.BalancingWallElement.WE) or
    (balancingWallElement == Internals.Types.BalancingWallElement.NSandWE)) then
    //
    // Connect wall cells in axial direction
    //
    for i in 1:(no_cells_wall-1) loop
      connect(wallCells[i].heatPort_E, wallCells[i+1].heatPort_W)
        annotation (Line(points={{6,26},{20,26},{20,16},{-20,16},{-20,26},{-6,26}},
                    color={238,46,47},thickness=1));
    end for;

  end if;

  connect(wallCells.heatPort_N, heatPort) annotation (Line(
      points={{0,32},{0,40}},
      color={238,46,47},
      thickness=1));
  connect(heatTransferCoefficient_tubeSide.alphaA, heatTransfers_liquidToWall.alphaA_input)
    annotation (Line(points={{-7.6,8},{-2,8}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (Icon(graphics={
        Rectangle(
          extent={{-100,40},{100,-40}},
          lineColor={0,0,0},
          lineThickness=1,
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid),
        Text(
          extent={{-60,10},{-40,-10}},
          lineColor={0,0,0},
          lineThickness=1,
          fillColor={255,255,255},
          fillPattern=FillPattern.None,
          fontSize=20,
          textString="1"),
        Text(
          extent={{40,10},{60,-10}},
          lineColor={0,0,0},
          lineThickness=1,
          fillColor={255,255,255},
          fillPattern=FillPattern.None,
          fontSize=20,
          textString="n"),
        Line(
          points={{0,40},{2,14},{-4,10},{2,-6},{-2,-16},{2,-32},{0,-40}},
          color={0,0,0},
          smooth=Smooth.Bezier)}), Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialLiquidHeatExchanger;
