within SorpLib.Components.HeatExchangers.Liquid.ModelicaMediaLibrary;
model LiquidHeatExchanger
  "Tube model with variable discretisation for liquid and wall cells"
  extends BaseClasses.PartialLiquidHeatExchanger(
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final type_independentMassBalances=
      Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final type_Media=Internals.Types.MediaModel.Modelica_IL,
    redeclare final Connectors.ModelicaMediaLibrary.LiquidPort_a port_a(
      redeclare final package Medium = Medium),
    redeclare final Connectors.ModelicaMediaLibrary.LiquidPort_b port_b(
      redeclare final package Medium = Medium),
    redeclare Fittings.HydraulicResistors.ModelicaMediaLibrary.LiquidTube
      hydraulicResistor_portA(
      final no_components=no_components,
      final m_flowInitial=m_flowInitial,
      final avoid_events=avoid_events,
      final fluidProperties_portA=fluidProperties_portA_instream,
      final fluidProperties_portB=liquidCellls[1].fluidProperties,
      redeclare final package Medium = Medium),
    redeclare Fittings.HydraulicResistors.ModelicaMediaLibrary.LiquidTube
      hydraulicResistors(
      each final no_components=no_components,
      each final m_flowInitial=m_flowInitial,
      each final avoid_events=avoid_events,
      final fluidProperties_portA=liquidCellls[1:no_cells_liquid - 1].fluidProperties,
      final fluidProperties_portB=liquidCellls[2:no_cells_liquid].fluidProperties,
      redeclare each final package Medium = Medium),
    redeclare Fittings.HydraulicResistors.ModelicaMediaLibrary.LiquidTube
      hydraulicResistor_portB(
      final no_components=no_components,
      final m_flowInitial=m_flowInitial,
      final avoid_events=avoid_events,
      final fluidProperties_portA=liquidCellls[no_cells_liquid].fluidProperties,
      final fluidProperties_portB=fluidProperties_portB_instream,
      redeclare final package Medium = Medium),
    redeclare Cells.ModelicaMediaLibrary.LiquidCell liquidCellls(
      each state_phxi=false,
      each singleStateVariable=true,
      each rhoStart=1000,
      each neglectTermVp=true,
      redeclare each final package Medium = Medium,
      each neglectDerivativeP=true,
      each use_incompressibleEquations=true),
    redeclare Cells.ModelicaMediaLibrary.WallCell wallCells(
      redeclare each final model Solid = Solid),
    heatTransferCoefficient_tubeSide(
      final fluidProperties=liquidCellls.fluidProperties));

  //
  // Definition of parameters
  //
  replaceable package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model Solid =
    Media.SolidMediaDefinition.SimpleSolidMediaDefinition.Aluminium
    constrainedby Media.SolidMediaDefinition.BaseClasses.PartialSolidMedia
    "Solid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

  //
  // Definition of media models
  //
  Medium.ThermodynamicState stateProperties_portA = Medium.setState_phX(
    p = port_a.p,
    h = if avoid_events then noEvent(actualStream(port_a.h_outflow)) else
      actualStream(port_a.h_outflow),
    X = if avoid_events then noEvent(actualStream(port_a.xi_outflow)) else
      actualStream(port_a.xi_outflow))
    "Record describing current state properties at port A";
  Medium.ThermodynamicState stateProperties_portB = Medium.setState_phX(
    p = port_b.p,
    h = if avoid_events then noEvent(actualStream(port_b.h_outflow)) else
      actualStream(port_b.h_outflow),
    X = if avoid_events then noEvent(actualStream(port_b.xi_outflow)) else
      actualStream(port_b.xi_outflow))
    "Record describing current state properties at port B";

  Medium.ThermodynamicState stateProperties_portA_instream = Medium.setState_phX(
    p = port_a.p,
    h = inStream(port_a.h_outflow),
    X = inStream(port_a.xi_outflow))
    "Record describing instreaming state properties at port A"
    annotation (HideResult = true);
  Medium.ThermodynamicState stateProperties_portB_instream = Medium.setState_phX(
    p = port_b.p,
    h = inStream(port_b.h_outflow),
    X = inStream(port_b.xi_outflow))
    "Record describing instreaming state properties at port B"
    annotation (HideResult = true);

  //
  // Definition of property records
  //
  Cells.PropertyRecord.FluidCellProperties fluidProperties_portA_instream(
    final T=if calc_propertyRecord then Medium.temperature(
        stateProperties_portA_instream) else -1,
    final rho=if calc_propertyRecord then Medium.density(
        stateProperties_portA_instream) else -1,
    final lambda=if calc_propertyRecord then Medium.thermalConductivity(
        stateProperties_portA_instream) else -1,
    final eta=if calc_propertyRecord then Medium.dynamicViscosity(
        stateProperties_portA_instream) else -1,
    final Pr=if calc_propertyRecord then Medium.prandtlNumber(
        stateProperties_portA_instream) else -1,
    final m_flow_portA=-1,
    final m_flow_portB=-1)
    "Record containing fluid properties required by models of transport phenomena"
    annotation (HideResult=true);

  Cells.PropertyRecord.FluidCellProperties fluidProperties_portB_instream(
    final T=if calc_propertyRecord then Medium.temperature(
        stateProperties_portB_instream) else -1,
    final rho=if calc_propertyRecord then Medium.density(
        stateProperties_portB_instream) else -1,
    final lambda=if calc_propertyRecord then Medium.thermalConductivity(
        stateProperties_portB_instream) else -1,
    final eta=if calc_propertyRecord then Medium.dynamicViscosity(
        stateProperties_portB_instream) else -1,
    final Pr=if calc_propertyRecord then Medium.prandtlNumber(
        stateProperties_portB_instream) else -1,
    final m_flow_portA=-1,
    final m_flow_portB=-1)
    "Record containing fluid properties required by models of transport phenomena"
    annotation (HideResult=true);

equation
  DH_flow = m_flow_A * Medium.specificEnthalpy(stateProperties_portA) +
    m_flow_B * Medium.specificEnthalpy(stateProperties_portB)
    "Difference enthalpy flow rate";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end LiquidHeatExchanger;
