within SorpLib.Components.HeatExchangers.Liquid.ModelicaMediaLibrary.Tester;
model TestLiquidHeatExchanger "Model to test liquid heat exchanger"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  LiquidHeatExchanger liquidHeatExchanger(
    no_components=1,
    no_cells_liquid=20,
    heatExchangerGeometry(length=7),
    redeclare model HeatTransferModel_TubeSide =
        HeatTransfers.TransportPhenomena.External.LiquidTube.SiederTate,
    redeclare model HeatTransferModel_WE =
        HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR (constantR=
            1e12),
    redeclare model PressureDropModel =
        Fittings.HydraulicResistors.TransportPhenomena.LiquidTube.Konakov,
    pInitial_liquidCell_1=100000,
    TInitial_liquidCell_1=303.15,
    TInitial_liquidCell_N=308.15,
    TInitial_wallCell_1=373.15,
    TInitial_wallCell_N=363.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Heat exchanger model"
    annotation (Placement(transformation(extent={{-10,-4},{10,4}})));

  //
  // Definition of boundaries
  //
protected
  Boundaries.ModelicaMediaLibrary.LiquidBoundary inletBoundary(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.VolumeFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.Temperature,
    m_flow=-0.001,
    V_flow=-10/1000/60,
    T=303.15,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Inlet of heat exchanger"
    annotation (Placement(transformation(extent={{-50,-10},{-30,10}})));

  Boundaries.ModelicaMediaLibrary.LiquidBoundary outletBoundary(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    p=100000,
    m_flow=0,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    "Outlet boundary"
    annotation (Placement(transformation(extent={{30,-10},{50,10}})));

equation
  //
  // Connections
  //
  connect(inletBoundary.port, liquidHeatExchanger.port_a) annotation (Line(
      points={{-40,0},{-10,0}},
      color={28,108,200},
      thickness=1));
  connect(liquidHeatExchanger.port_b, outletBoundary.port) annotation (Line(
      points={{9.8,0},{40,0}},
      color={28,108,200},
      thickness=1));

  //
  // Annotations
  //
  annotation (experiment(StopTime=500), Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestLiquidHeatExchanger;
