within SorpLib.Components.HeatExchangers.Liquid.TILMediaLibrary;
model LiquidHeatExchanger
  "Tube model with variable discretisation for liquid and wall cells"
  extends BaseClasses.PartialLiquidHeatExchanger(
    type_overallMassBalance=SorpLib.Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final type_independentMassBalances=
      Internals.Types.BalanceEquations.SteadyState_FreeInitial,
    final type_Media=Internals.Types.MediaModel.TIL_IL,
    redeclare final Connectors.TILMediaLibrary.LiquidPort_a port_a(
      final liquidType=liquidType),
    redeclare final Connectors.TILMediaLibrary.LiquidPort_b port_b(
      final liquidType=liquidType),
    redeclare Fittings.HydraulicResistors.TILMediaLibrary.LiquidTube
      hydraulicResistor_portA(
      final no_components=no_components,
      final m_flowInitial=m_flowInitial,
      final avoid_events=avoid_events,
      final fluidProperties_portA=fluidProperties_portA_instream,
      final fluidProperties_portB=liquidCellls[1].fluidProperties,
      final liquidType=liquidType),
    redeclare Fittings.HydraulicResistors.TILMediaLibrary.LiquidTube
      hydraulicResistors(
      each final no_components=no_components,
      each final m_flowInitial=m_flowInitial,
      each final avoid_events=avoid_events,
      final fluidProperties_portA=liquidCellls[1:no_cells_liquid - 1].fluidProperties,
      final fluidProperties_portB=liquidCellls[2:no_cells_liquid].fluidProperties,
      each final liquidType=liquidType),
    redeclare Fittings.HydraulicResistors.TILMediaLibrary.LiquidTube
      hydraulicResistor_portB(
      final no_components=no_components,
      final m_flowInitial=m_flowInitial,
      final avoid_events=avoid_events,
      final fluidProperties_portA=liquidCellls[no_cells_liquid].fluidProperties,
      final fluidProperties_portB=fluidProperties_portB_instream,
      final liquidType=liquidType),
    redeclare Cells.TILMediaLibrary.LiquidCell liquidCellls(
      each singleStateVariable=true,
      each rhoStart=1000,
      each neglectTermVp=true,
      each final liquidType=liquidType,
      each neglectDerivativeP=true),
    redeclare Cells.TILMediaLibrary.WallCell wallCells(
      redeclare each final model WallMaterial = WallMaterial),
    heatTransferCoefficient_tubeSide(
      final fluidProperties=liquidCellls.fluidProperties));

  //
  // Definition of parameters
  //
  replaceable parameter TILMedia.LiquidTypes.TILMedia_Water liquidType
    constrainedby TILMedia.LiquidTypes.BaseLiquid
    "Liquid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);
  replaceable model WallMaterial =
    TILMedia.SolidTypes.TILMedia_Aluminum
    constrainedby TILMedia.SolidTypes.BaseSolid
    "Solid media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

  //
  // Definition of media models
  //
  TILMedia.Liquid_ph stateProperties_portA(
    final liquidType=liquidType,
    final computeTransportProperties=false,
    final p = port_a.p,
    final h = if avoid_events then noEvent(actualStream(port_a.h_outflow)) else
      actualStream(port_a.h_outflow),
    final xi = if avoid_events then noEvent(actualStream(port_a.xi_outflow)) else
      actualStream(port_a.xi_outflow))
    "Record describing current state properties at port A";
  TILMedia.Liquid_ph stateProperties_portB(
    final liquidType=liquidType,
    final computeTransportProperties=false,
    final p = port_b.p,
    final h = if avoid_events then noEvent(actualStream(port_b.h_outflow)) else
      actualStream(port_b.h_outflow),
    final xi = if avoid_events then noEvent(actualStream(port_b.xi_outflow)) else
      actualStream(port_b.xi_outflow))
    "Record describing current state properties at port B";

  TILMedia.Liquid_ph stateProperties_portA_instream(
    final liquidType=liquidType,
    final computeTransportProperties=calc_propertyRecord,
    final p = port_a.p,
    final h = inStream(port_a.h_outflow),
    final xi = inStream(port_a.xi_outflow))
    "Record describing instreaming state properties at port A"
    annotation (HideResult = true);
  TILMedia.Liquid_ph stateProperties_portB_instream(
    final liquidType=liquidType,
    final computeTransportProperties=calc_propertyRecord,
    final p = port_b.p,
    final h = inStream(port_b.h_outflow),
    final xi = inStream(port_b.xi_outflow))
    "Record describing instreaming state properties at port B"
    annotation (HideResult = true);

  //
  // Definition of property records
  //
  Cells.PropertyRecord.FluidCellProperties fluidProperties_portA_instream(
    final T=if calc_propertyRecord then stateProperties_portA_instream.T else -1,
    final rho=if calc_propertyRecord then stateProperties_portA_instream.d
         else -1,
    final lambda=if calc_propertyRecord then stateProperties_portA_instream.transp.lambda
         else -1,
    final eta=if calc_propertyRecord then stateProperties_portA_instream.transp.eta
         else -1,
    final Pr=if calc_propertyRecord then stateProperties_portA_instream.transp.Pr
         else -1,
    final m_flow_portA=-1,
    final m_flow_portB=-1)
    "Record containing fluid properties required by models of transport phenomena"
    annotation (HideResult=true);

  Cells.PropertyRecord.FluidCellProperties fluidProperties_portB_instream(
    final T=if calc_propertyRecord then stateProperties_portB_instream.T else -1,
    final rho=if calc_propertyRecord then stateProperties_portB_instream.d
         else -1,
    final lambda=if calc_propertyRecord then stateProperties_portB_instream.transp.lambda
         else -1,
    final eta=if calc_propertyRecord then stateProperties_portB_instream.transp.eta
         else -1,
    final Pr=if calc_propertyRecord then stateProperties_portB_instream.transp.Pr
         else -1,
    final m_flow_portA=-1,
    final m_flow_portB=-1)
    "Record containing fluid properties required by models of transport phenomena"
    annotation (HideResult=true);

equation
  DH_flow = m_flow_A * stateProperties_portA.h +
    m_flow_B * stateProperties_portB.h
    "Difference enthalpy flow rate";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end LiquidHeatExchanger;
