within SorpLib.Components.HeatExchangers.SummaryRecords;
record SingleEvaporatorCondenser
  "Record containing most import variables of a evaporator or condenser of a pure fluid"
  extends Internals.ClassTypes.Record;

  //
  // Variables describing the phase seperator
  //
  Modelica.SIunits.Pressure p_VLE
    "Average pressure in phase seperator"
    annotation (Dialog(tab="General", group="Phase Seperator"));
  Modelica.SIunits.Density rho_VLE
    "Average density in phase seperator"
    annotation (Dialog(tab="General", group="Phase Seperator"));
  Modelica.SIunits.Temperature T_VLE
    "Average temperature in phase seperator"
    annotation (Dialog(tab="General", group="Phase Seperator"));

  Modelica.SIunits.Mass mass
    "Fluid mass in phase seperator"
    annotation (Dialog(tab="General", group="Phase Seperator"));

  //
  // Variables describing the heat exchanger
  //
  Modelica.SIunits.Pressure p_liq_inlet
    "Pressure of liquid at heat exchanger inlet"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.Pressure p_liq_outlet
    "Pressure of liquid at heat exchanger outlet"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.Pressure p_liq_avg
    "Average pressure of liquid in heat exchanger"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.PressureDifference dp_liq = p_liq_inlet - p_liq_outlet
    "Pressure difference of liquid in heat exchanger";

  Modelica.SIunits.Temperature T_liq_inlet
    "Temperature of liquid at heat exchanger inlet"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.Temperature T_liq_outlet
    "Temperature of liquid at heat exchanger outlet"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));
  Modelica.SIunits.Temperature T_liq_avg
    "Average temperature of liquid in heat exchanger"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));

  Modelica.SIunits.Temperature T_wall_avg
    "Average wall temperature of heat exchanger"
    annotation (Dialog(tab="General", group="Heat Exchanger Tubes"));

  //
  // Variables required for balance equations
  //
  Modelica.SIunits.MassFlowRate m_flow_hxTwpair
    "Mass flow rate of vapor from heat exchanger to working pair cells"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.MassFlowRate m_flow_hxThx
    "Mass flow rate of liquid"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.MassFlowRate m_flow_liq_inlet
    "Mass flow rate of liquid at inlet of heat exchanger"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.MassFlowRate m_flow_liq_outlet
    "Mass flow rate of liquid at outlet of heat exchanger"
    annotation (Dialog(tab="General", group="Balance Equations"));

  Modelica.SIunits.HeatFlowRate Q_flow_wallTVLE
    "Heat flow rate from heat exchanger walls to phase seperator"
    annotation (Dialog(tab="General", group="Balance Equations"));
  Modelica.SIunits.HeatFlowRate DH_liquid
    "Difference enthalpy flow of liquid in heat exchanger"
    annotation (Dialog(tab="General", group="Balance Equations"));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 14, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end SingleEvaporatorCondenser;
