within SorpLib.Components.HeatTransfers.TransportPhenomena.Internal.General;
model ConstantAlpha
  "Heat transfer | Heat transfer model with constant heat transfer coefficient alpha"
  extends
    SorpLib.Components.HeatTransfers.BaseClasses.PartialInternalHeatTransfer(
      final computeTransportProperties=false, final useAlphaAState=false);

  //
  // Definition of parameters
  //
  parameter Modelica.SIunits.CoefficientOfHeatTransfer constantAlpha = 25
    "Constant value for alpha for entire heat transfer resistance"
    annotation(Dialog(tab = "General", group = "Heat transfer"));
  parameter Modelica.SIunits.Area A = 1
    "Constant value for heat transfer area for entire heat transfer resistance"
    annotation(Dialog(tab = "General", group = "Heat transfer"));

equation
  alphaA = constantAlpha*A
    "Calculation of heat transfer coefficient";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 13, 2021, by Mirko Engelpracht:<br/>
  Smaller revision after resctructering of the library.
  </li>
  <li>
  December 06, 2017, by Andrej Gibelhaus:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>
  This simple transfer model calculates the heat flow based on the temperature differnce with a constant alpha.
</p>
<h4>Main equations</h4>
<p>
  <p align=\"center\"> <i>Q</i><sub>in</sub> = <i><code>&alpha;</code> A</i> (<i>T</i><sub>in</sub> - <i>T</i><sub>out</sub>) </p>
  <p>where <i><code>&alpha;</code></i> is a constant heat tranfer coefficient and <i>A</i> is the heat transfer area. </p>
</p>
<h4>Assumptions and limitations</h4>
  <p>
    In general, the heat transfer coefficient depends on fluid properties and geometry. Thus, a constant coefficient is only an approximation.
  </p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end ConstantAlpha;
