within SorpLib.Components.HeatTransfers.TransportPhenomena.Internal;
package Wall "Heat transfer models for wall cells"
  extends Internals.ClassTypes.ModelPackage;

  model ConstantR
    "Wall cell | Constant heat transfer resistance of cell"
    extends HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer;

    //
    // Definition of parameters
    //
    parameter Modelica.SIunits.ThermalResistance constantR = 25
      "Constant value for R for one wall cell and whole direction"
      annotation (Dialog(tab="General",group="Heat Transfer"),
                  HideResult = true);

  equation
    k_PortCenter = 1/(constantR/2)
      "Calculation of heat transfer coefficient: From heat port (e.g., S or W) to 
     cell center";
    k_CenterPort = 1/(constantR/2)
      "Calculation of heat transfer coefficient: From cell center to heat port 
     (e.g., N or E)";

    //
    // Annotations
    //
    annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>",   info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
  end ConstantR;

  model LambdaPlain_GeometryBased
    "Wall cell | Geometry-based heat transfer coefficient for plain heat flow"
    extends HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer;

    //
    // Definition of parameters
    //
    parameter Modelica.SIunits.Length thickness = cellGeometry.length_WE
      "Thickness of plain wall"
      annotation (Dialog(tab="General",group="Geometry"),
                  HideResult = true);
    parameter Modelica.SIunits.Area crossSectionalArea = cellGeometry.crossSectionalArea
      "Cross-sectional area for heat flow calculation"
      annotation (Dialog(tab="General",group="Geometry"),
                  HideResult = true);

  equation
    k_PortCenter = cellProperties.lambda*crossSectionalArea/(thickness/2)
      "Calculation of heat transfer coefficient: From heat port (e.g., S or W) to 
     cell center";
    k_CenterPort = cellProperties.lambda*crossSectionalArea/(thickness/2)
      "Calculation of heat transfer coefficient: From cell center to heat port 
    (e.g., N or E)";

    //
    // Annotations
    //
    annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>",   info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
  end LambdaPlain_GeometryBased;

  model LambdaCircular_GeometryBased
    "Wall cell | Geometry-based heat transfer coefficient for circular heat flow"
    extends HeatTransfers.BaseClasses.PartialInternalWallHeatTransfer;

    //
    // Definition of parameters
    //
    parameter Modelica.SIunits.Diameter d_inner = 0.01
      "Inner diameter of tube"
      annotation (Dialog(tab="General",group="Geometry"),
                  HideResult = true);
    parameter Modelica.SIunits.Diameter d_outer = 0.012
      "Outer diameter of tube"
      annotation (Dialog(tab="General",group="Geometry"),
                  HideResult = true);

  protected
    final parameter Modelica.SIunits.Diameter d_center = (d_inner+d_outer)/2
      "Center diameter of tube"
      annotation (Dialog(tab="General",group="Geometry"),
                  HideResult = true);

  equation
    k_PortCenter = Modelica.Constants.pi*cellGeometry.length_WE /
      (1/(2*cellProperties.lambda) * Modelica.Math.log(d_center/d_inner))
      "Calculation of heat transfer coefficient: From heat port (e.g., S or W) to 
     cell center";
    k_CenterPort = Modelica.Constants.pi*cellGeometry.length_WE /
      (1/(2*cellProperties.lambda) * Modelica.Math.log(d_outer/d_center))
      "Calculation of heat transfer coefficient: From cell center to heat port 
     (e.g., N or E)";

    //
    // Annotations
    //
    annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>",   info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
  end LambdaCircular_GeometryBased;
annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 12, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end Wall;
