within SorpLib.Components.MassTransfers.BaseClasses;
partial model PartialSingleMassTransfer_dp
  "Base model of pressure-driven mass transfer"
  extends PartialSingleMassTransfer(
    redeclare final model MassTransfer = MassTransfer_dp);

  //
  // Definition of models describing the mass transfer
  //
  replaceable model MassTransfer_dp =
    SorpLib.Components.MassTransfers.TransportPhenomena.PressureDriven.ConstantCoefficient
    constrainedby
    SorpLib.Components.MassTransfers.TransportPhenomena.BaseClasses.PartiallInternalMassTransfer_dp(
      final massTransferProperties=massTransferProperties)
    "Mass transfer model"
    annotation (Dialog(tab="General",group="Mass Transfer", enable=not use_beta_input),
                choices(choice(redeclare model MassTransfer_dp =
            TransHeat.Components.MassTransfers.TransportPhenomena.PressureDriven.ConstantCoefficient
                         "Mass Transfer | Constant mass transfer coefficient for pressure-driven mass transfer"),
                       choice(redeclare model MassTransfer_dp =
            TransHeat.Components.MassTransfers.TransportPhenomena.PressureDriven.ConstantSpecificCoefficient
                         "Mass Transfer | Constant specific mass transfer coefficient for pressure-driven mass transfer"),
                       choice(redeclare model MassTransfer_dp =
            TransHeat.Components.MassTransfers.TransportPhenomena.PressureDriven.DarcyPackedBedSpheres
                         "Mass Transfer | Packed bed with spheres according to Darcy's law for pressure-driven mass transfer"),
                       choice(redeclare model MassTransfer_dp =
            TransHeat.Components.MassTransfers.TransportPhenomena.PressureDriven.DarcyPorousMedia
                         "Mass Transfer | Porous media according to Darcy's law for pressure-driven mass transfer"),
                       choice(redeclare model MassTransfer_dp =
            TransHeat.Components.MassTransfers.TransportPhenomena.PressureDriven.LaminarConnections
                         "Mass Transfer | Laminar flow trough connection for pressure-driven mass transfer")),
                 Evaluate=true,
                 HideResult=true);

  //
  // Definition of property record
  //
  TransportPhenomena.PropertyRecord.MassTransferProperties
    massTransferProperties(
      T_adsorbate_theoEqu=-1,
      T_adsorptive=T_adsorptive,
      d_adsorptive=d_adsorptive,
      eta_adsorptive=eta_adsorptive)
    "Record containing properties of mass transfer model if required";

equation
  //
  // Set driving potential
  //
  drivingForce_ = port_a.p - port_b.p
    "Pressure driven mass flow rate";

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(revisions="<html>
<ul>
  <li>
  January 18, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialSingleMassTransfer_dp;
