within SorpLib.Components.MassTransfers.TILMediaLibrary;
model MassTransfer_VLE_dx "Model of loading-driven mass transfer"
  extends BaseClasses.PartialSingleMassTransfer_dx(
    final type_Media=Internals.Types.MediaModel.TIL_VLE,
    redeclare final Connectors.TILMediaLibrary.VLEPort_a port_a(
      final vleFluidType=vleFluidType),
    redeclare final Connectors.TILMediaLibrary.VLEPort_b port_b(
      final vleFluidType=vleFluidType),
    redeclare replaceable model WorkingPair =
      Media.WorkingPair.SingleComponent.TIL_VLE.H2O_AQSOAZ02_Goldsworthy);

  //
  // Definition of parameters describing the medium
  //
  replaceable parameter TILMedia.VLEFluidTypes.TILMedia_Water vleFluidType
    constrainedby TILMedia.VLEFluidTypes.BaseVLEFluid
    "VLE media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

  //
  // Definition of media models
  //
  TILMedia.VLEFluid_ph stateProperties_act_portA(
    final vleFluidType=vleFluidType,
    final computeTransportProperties = true,
    final computeSurfaceTension=false,
    final p = port_a.p,
    final h = if avoid_events then noEvent(actualStream(port_a.h_outflow)) else
      actualStream(port_a.h_outflow),
    final xi = if avoid_events then noEvent(actualStream(port_a.xi_outflow)) else
      actualStream(port_a.xi_outflow)) if
    calculate_FluidProperties
    "Current state properties at port A";

  TILMedia.VLEFluid_ph stateProperties_act_portB(
    final vleFluidType=vleFluidType,
    final computeTransportProperties = true,
    final computeSurfaceTension=false,
    final p = port_b.p,
    final h = if avoid_events then noEvent(actualStream(port_b.h_outflow)) else
      actualStream(port_b.h_outflow),
    final xi = if avoid_events then noEvent(actualStream(port_b.xi_outflow)) else
      actualStream(port_b.xi_outflow)) if
    calculate_FluidProperties
    "Current state properties at port B";

  TILMedia.VLEFluid_ph stateProperties_in_portA(
    final vleFluidType=vleFluidType,
    final computeTransportProperties = true,
    final computeSurfaceTension=false,
    final p = port_a.p,
    final h = inStream(port_a.h_outflow),
    final xi = inStream(port_a.xi_outflow)) if
    massTransfer.calculate_FluidProperties
    "State properties at port A";

  TILMedia.VLEFluid_ph stateProperties_in_portB(
    final vleFluidType=vleFluidType,
    final computeTransportProperties = true,
    final computeSurfaceTension=false,
    final p = port_b.p,
    final h = inStream(port_b.h_outflow),
    final xi = inStream(port_b.xi_outflow)) if
    massTransfer.calculate_FluidProperties or
    calculate_equilibriumPropertiesInternally
    "State properties at port B";

  //
  // Definition of connectors for conditional removed models / variables
  //
protected
  Modelica.Blocks.Interfaces.RealInput T_B_theoEqu_calc(final unit="K")=
    stateProperties_in_portB.T if
    calculate_equilibriumPropertiesInternally
    "Equilibrium temperature of adsorbate at port B"
    annotation (HideResult=true);

  Modelica.Blocks.Interfaces.RealInput T_adsorptive_A_cal(final unit="K")=
    stateProperties_in_portA.T if massTransfer.calculate_FluidProperties
    "Temperature of adsorptive at port A"
    annotation (HideResult=true);
  Modelica.Blocks.Interfaces.RealInput T_adsorptive_B_cal(final unit="K")=
    stateProperties_in_portB.T if massTransfer.calculate_FluidProperties
    "Temperature of adsorptive at port B"
    annotation (HideResult=true);

  Modelica.Blocks.Interfaces.RealInput d_adsorptive_A_cal(final unit="kg/m3")=
    stateProperties_in_portA.d if massTransfer.calculate_FluidProperties
    "Density of adsorptive at port A"
    annotation (HideResult=true);
  Modelica.Blocks.Interfaces.RealInput d_adsorptive_B_cal(final unit="kg/m3")=
    stateProperties_in_portB.d if massTransfer.calculate_FluidProperties
    "Density of adsorptive at port B"
    annotation (HideResult=true);

  Modelica.Blocks.Interfaces.RealInput eta_adsorptive_A_cal(final unit="Pa.s")=
    stateProperties_in_portA.transp.eta if massTransfer.calculate_FluidProperties
    "Dynamic viscosity of adsorptive at port A"
    annotation (HideResult=true);
  Modelica.Blocks.Interfaces.RealInput eta_adsorptive_B_cal(final unit="Pa.s")=
    stateProperties_in_portB.transp.eta if massTransfer.calculate_FluidProperties
    "Dynamic viscosity of adsorptive at port B"
    annotation (HideResult=true);

equation
  //
  // Connections
  //
  connect(T_act_internal, T_B_theoEqu_calc);

  connect(T_adsorptive_A_internal, T_adsorptive_A_cal);
  connect(T_adsorptive_B_internal, T_adsorptive_B_cal);

  connect(d_adsorptive_A_internal, d_adsorptive_A_cal);
  connect(d_adsorptive_B_internal, d_adsorptive_B_cal);

  connect(eta_adsorptive_A_internal, eta_adsorptive_A_cal);
  connect(eta_adsorptive_B_internal, eta_adsorptive_B_cal);

  //
  // Annotations
  //
  annotation (Icon(graphics={
        Ellipse(
          extent={{80,62},{-40,-58}},
          lineColor={0,0,0},
          fillColor={175,175,175},
          fillPattern=FillPattern.Solid),
        Polygon(
          points={{-12,56},{-8,48},{-8,40},{-6,34},{-2,28},{6,18},{20,16},{52,16},
              {50,10},{40,10},{18,12},{16,8},{24,4},{40,2},{46,-2},{48,-8},{46,-18},
              {42,-24},{38,-32},{28,-36},{18,-38},{12,-38},{2,-34},{4,-30},{10,-34},
              {18,-34},{26,-32},{32,-26},{38,-20},{40,-12},{38,-6},{32,-4},{26,-2},
              {22,0},{16,2},{12,6},{14,0},{20,-6},{26,-14},{20,-14},{16,-6},{10,
              0},{8,4},{10,10},{6,14},{0,18},{-4,20},{-4,16},{-6,12},{-4,10},{-4,
              4},{-4,2},{-4,0},{-2,-2},{0,-4},{4,-10},{-4,-4},{-4,-8},{-4,-10},{
              -4,-18},{-10,-24},{-8,-8},{-6,-2},{-10,0},{-24,2},{-30,6},{-28,8},
              {-16,4},{-8,2},{-8,8},{-10,12},{-14,14},{-22,22},{-28,32},{-22,28},
              {-10,16},{-8,22},{-10,28},{-14,34},{-10,42},{-12,56}},
          lineColor={0,0,0},
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid,
          smooth=Smooth.Bezier),
        Text(
          extent={{-40,80},{-20,60}},
          lineColor={0,0,0},
          fillColor={255,255,255},
          fillPattern=FillPattern.None,
          textString="D",
          textStyle={TextStyle.Italic}),
        Line(
          points={{-24,66},{-18,62},{-12,54}},
          color={0,140,72},
          smooth=Smooth.Bezier,
          arrow={Arrow.None,Arrow.Filled},
          thickness=0.5),
        Line(
          points={{-10,52},{-10,44},{-6,30},{4,18},{14,10},{20,2},{34,-2},{44,-10},
              {40,-22},{28,-34},{12,-36},{4,-32}},
          color={0,140,72},
          thickness=0.5,
          smooth=Smooth.Bezier,
          arrow={Arrow.None,Arrow.Filled}),
        Ellipse(
          extent={{-12,54},{-10,52}},
          lineColor={0,140,72},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{4,-30},{6,-32}},
          lineColor={0,140,72},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-68,52},{-60,60}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-60,40},{-52,48}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-74,32},{-66,40}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-60,20},{-52,28}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-72,12},{-64,20}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-60,2},{-52,10}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-84,20},{-76,28}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-84,44},{-76,52}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-56,62},{-48,70}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-80,64},{-72,72}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-66,74},{-58,82}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-82,0},{-74,8}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-70,-6},{-62,2}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-56,-18},{-48,-10}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-74,-22},{-66,-14}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-88,-14},{-80,-6}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-86,-34},{-78,-26}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-64,-34},{-56,-26}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-48,-40},{-40,-32}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-76,-50},{-68,-42}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-60,-52},{-52,-44}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid),
        Ellipse(
          extent={{-86,-64},{-78,-56}},
          lineColor={28,108,200},
          lineThickness=0.5,
          fillColor={28,108,200},
          fillPattern=FillPattern.Solid)}), Diagram(graphics={Line(
          points={{-80,-40},{80,-40}},
          color={0,0,0},
          thickness=0.5,
          arrow={Arrow.None,Arrow.Filled}), Text(
          extent={{-80,-20},{80,-40}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillColor={0,255,255},
          fillPattern=FillPattern.Solid,
          textString="From gas to sorbent")}),
    Documentation(revisions="<html>
<ul>
  <li>
  January 18, 2021, by Mirko Engelpracht:<br/>
  Major revisions (e.g., object-oriented approach) after restructuring of the library.
  </li>
  <li>
  November 30, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
  <p>
    The Mass Transfer Diffusion model extends the <a href=\"modelica://SorpLib.Components.MassTransfer.Partial.PartialMassTransfer\">SorpLib.Components.MassTransfer.Partial.PartialMassTransfer</a>.<br>
    The Mass Transfer Diffusion model describes the mass transfer resistance caused by intra-particle resistances.<br>
    The Mass Transfer Diffusion model can be used to model an effective mass transfer resistance (e.g. LDF approach) but also to model detailled diffusion process (e.g., Knudsen diffsion or surface diffusion) 
    with spatial distribution of the particle using a finite volume approach. 
  </p>
<h4>Main equations</h4>
  <p>
    The mass flow <code>m&#775;</code> can be proportional to a pressure drop <code>&Delta;</code>p or to a loading difference (<i>x</i>-<i>x</i><sub>eq</sub>):
    <p align=\"center\"><i><code>m&#775;</code></i><sub>in</sub> = <i><code>&beta;</code></i> <i><code>&Delta;</code>p</i></p>
    <p align=\"center\"><i><code>m&#775;</code></i><sub>in</sub> = <i><code>&beta;</code></i> (<i>x</i>-<i>x</i><sub>eq</sub>)</p>
    For the mass transfer coefficient <i><code>&beta;</code></i>, different correlations are implemented based on the partial models
    <a href=\"modelica://SorpLib.Components.MassTransfer.MassTransferPhenomena.Partial.PartialMassTransfer_dp\">SorpLib.Components.MassTransfer.MassTransferPhenomena.Partial.PartialMassTransfer_dp</a>
    and <a href=\"modelica://SorpLib.Components.MassTransfer.MassTransferPhenomena.Partial.PartialMassTransfer_dx\">SorpLib.Components.MassTransfer.MassTransferPhenomena.Partial.PartialMassTransfer_dx</a>.
  </p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
  <p>
    Two adsorbent/adsorbate equilibrium models are used in Mass Transfer Diffusion model to determine the loading <i>x</i> and the equilibirum loading <i>x</i><sub>eq</sub>.
  </p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end MassTransfer_VLE_dx;
