within SorpLib.Components.MassTransfers.TILMediaLibrary.Tester;
model TestMassTransfer_VLE_dp
  "Tester for pressure-driven mass transfer model"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  MassTransfer_VLE_dp massTransferDiffusion(
    is_activelyCloseable=true,
    is_flapValve=true,
    is_flowAB=false,
    calculate_FluidProperties=true,
    use_beta_input=false,
    propertiesPosition=SorpLib.Internals.Types.PositionProperties.Average,
    redeclare model MassTransfer_dp =
        TransportPhenomena.PressureDriven.DarcyPackedBedSpheres)
                                                    "Mass transfer model"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}})));

  //
  // Definition of boundaries
  //
protected
  Modelica.Blocks.Sources.RealExpression specificEnthalpy(y=2.8e6 + 50*time)
    "Inpput for specific enthalpy"
    annotation (Placement(transformation(extent={{80,-10},{60,10}})));
  Modelica.Blocks.Sources.Sine sine(
    offset=1800,
    amplitude=300,
    freqHz=1/100)
    "Inputsignal for pressure at port A"
    annotation (Placement(transformation(extent={{-80,-10},{-60,10}})));

  Modelica.Blocks.Sources.Step step(startTime=250)
    "Indicator for status of mass transport"
    annotation (Placement(transformation(extent={{-36,-60},{-16,-40}})));

  Boundaries.TILMediaLibrary.VLEBoundary vleBoundaryInlet1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    use_pInput=true,
    h=2.8e6)
    "Inlet conditions"
    annotation (Placement(transformation(extent={{-44,-10},{-36,10}})));

  Boundaries.TILMediaLibrary.VLEBoundary vleBoundaryOutlet1(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    p(displayUnit="kPa") = 1900,
    use_hInput=true)
                  "Outlet conditions"
    annotation (Placement(transformation(extent={{44,-10},{36,10}})));

equation
  //
  // Connections
  //
  connect(step.y, massTransferDiffusion.open_input)
    annotation (Line(points={{-15,-50},{0,-50},{0,-10}}, color={0,0,127}));
  connect(sine.y, vleBoundaryInlet1.p_input) annotation (Line(points={{-59,0},{-50,
          0},{-50,7},{-40.48,7}}, color={0,0,127}));
  connect(vleBoundaryInlet1.port, massTransferDiffusion.port_a) annotation (
      Line(
      points={{-40,0},{-10,0}},
      color={0,140,72},
      thickness=1));
  connect(massTransferDiffusion.port_b, vleBoundaryOutlet1.port) annotation (
      Line(
      points={{10,0},{40,0}},
      color={0,140,72},
      thickness=1));
  connect(vleBoundaryOutlet1.h_input, specificEnthalpy.y) annotation (Line(
        points={{40.48,-4},{50,-4},{50,0},{59,0}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=500), Documentation(revisions="<html>
<ul>
  <li>
  January 18, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestMassTransfer_VLE_dp;
