within SorpLib.Components.MassTransfers.TransportPhenomena.LoadingDriven;
model ConstantSpecificCoefficient
  "Mass Transfer | Constant specific mass transfer coefficient for loading-driven mass transfer"
  extends BaseClasses.PartiallInternalMassTransfer_dx(
    final calculate_FluidProperties=false);

  //
  // Definition of parameters
  //
  parameter Real constantSpecificCoefficient(final unit="kg/(s.m2)")= 1e-7
    "Constant specific mass transfer coefficient for loading-driven mass transfer"
    annotation (Dialog(tab="General", group="Mass transfer"),
                HideResult=true);
  parameter Modelica.SIunits.Area massTransferArea = 1
    "Mass transfer area"
    annotation (Dialog(tab="General", group="Mass transfer"),
                HideResult=true);

equation
  //
  // Calculation of mass transfer coefficient
  //
  beta = constantSpecificCoefficient*massTransferArea;

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 18, 2021, by Mirko Engelpracht:<br/>
  Minor revisions after restructuring of the library.
  </li>
  <li>
  November 30, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>
  This simple mass transfer model provides a constant specific mass transfer coefficient.
</p>
<h4>Main equations</h4>
<p>
  The mass transfer according to the Linear Driving Force apporach is determined by the following equation:
  <p align=\"center\"> <i><code>m&#775;</code></i> = <code>&beta;</code> <i>A</i> (<i>x</i> - <i>x</i><sub>eq</sub>) </p>
  where <code>&beta;</code> is a constant specific mass transfer coefficient and <i>A</i> is the mass transfer area.<br>
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end ConstantSpecificCoefficient;
