﻿within SorpLib.Components.MassTransfers.TransportPhenomena.LoadingDriven;
model Glueckauf
  "Mass Transfer | Glückauf-approach for loading-driven mass transfer"
  extends BaseClasses.PartiallInternalMassTransfer_dx(
    final calculate_FluidProperties=false);

  //
  // Definition of parameters
  //
  parameter Modelica.SIunits.Mass m_sorbent(start=2) = 2.5
    "Mass of dry sorbent material"
    annotation (Dialog(tab="General", group="Mass transfer"),
                HideResult=true);
  parameter Modelica.SIunits.Radius r_sorbent = 0.001
    "Radius of sorbent material"
    annotation (Dialog(tab="General", group="Mass transfer"),
                HideResult=true);
  parameter Real D(unit="m2/s") = 1e-10
    "Diffusion coefficient"
    annotation (Dialog(tab="General", group="Mass transfer"),
                HideResult=true);

equation
  //
  // Calculation of mass transfer coefficient
  //
  beta = 15*m_sorbent*D/r_sorbent^2;

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 18, 2021, by Mirko Engelpracht:<br/>
  Minor revisions after restructuring of the library.
  </li>
  <li>
  November 30, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>
  This mass transfer model was derived by Glueckauf (1955) for spheres.
</p>
<h4>Main equations</h4>
<p>
  The mass transfer according to the Linear Driving Force apporach is determined by the following equation:
  <p align=\"center\"> <i><code>m&#775;</code></i> = 15 <i>D</i> / <i>r</i><sup>2</sup> * <i>m</i><sub>sor</sub> (<i>x</i> - <i>x</i><sub>eq</sub>) </p>
  where <i>D</i> is the diffusion coefficient and <i>r</i> is the particle radius.<br>
</p>
<h4>Assumptions and limitations</h4>
  <p>
    This correlation is derived for spheres.
  </p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<ul>
  <li>Glueckauf, E. Theory of Chromatography. Part 10: Formulae for Diffusion into Spheres and their Application to Chromatography. Transactions of the Faraday Society, 1955, 51(11), 1540-1551.</li>
</ul>
</html>"));
end Glueckauf;
