within SorpLib.Components.MassTransfers.TransportPhenomena.PressureDriven;
model ConstantCoefficient
  "Mass Transfer | Constant mass transfer coefficient for pressure-driven mass transfer"
  extends BaseClasses.PartiallInternalMassTransfer_dp(
    final calculate_FluidProperties=false);

  //
  // Definition of parameters
  //
  parameter Real constantCoefficient(final unit="m.s")= 1e-7
    "Constant mass transfer coefficient for pressure-driven mass transfer"
    annotation (Dialog(tab="General", group="Mass transfer"),
                HideResult=true);

equation
  //
  // Calculation of mass transfer coefficient
  //
  beta = constantCoefficient;

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 18, 2021, by Mirko Engelpracht:<br/>
  Minor revisions after restructuring of the library.
  </li>
  <li>
  November 30, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>
This simple transfer model calculates the mass flow based on the pressure 
differnce with a constant transfer coefficient.
</p>
<h4>Main equations</h4>
<p>
  <p align=\"center\"><i><code>m&#775;</code></i> = <i><code>&beta;</code></i> 
  <i><code>&Delta;</code>p</i></p>
  <p>where <i><code>&beta;</code></i> is a constant parameter</p>
</p>
<h4>Assumptions and limitations</h4>
<p>
  In general, the mass transfer coefficient depends on fluid properties. Thus, 
  a constant coefficient is only an approximation.
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end ConstantCoefficient;
