within SorpLib.Components.OpenAdsorbers.BaseModels;
partial model PartialOpenAdsorber
  "Base model for all open adsorber models"

  //
  // Definition of general parameters
  //
  parameter Integer no_cells(min=2)=5
    "Discretization number"
    annotation (Dialog(tab = "General", group = "Discretisation"),
                Evaluate=true,
                HideResult=true);

  replaceable parameter OpenAdsorbers.Geometry.OpenAdsorber
    adsorberGeometry constrainedby OpenAdsorbers.Geometry.OpenAdsorber
    "Geometry of open adsorber"
    annotation (Dialog(tab="General", group="Geometry"),
                choicesAllMatching = true);

  replaceable model MassTransportCoefficient =
    SorpLib.Components.MassTransfers.TransportPhenomena.OpenAdsorber.PackedBed_Kast1988
    constrainedby
    MassTransfers.TransportPhenomena.BaseClasses.PartialExternalMassTransferOpenAdsorber_dp
    "Mass transfer model to calculate mass transfer between working pair and gas"
    annotation (Dialog(tab = "Transport Phenomena", group = "Mass Transfer"),
                choices(choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.MassTransfers.TransportPhenomena.OpenAdsorber.ConstantCoefficient
                          "Open adsorber | Constant mass transfer coefficient for pressure-driven mass transfer"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.MassTransfers.TransportPhenomena.OpenAdsorber.ConstantSpecificCoefficient
                          "Open adsorber | Constant specific mass transfer coefficient for pressure-driven mass transfer"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.MassTransfers.TransportPhenomena.OpenAdsorber.PackedBed_Kast1988
                          "Open adsorber | Packed bed according to Kast")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferCoefficient_gasToWorkingPair =
    SorpLib.Components.HeatTransfers.TransportPhenomena.External.OpenAdsorber.Gas_PackedBed_Kast1988
    constrainedby
    HeatTransfers.BaseClasses.PartialExternalHeatTransferCoefficientOpenAdsorber
    "Heat transfer model for heat transfer coefficient between working pair
    and gas cells"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.OpenAdsorber.ConstantAlpha
                          "Open adsorber | Constant alpha for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.OpenAdsorber.ConstantAlphaA
                          "Open adsorber | Constant alphaA for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.OpenAdsorber.Gas_PackedBed_Kast1988
                          "Open adsorbers | Packed bed: sorbent <-> gas according to Kast")),
                Evaluate=true,
                HideResult = true);

  replaceable model HeatTransferCoefficient_gasToCasing =
    SorpLib.Components.HeatTransfers.TransportPhenomena.External.OpenAdsorber.Wall_PackedBed_Kast1988
    constrainedby
    HeatTransfers.BaseClasses.PartialExternalHeatTransferCoefficientOpenAdsorber
    "Heat transfer model for heat transfer coefficient between casing and gas
     cells"
    annotation (Dialog(tab = "Transport Phenomena", group = "Heat Transfer"),
                choices(choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.OpenAdsorber.ConstantAlpha
                          "Open adsorber | Constant alpha for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.OpenAdsorber.ConstantAlphaA
                          "Open adsorber | Constant alphaA for each cell"),
                        choice(redeclare model HeatTransferModel_TubeSide =
            TransHeat.Components.HeatTransfers.TransportPhenomena.External.OpenAdsorber.Wall_PackedBed_Kast1988
                          "Open adsorber | Packed bed: casing <-> gas according to Kast")),
                Evaluate=true,
                HideResult = true);

  parameter Internals.Types.PositionProperties propertiesPosition_pressureDrop=SorpLib.Internals.Types.PositionProperties.PortA
    "Tye defining calculation approach for fluid properties if needed"
    annotation (Dialog(tab="Transport Phenomena", group="Pressure Drop"),
                Evaluate=true,
                HideResult = true);

  replaceable model PressureDropModel =
    SorpLib.Components.Fittings.HydraulicResistors.TransportPhenomena.OpenAdsorber.PackedBed_Kast1988
    constrainedby
    SorpLib.Components.Fittings.HydraulicResistors.BaseClasses.PartialPressureDropOpenAdsorbers
    "Pressure drop model"
    annotation (Dialog(tab="Transport Phenomena", group="Pressure Drop"),
                Evaluate=true,
                HideResult = true,
                choices(choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.OpenAdsorber.ZeroPressureDrop
                          "Open adsorber | Zero pressure drop (i.e, 0 Pa)"),
                        choice(redeclare model PressureDropModel =
            TransHeat.Components.Fittings.HydraulicResistors.TransportPhenomena.OpenAdsorber.PackedBed_Kast1988
                          "Open adsorber | Packed bed according to Kast")));

  //
  // Definition of parameters describing the medium
  //
  parameter Integer no_components = 2
    "Number of components in the gas mixture"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);
  parameter Integer index_adsorptiv = 1
    "Index of adsorptiv that is adsorbed or desorbed in gas mixture"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);

  replaceable model WorkingPair =
    SorpLib.Media.WorkingPair.SingleComponent.BaseClasses.PartialSingleWPair
    constrainedby
    SorpLib.Media.WorkingPair.SingleComponent.BaseClasses.PartialSingleWPair
    "Working pair model"
    annotation (Dialog(tab="Media",group="Working Pair"),
                choicesAllMatching = true,
                Evaluate=true,
                HideResult=true);
  parameter Modelica.SIunits.Mass m_sorbent = 2.5
    "Mass of dry sorbent"
    annotation (Dialog(tab="Media",group="Working Pair"),
                HideResult=true);

  //
  // Definition of parameters describing the initialisation
  //
  parameter Modelica.SIunits.Pressure pInitial_gas= 1e5
    "Initial value for pressure"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Gas"),
                HideResult = true);
  parameter Modelica.SIunits.SpecificEnthalpy hInitial_gas= 84011
    "Initial value for specific enthalpy"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Gas",
                       enable=state_phxi),
                HideResult = true);

  parameter Modelica.SIunits.MassFraction[no_components-1] xiInitial_gas=
    fill(1/no_components, no_components-1)
    "Initial values for independent mass fractions"
    annotation (Dialog(tab="Initialisation", group="Initial Values - Gas"),
                HideResult = true);

  parameter Real xInitial(unit="kg/kg") = 0.2
    "Initial value for equilibrium loading"
    annotation (Dialog(group = "Initial Values - Working Pair", tab = "Initialisation"),
                HideResult=true);
  parameter Modelica.SIunits.Temperature TInitial_WPair = 298.15
    "Initial value for equilibrium temperature of adsorbate"
    annotation (Dialog(group = "Initial Values - Working Pair", tab = "Initialisation"),
                HideResult=true);

  parameter Modelica.SIunits.Temperature TInitial_casing = 293.15
    "Initial value for temperature"
    annotation (Dialog(group = "Initial Values - Casing", tab = "Initialisation"),
                HideResult = true);

  parameter Modelica.SIunits.Pressure pStart_WPair = 5000
    "Initial value for equilibrium pressure of adsorbate"
    annotation (Dialog(group = "Start Values", tab = "Initialisation"),
                HideResult=true);
  parameter Modelica.SIunits.Density rhoStart_gas= 1000
    "Start value for density"
    annotation (Dialog(tab="Initialisation", group="Start Values"),
                HideResult = true);
  parameter Modelica.SIunits.MassFlowRate m_flowInitial = 1e-4
    "Start value for mass flow rate"
    annotation (Dialog(tab="Initialisation", group="Start Values"),
                HideResult = true);

  //
  // Definition of parameters describing advanced options
  //
  parameter Internals.Types.BalanceEquations type_overallMassBalance=
    Internals.Types.BalanceEquations.Transient_FixedInitial
    "Handling of the overall mass equation and corresponding initialisation"
    annotation(Dialog(tab = "Advanced", group = "Conservation Equations"),
                Evaluate=true,
                HideResult = true);
  parameter Internals.Types.BalanceEquations type_independentMassBalances=
    Internals.Types.BalanceEquations.SteadyState_FreeInitial
    "Handling of the independent mass equations and corresponding initialisations"
    annotation(Dialog(tab = "Advanced", group = "Conservation Equations"),
                Evaluate=true,
                HideResult = true);
  parameter Internals.Types.BalanceEquations type_energyBalance=
    Internals.Types.BalanceEquations.Transient_FixedInitial
    "Handling of the energy equation and corresponding initialisation"
    annotation(Dialog(tab = "Advanced", group = "Conservation Equations"),
                Evaluate=true,
                HideResult = true);

  parameter Boolean avoid_events = true
    "= true, if events are avoid by using noEvent()-operator"
    annotation (Dialog(tab = "Advanced", group = "Numerics"),
                Evaluate=true,
                HideResult = true);

  //
  // Definition of constants
  //
protected
  constant Internals.Types.MediaModel type_Media=
    Internals.Types.MediaModel.Modelica_VLE
    "Type required to check consistency of media models"
    annotation (HideResult=true);

  //
  // Definition of models
  //
public
  replaceable Cells.BaseClasses.PartialWorkingPairCell[no_cells]
    workingPair(
    each final no_components=1,
    each final m_sorbent=m_sorbent/no_cells,
    each final TInitial=TInitial_WPair,
    each final type_massBalance=type_overallMassBalance,
    each final type_energyBalance=type_energyBalance,
    each final avoid_events=avoid_events)
    "Model of working pair"
    annotation (Placement(transformation(extent={{-10,-90},{10,-70}})));

  replaceable Cells.BaseClasses.PartialGasCell[no_cells] gas(
    each final cellGeometry(
      final hydraulicDiameter=adsorberGeometry.d_hydraulic,
      final length=adsorberGeometry.length/no_cells,
      final hydraulicCrossSectionalArea=adsorberGeometry.innerCrossSectionalArea,
      final heatTransferArea=adsorberGeometry.innerHeatTransferArea/no_cells,
      final volume=(adsorberGeometry.innerVolume - adsorberGeometry.bedVolume)/
          no_cells,
      final nParallelHydraulicFlows=1),
    each final no_components=no_components,
    each final calc_propertyRecord=Modelica.Math.BooleanVectors.anyTrue(
        massTransportCoefficient.calculate_FluidProperties) or
        Modelica.Math.BooleanVectors.anyTrue(
        heatTransferCoefficient_gasToWorkingPair.calc_propertyRecord) or
        Modelica.Math.BooleanVectors.anyTrue(
        heatTransferCoefficient_gasToCasing.calc_propertyRecord),
    each final pInitial=pInitial_gas,
    each final hInitial=hInitial_gas,
    each final xiInitial=xiInitial_gas,
    each final m_flowInitial=m_flowInitial,
    each final rhoStart=rhoStart_gas,
    each final type_overallMassBalance=type_overallMassBalance,
    each final type_independentMassBalances=type_independentMassBalances,
    each final type_energyBalance=type_energyBalance,
    each final neglectTermVp=false,
    each final avoid_events=avoid_events,
    each final index_adsorptiv=index_adsorptiv)
    "Model of gas cell"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}})));

  replaceable Cells.BaseClasses.PartialWallCell[no_cells] casing(
    each final cellGeometry(
      final length_WE=adsorberGeometry.length_heatTransfer/no_cells,
      final length_NS=adsorberGeometry.wallThickness_casing,
      final crossSectionalArea=adsorberGeometry.outerCrossSectionalArea -
          adsorberGeometry.innerCrossSectionalArea,
      final volume=adsorberGeometry.wallVolume_casing/no_cells),
    each final balancingWallElement=SorpLib.Internals.Types.BalancingWallElement.NoResistances,
    redeclare each final model HeatTransferModel_NS =
        HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR,
    redeclare each final model HeatTransferModel_WE =
        HeatTransfers.TransportPhenomena.Internal.Wall.ConstantR,
    each final TInitial=TInitial_casing,
    each final type_energyBalance=SorpLib.Internals.Types.BalanceEquations.Transient_FreeInitial)
    "Casing of open adsorber"
    annotation (Placement(transformation(extent={{-10,60},{10,80}})));

  replaceable MassTransfers.BaseClasses.PartialMassTransfer[no_cells] massTransfer(
    each final is_activelyCloseable=false,
    each final is_flapValve=false,
    each final calculate_FluidProperties=false,
    each final use_beta_input=true,
    each final no_components=1,
    each final avoid_events=avoid_events)
    "Mass transfer model describing mass transfer between gas and working pair"
    annotation (Placement(transformation(extent={{-10,-10},{10,10}},
        rotation=270,
        origin={-30,-50})));

  HeatTransfers.HeatTransfer[no_cells] heatTransfer_gasToWorkingPair(
    each final n_A=1,
    each final n_B=1,
    each final use_alphaA_input=true)
    "Heat transfer model describing heat transfer between gas and working pair"
    annotation (Placement(transformation(
        extent={{-10,4},{10,-4}},
        rotation=90,
        origin={30,-50})));

  HeatTransfers.HeatTransfer[no_cells] heatTransfer_gasToCasing(
    each final n_A=1,
    each final n_B=1,
    each final use_alphaA_input=true)
    "Heat transfer model describing heat transfer between gas and casing"
    annotation (Placement(transformation(
        extent={{-10,-4},{10,4}},
        rotation=90,
        origin={0,40})));

  replaceable
    Fittings.HydraulicResistors.BaseClasses.PartialHydraulicResistorOpenAdsorbers
    hydraulicResistor_a(
    final no_components=no_components,
    final propertiesPosition=propertiesPosition_pressureDrop,
    final m_flowInitial=m_flowInitial,
    final avoid_events=avoid_events,
    redeclare final model PressureDropOpenAdsorber = PressureDropModel,
    each final cellGeometry(
      final d_inner=adsorberGeometry.d_hydraulic,
      final length=adsorberGeometry.length/no_cells,
      final length_heatTransfer=adsorberGeometry.length_heatTransfer/no_cells,
      final psi=adsorberGeometry.psi,
      final innerCrossSectionalArea=adsorberGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=adsorberGeometry.innerHeatTransferArea/
          no_cells))    "Hydraulic resistor at port a"
    annotation (Placement(transformation(extent={{-60,-4},{-40,4}})));

  replaceable
    Fittings.HydraulicResistors.BaseClasses.PartialHydraulicResistorOpenAdsorbers
    [no_cells - 1] hydraulicResistors(
      each final no_components=no_components,
      each final propertiesPosition=propertiesPosition_pressureDrop,
      each final m_flowInitial=m_flowInitial,
      each final avoid_events=avoid_events,
    redeclare each final model PressureDropOpenAdsorber = PressureDropModel,
    each final cellGeometry(
      final d_inner=adsorberGeometry.d_hydraulic,
      final length=adsorberGeometry.length/no_cells,
      final length_heatTransfer=adsorberGeometry.length_heatTransfer/no_cells,
      final psi=adsorberGeometry.psi,
      final innerCrossSectionalArea=adsorberGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=adsorberGeometry.innerHeatTransferArea/
          no_cells))                         "Hydraulic resistors between gas cells"
    annotation (Placement(transformation(extent={{-10,-4},{10,4}},
        rotation=180,
        origin={0,-30})));

  replaceable
    Fittings.HydraulicResistors.BaseClasses.PartialHydraulicResistorOpenAdsorbers
    hydraulicResistor_b(
      final no_components=no_components,
    final propertiesPosition=propertiesPosition_pressureDrop,
    final m_flowInitial=m_flowInitial,
    final avoid_events=avoid_events,
    redeclare final model PressureDropOpenAdsorber = PressureDropModel,
    each final cellGeometry(
      final d_inner=adsorberGeometry.d_hydraulic,
      final length=adsorberGeometry.length/no_cells,
      final length_heatTransfer=adsorberGeometry.length_heatTransfer/no_cells,
      final psi=adsorberGeometry.psi,
      final innerCrossSectionalArea=adsorberGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=adsorberGeometry.innerHeatTransferArea/
          no_cells))    "Hydraulic resistor at port b"
    annotation (Placement(transformation(extent={{40,-4},{60,4}})));

  MassTransportCoefficient[no_cells] massTransportCoefficient(
      each final no_cells_gas=no_cells, each final cellGeometry(
      final d_inner=adsorberGeometry.d_hydraulic,
      final length=adsorberGeometry.length/no_cells,
      final length_heatTransfer=adsorberGeometry.length_heatTransfer/no_cells,
      final psi=adsorberGeometry.psi,
      final innerCrossSectionalArea=adsorberGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=adsorberGeometry.innerHeatTransferArea/
          no_cells,
      final d_particle=adsorberGeometry.d_particle,
      final A_particle_surface=adsorberGeometry.particleSurface))
    "Model to calculate mass transport coefficient between gas and sorbent"
    annotation (Placement(transformation(extent={{-68,-60},{-48,-40}})));

  HeatTransferCoefficient_gasToWorkingPair[no_cells]
    heatTransferCoefficient_gasToWorkingPair(
      each final no_cells_gas=no_cells, each final cellGeometry(
      final d_inner=adsorberGeometry.d_hydraulic,
      final length=adsorberGeometry.length/no_cells,
      final length_heatTransfer=adsorberGeometry.length_heatTransfer/no_cells,
      final psi=adsorberGeometry.psi,
      final innerCrossSectionalArea=adsorberGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=adsorberGeometry.innerHeatTransferArea/
          no_cells,
      final d_particle=adsorberGeometry.d_particle,
      final A_particle_surface=adsorberGeometry.particleSurface))
    "Model to calculate heat transfer coefficient between gas and working pair"
    annotation (Placement(transformation(extent={{56,-56},{44,-44}})));

 HeatTransferCoefficient_gasToCasing[no_cells]
    heatTransferCoefficient_gasToCasing(
      each final no_cells_gas=no_cells, each final cellGeometry(
      final d_inner=adsorberGeometry.d_hydraulic,
      final length=adsorberGeometry.length/no_cells,
      final length_heatTransfer=adsorberGeometry.length_heatTransfer/no_cells,
      final psi=adsorberGeometry.psi,
      final innerCrossSectionalArea=adsorberGeometry.innerCrossSectionalArea,
      final innerHeatTransferArea=adsorberGeometry.innerHeatTransferArea/
          no_cells,
      final d_particle=adsorberGeometry.d_particle,
      final A_particle_surface=adsorberGeometry.particleSurface))
    "Model to calculate heat transfer coefficient between gas and casing"
    annotation (Placement(transformation(extent={{-26,34},{-14,46}})));

  //
  // Definition of connectors
  //
  replaceable Connectors.BaseClasses.PartialMediaConnector gas_a(
    final no_components=no_components,
    m_flow(start = m_flowInitial))
    "Inlet port of gas mixture at design direction"
    annotation (Placement(transformation(extent={{-90,-10},{-70,10}})));

  replaceable Connectors.BaseClasses.PartialMediaConnector gas_b(
    final no_components=no_components,
    m_flow(start = -m_flowInitial))
    "Outlet port of gas mixture at design direction"
    annotation (Placement(transformation(extent={{70,-10},{90,10}})));

  Connectors.Thermal.Port_a[no_cells] heatPort "Heat port from casing to environment"
    annotation (Placement(transformation(extent={{-10,90},{10,110}})));

equation
  //
  // Connections of fluid ports
  //
  connect(gas_a, hydraulicResistor_a.port_a) annotation (Line(
      points={{-80,0},{-60,0}},
      color={244,125,35},
      thickness=1));
  connect(hydraulicResistor_a.port_b, gas[1].port_a) annotation (Line(
      points={{-40.2,0},{-7,0}},
      color={244,125,35},
      thickness=1));

  for i in 1:(no_cells-1) loop
    connect(gas[i].port_b, hydraulicResistors[i].port_a) annotation (Line(
        points={{5.2,0},{20,0},{20,-30},{10,-30}},
        color={244,125,35},
        thickness=1));
    connect(hydraulicResistors[i].port_b, gas[i+1].port_a) annotation (Line(
        points={{-9.8,-30},{-20,-30},{-20,0},{-7,0}},
        color={244,125,35},
        thickness=1));
  end for;

  connect(hydraulicResistor_b.port_a, gas[no_cells].port_b) annotation (Line(
      points={{40,0},{5.2,0}},
      color={244,125,35},
      thickness=1));
  connect(hydraulicResistor_b.port_b, gas_b) annotation (Line(
      points={{59.8,0},{70,0},{70,0},{80,0}},
      color={244,125,35},
      thickness=1));

  //
  // Connections of heat ports
  //
  connect(casing.heatPort_N, heatPort) annotation (Line(
      points={{0,80},{0,100}},
      color={238,46,47},
      thickness=1));
  connect(heatTransfer_gasToCasing.heatPort_b[1], casing.heatPort_S) annotation (
      Line(
      points={{0,50},{0,60}},
      color={238,46,47},
      thickness=1));
  connect(gas.heatPort, heatTransfer_gasToCasing.heatPort_a[1]) annotation (Line(
      points={{0,6},{0,30}},
      color={238,46,47},
      thickness=1));
  connect(heatTransfer_gasToWorkingPair.heatPort_b[1], gas.heatPort_adsorptiv)
    annotation (Line(
      points={{30,-40},{30,-20},{3,-20},{3,-6}},
      color={238,46,47},
      thickness=1));
  connect(workingPair.heatPort_b, heatTransfer_gasToWorkingPair.heatPort_a[1])
    annotation (Line(
      points={{0,-74},{0,-64},{30,-64},{30,-60}},
      color={238,46,47},
      thickness=1));

  //
  // Connections of signals
  //
  connect(heatTransferCoefficient_gasToCasing.alphaA, heatTransfer_gasToCasing.alphaA_input)
    annotation (Line(points={{-13.4,40},{-4,40}}, color={0,0,127}));
  connect(heatTransferCoefficient_gasToWorkingPair.alphaA,
    heatTransfer_gasToWorkingPair.alphaA_input)
    annotation (Line(points={{43.4,-50},{34,-50}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)));
end PartialOpenAdsorber;
