within SorpLib.Components.OpenAdsorbers.Geometry;
record OpenAdsorber
  "Record minimum number of geometric definitions of open adsorber"
  extends Internals.ClassTypes.Record;

  //
  // Definition of parameters
  //
  parameter Real psi(final unit="1")=0.34
    "Void percentage of packed bed";

  parameter Modelica.SIunits.Length wallThickness_casing = 0.01
    "Thickness of adsorber casing";
  parameter Modelica.SIunits.Area innerHeatTransferArea_casing = 1
    "Inner heat transfer area of adsorber casing";
  parameter Modelica.SIunits.Area outerHeatTransferArea_casing = 1
    "Outer heat transfer area of adsorber casing";
  parameter Modelica.SIunits.Volume wallVolume_casing = 0.02
    "Wall volume of adsorber";

  parameter Modelica.SIunits.Diameter d_particle = 0.0009
    "Diameter of sorbent material";
  parameter Modelica.SIunits.Diameter d_hydraulic = 0.1
    "Inner hydraulic diameter of adsorber";

  parameter Modelica.SIunits.Length length = 1
    "Total length of adsorber";
  parameter Modelica.SIunits.Length length_heatTransfer = length
    "Length of adsorber available for heat transfer on sorbent-side 
     and for casing N-S direction";

  parameter Modelica.SIunits.Area innerCrossSectionalArea=
    Modelica.Constants.pi/4 * d_hydraulic^2
    "Inner cross-sectional area of adsorber";
  parameter Modelica.SIunits.Area outerCrossSectionalArea=
    Modelica.Constants.pi/4 * (d_hydraulic+2*wallThickness_casing)^2
    "Outer cross-sectional area of adsorber";

  parameter Modelica.SIunits.Volume innerVolume=
    innerCrossSectionalArea * length
    "Inner adsorber volume";
  parameter Modelica.SIunits.Volume outerVolume=
    outerCrossSectionalArea * length
    "Outer adsorber volume";

  parameter Modelica.SIunits.Area innerHeatTransferArea=
    Modelica.Constants.pi * d_hydraulic * length_heatTransfer
    "Inner heat transfer area of adsorber";
  parameter Modelica.SIunits.Area outerHeatTransferArea=
    Modelica.Constants.pi * (d_hydraulic+2*wallThickness_casing) *
    length_heatTransfer
    "Outer heat transfer area of adsorber";

  //
  // Definition of final parameters
  //
  final parameter Modelica.SIunits.Volume bedVolume = innerVolume*(1-psi)
    "Volume of packed bed (i.e., = innerVolume if no gas is available)";
  final parameter Modelica.SIunits.Volume particleVolume=
    (Modelica.Constants.pi/6)*(d_particle)^3
    "Volume of one particle";
  final parameter Real no_particle = bedVolume/particleVolume
    "Number of particles";

  final parameter Modelica.SIunits.Area particleSurface=
    no_particle*Modelica.Constants.pi*(d_particle)^2
    "Total surface of particles";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 19, 2021, by Mirko Engelpracht:<br/>
  First implementation including major revisions after restructuring of the library.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end OpenAdsorber;
