within SorpLib.Components.PhaseSeperators.ModelicaMediaLibrary;
model SinglePhaseSeperator
  "Phase seperator of pure fluid using the Modelica.Media library"
  extends BaseClasses.PartialSinglePhaseSeperator(
    final type_Media=Internals.Types.MediaModel.Modelica_VLE,
    redeclare final Connectors.ModelicaMediaLibrary.VLEPort_a liquidPort(
      redeclare each final package Medium = Medium),
    redeclare final Connectors.ModelicaMediaLibrary.VLEPort_a vaporPort(
      redeclare each final package Medium = Medium));

  //
  // Definition of parameters
  //
  replaceable package Medium =
      Modelica.Media.Water.WaterIF97_ph
    constrainedby Modelica.Media.Interfaces.PartialMedium(
      smoothModel = avoidEvents)
    "VLE media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

  //
  // Definition of media models
  //
  Medium.SaturationProperties satProperties = Medium.setSat_T(T)
    "Record describing current thermodynamic state of homogeneous phase
     seperator: Saturation properties"
    annotation (HideResult = true);
  Medium.ThermodynamicState stateProperties = Medium.setState_dT(rho, T)
    "Record describing current thermodynamic state of homogeneous phase
     seperator: Other properties"
    annotation (HideResult = true);

equation
  //
  // Assertations
  //
  assert(no_components==1,
    "Error in phase seperator model: This model is only valid for
     one component!");

  if type_energyBalance ==
    Internals.Types.BalanceEquations.SteadyState_FreeInitial then
    assert(type_overallMassBalance ==
      Internals.Types.BalanceEquations.SteadyState_FreeInitial,
      "Steady-state energy balance is only allowed in combination with
       steady-state mass balance!");
   end if;

  //
  // Passing state variables
  //
  p = Medium.saturationPressure_sat(satProperties)
    "Pressure of fluid in phase seperator";
  h = h_liq + q * (h_vap - h_liq)
    "Specific enthalpy of fluid in phase seperator";

  cv = Medium.specificHeatCapacityCv(stateProperties)
    "Specific heat capacity at constant volume of fluid in phase seperator";

  rho_liq = Medium.bubbleDensity(satProperties)
    "Bubble density of fluid in phase seperator";
  rho_vap = Medium.dewDensity(satProperties)
    "Dew density of fluid in phase seperator";

  h_liq = Medium.bubbleEnthalpy(satProperties)
    "Bubble density of fluid in phase seperator";
  h_vap = Medium.dewEnthalpy(satProperties)
    "Dew density of fluid in phase seperator";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 13, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end SinglePhaseSeperator;
