within SorpLib.Components.PhaseSeperators.ModelicaMediaLibrary.Tester;
model TestSinglePhaseSeperator "Model to test phase seperator of a pure fluid"
  extends Modelica.Icons.Example;

  //
  // Definition of models
  //
  SinglePhaseSeperator singlePhaseSeperator(
      nPorts_Liquid=1, nPorts_Vapor=1)
      "Phase seperator model"
      annotation (
      Placement(transformation(extent={{-10,-10},{10,10}})));

  //
  // Definition of boundaries
  //
protected
  Boundaries.Thermal.HeatSource heatSource(
    boundaryType=SorpLib.Internals.Types.BoundaryThermal.HeatFlow,
    use_QFlowInput=true,
    Q_flow=-250) "Heat source boundary" annotation (
      Placement(transformation(extent={{30,-10},{10,10}})));

  Boundaries.ModelicaMediaLibrary.VLEBoundary
    liquidSource(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    use_mFlowInput=true,
    m_flow=-0.0001,
    h=0.5e6,
    T=303.15) "Liquid port boundary" annotation (
      Placement(transformation(extent={{-30,-40},{-10,-20}})));

  Boundaries.ModelicaMediaLibrary.VLEBoundary vaporPort(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    boundaryType_S=SorpLib.Internals.Types.BoundaryStream.SpecificEnthalpy,
    use_mFlowInput=true,
    m_flow=-0.0001,
    h=1e6,
    T=303.15) "Vapor port boundary" annotation (
      Placement(transformation(extent={{-30,20},{-10,40}})));

  Modelica.Blocks.Sources.Ramp input_heatFlow(
    height=-350,
    duration=250,
    startTime=250)
    "Input for heat flow"
    annotation (Placement(transformation(
        extent={{4,-4},{-4,4}},
        rotation=0,
        origin={40,0})),   HideResult=true);
  Modelica.Blocks.Sources.Trapezoid input_liquidPort(
    amplitude=-0.0001,
    rising=250,
    width=400,
    falling=250,
    period=950,
    startTime=50) "Input for liquid port boundary"
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={-40,-30})), HideResult=true);
  Modelica.Blocks.Sources.Ramp input_vaporPort(
    height=0.0001,
    duration=250,
    startTime=500)
    "Input for vapor Port"
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={-40,30})), HideResult=true);

equation
  //
  // Connections
  //
  connect(heatSource.port, singlePhaseSeperator.heatPort)
    annotation (Line(
      points={{20,0},{6,0}},
      color={238,46,47},
      thickness=1));
  connect(liquidSource.port, singlePhaseSeperator.liquidPort[
    1]) annotation (Line(
      points={{-20,-30},{0,-30},{0,-9}},
      color={0,140,72},
      thickness=1));
  connect(vaporPort.port, singlePhaseSeperator.vaporPort[
    1]) annotation (Line(
      points={{-20,30},{0,30},{0,8.8}},
      color={0,140,72},
      thickness=1));
  connect(input_heatFlow.y, heatSource.Q_flow_input)
    annotation (Line(points={{35.6,0},{28,0},{28,-5},{21,
          -5}}, color={0,0,127}));
  connect(input_liquidPort.y, liquidSource.m_flow_input)
    annotation (Line(points={{-35.6,-30},{-30,-30},{-30,-26},
          {-21.2,-26}}, color={0,0,127}));
  connect(input_vaporPort.y, vaporPort.m_flow_input)
    annotation (Line(points={{-35.6,30},{-30,30},{-30,34},
          {-21.2,34}}, color={0,0,127}));

  //
  // Annotations
  //
  annotation (experiment(StopTime=1000), Documentation(revisions="<html>
<ul>
  <li>
  January 13, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestSinglePhaseSeperator;
