within SorpLib.Components.PhaseSeperators.TILMediaLibrary;
model SinglePhaseSeperator
  "Phase seperator of pure fluid using the TILMedia library"
  extends BaseClasses.PartialSinglePhaseSeperator(
    final type_Media=Internals.Types.MediaModel.TIL_VLE,
    redeclare final Connectors.TILMediaLibrary.VLEPort_a liquidPort(
      each final vleFluidType=vleFluidType),
    redeclare final Connectors.TILMediaLibrary.VLEPort_a vaporPort(
      each final vleFluidType=vleFluidType));

  //
  // Definition of parameters
  //
  replaceable parameter TILMedia.VLEFluidTypes.TILMedia_Water vleFluidType
    constrainedby TILMedia.VLEFluidTypes.BaseVLEFluid
    "VLE media"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                Hide=true);

  //
  // Definition of media models
  //
  TILMedia.VLEFluid_dT stateProperties(
    final vleFluidType=vleFluidType,
    final computeSurfaceTension=false,
    final d=rho,
    final T=T)
    "Model calculating thermodynamic properties"
    annotation (Placement(transformation(extent={{-10,-12},{10,8}})));

equation
  //
  // Assertations
  //
  assert(no_components==1,
    "Error in phase seperator model: This model is only valid for
     one component!");

  if type_energyBalance ==
    Internals.Types.BalanceEquations.SteadyState_FreeInitial then
    assert(type_overallMassBalance ==
      Internals.Types.BalanceEquations.SteadyState_FreeInitial,
      "Steady-state energy balance is only allowed in combination with
       steady-state mass balance!");
   end if;

  //
  // Passing state variables
  //
  p = stateProperties.p
    "Pressure of fluid in phase seperator";
  h = stateProperties.h
    "Specific enthalpy of fluid in phase seperator";

  cv = stateProperties.cv
    "Specific heat capacity at constant volume of fluid in phase seperator";

  rho_liq = stateProperties.VLE.d_l
    "Bubble density of fluid in phase seperator";
  rho_vap = stateProperties.VLE.d_v
    "Dew density of fluid in phase seperator";

  h_liq = stateProperties.VLE.h_l
    "Bubble density of fluid in phase seperator";
  h_vap = stateProperties.VLE.h_v
    "Dew density of fluid in phase seperator";

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 13, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end SinglePhaseSeperator;
