within SorpLib.Components.Sensors.Fluid.BaseClasses;
partial model PartialFlowSensor "Base model for all flow sensors"

  //
  // Definition of parameters
  //
  parameter Integer no_components = 1
    "Number of components"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);

  parameter Boolean avoid_events = true
    "= true, if events are avoid by using noEvent()-operator"
    annotation (Dialog(tab = "Advanced", group = "Numerics"),
                Evaluate=true,
                HideResult = true);

  //
  // Definition of constants
  //
protected
  constant Internals.Types.MediaModel type_Media=
    Internals.Types.MediaModel.Modelica_VLE
    "Type required to check consistency of media models"
    annotation (HideResult=true);

  //
  // Definition of connectors
  //
public
  replaceable Connectors.BaseClasses.PartialMediaConnector port_a(
    final no_components=no_components)
    "Inlet fluid port at design direction"
    annotation (Placement(transformation(extent={{-70,-10},{-50,10}})));
  replaceable Connectors.BaseClasses.PartialMediaConnector port_b(
    final no_components=no_components)
    "Outlet fluid port at design direction"
    annotation (Placement(transformation(extent={{50,-10},{70,10}})));

  Modelica.Blocks.Interfaces.RealOutput value "
    Value measured by sensor"
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={0,60})));
equation
  //
  // Connections
  //
  connect(port_a, port_b) annotation (Line(
      points={{-60,0},{60,0}},
      color={0,0,0},
      thickness=1));

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-60,-60},
            {60,60}}), graphics={Ellipse(
          extent={{-60,60},{60,-60}},
          lineColor={0,0,0},
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid)}),                      Diagram(
        coordinateSystem(preserveAspectRatio=false, extent={{-60,-60},{60,60}})),
    Documentation(revisions="<html>
<ul>
  <li>
  January 20, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialFlowSensor;
