within SorpLib.Components.Sensors.Fluid.ModelicaMediaLibrary;
model Liquid_SpecificEnthalpy
  "Sensor measuring specific enthalpy at desig inlet (port A)"
  extends BaseClasses.PartialFlowSensor(
    final type_Media=Internals.Types.MediaModel.Modelica_IL,
    redeclare Connectors.ModelicaMediaLibrary.LiquidPort_a port_a(redeclare
        final package Medium =
                         Medium),
    redeclare Connectors.ModelicaMediaLibrary.LiquidPort_b port_b(redeclare
        final package Medium =
                         Medium));

  //
  // Definition of parameters
  //
  parameter Boolean allowFlowReversal = false
    " = true, if flow reversal is allowed"
    annotation (Dialog(tab="General", group="General"),
                Evaluate=true,
                HideResult=true);

  replaceable package Medium = Modelica.Media.Water.WaterIF97_R1pT
    constrainedby Modelica.Media.Interfaces.PartialMedium
    "Medium model"
    annotation (Dialog(tab="Media", group="Medium Model"),
                evaluate=true,
                HideResult=true,
                choicesAllMatching=true);

equation
  //
  // Get sensor value
  //
  if allowFlowReversal then
    value = SorpLib.Internals.Numerics.regStep_noEvent(
      port_a.m_flow,
      port_b.h_outflow,
      port_a.h_outflow,
      1e-4) "Specific enthalpy at actual inlet";

  else
    value = port_b.h_outflow
      "Specific enthalpy at design inlet";

  end if;

  //
  // Annotations
  //
  annotation (Icon(graphics={Text(
          extent={{-60,50},{60,-30}},
          lineColor={0,0,0},
          lineThickness=1,
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid,
          textString="h"),
     Line(points={{-40,-30},{38,-30}},
          color={0,0,0},
          thickness=1,
          arrow={Arrow.None,Arrow.Filled})}), Documentation(revisions="<html>
<ul>
  <li>
  January 20, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end Liquid_SpecificEnthalpy;
