within SorpLib.Components.Sensors.Fluid.TILMediaLibrary;
model Liquid_MassFlowRate
  "Sensor measuring mass flow rate at design inlet (port A)"
  extends BaseClasses.PartialFlowSensor(
    final type_Media=Internals.Types.MediaModel.TIL_IL,
    redeclare final Connectors.TILMediaLibrary.LiquidPort_a port_a(
      final liquidType=Medium),
    redeclare final Connectors.TILMediaLibrary.LiquidPort_b port_b(
      final liquidType=Medium));

  //
  // Definition of parameters
  //
  replaceable parameter TILMedia.LiquidTypes.TILMedia_Water Medium
    constrainedby TILMedia.LiquidTypes.BaseLiquid
    "Medium model"
    annotation (Dialog(tab="Media", group="Medium Model"),
                evaluate=true,
                HideResult=true,
                choicesAllMatching=true);

equation
  //
  // Get sensor value
  //
  value = port_a.m_flow
    "Mass flow rate at design inlet";

  //
  // Annotations
  //
  annotation (Icon(graphics={Text(
          extent={{-60,60},{60,-20}},
          lineColor={0,0,0},
          lineThickness=1,
          fillColor={255,255,255},
          fillPattern=FillPattern.Solid,
          textString=".
m"), Line(points={{-40,-30},{38,-30}},
          color={0,0,0},
          thickness=1,
          arrow={Arrow.None,Arrow.Filled})}), Documentation(revisions="<html>
<ul>
  <li>
  January 20, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end Liquid_MassFlowRate;
