within SorpLib.Components.Sensors.Fluid.TILMediaLibrary.Tester;
model TestVLESensor "Model to test VLE sensors"
  extends Modelica.Icons.Example;

  //
  // Definition of sensor models
  //
  VLE_MassFlowRate sensor_m_flow "Mass flow sensor"
    annotation (Placement(transformation(extent={{-56,-6},{-44,6}})));
  VLE_SpecificEnthalpy specificEnthalpy_sensor
    "Sensor to measure specific enthalpy"
    annotation (Placement(transformation(extent={{-36,-6},{-24,6}})));

  //
  // Definition of bounadaries
  //
protected
  Boundaries.TILMediaLibrary.VLEBoundary      designInlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.MassFlow,
    m_flow=-0.15,
    h=400e3) "Design inlet boundary"
    annotation (Placement(transformation(extent={{-90,-10},{-70,10}})));
  Boundaries.TILMediaLibrary.VLEBoundary      designOutlet(
    boundaryType_PF=SorpLib.Internals.Types.BoundaryPotentialFlow.Pressure,
    m_flow=-0.15,
    h=200e3) "Design outlet boundary"
    annotation (Placement(transformation(extent={{70,-10},{90,10}})));

equation
  //
  // Connections
  //
  connect(designInlet.port, sensor_m_flow.port_a) annotation (Line(
      points={{-80,0},{-56,0}},
      color={0,140,72},
      thickness=1));
  connect(sensor_m_flow.port_b, specificEnthalpy_sensor.port_a) annotation (
      Line(
      points={{-44,0},{-36,0}},
      color={0,140,72},
      thickness=1));
  connect(specificEnthalpy_sensor.port_b, designOutlet.port) annotation (Line(
      points={{-24,0},{80,0}},
      color={0,140,72},
      thickness=1));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  January 20, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
xxx
</p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TestVLESensor;
