within SorpLib.Components.Valves.BaseClasses;
partial model PartialValve "Base model for all valves"

  //
  // Definition of parameters
  //
  parameter Integer no_components = 1
    "Number of components"
    annotation (Dialog(tab="General", group="Medium Model"),
                evaluate=true,
                HideResult=true);

  //
  // Definition of constants
  //
protected
  constant Internals.Types.MediaModel type_Media=
    Internals.Types.MediaModel.Modelica_VLE
    "Type required to check consistency of media models"
    annotation (HideResult=true);

  //
  // Connectors
  //
public
  replaceable Connectors.BaseClasses.PartialMediaConnector port_a(
    final  no_components=no_components) "Design inlet"
    annotation (Placement(transformation(extent={{90,-10},{110,10}})));
  replaceable Connectors.BaseClasses.PartialMediaConnector port_b(
    final no_components=no_components) "Design outlet"
    annotation (Placement(transformation(extent={{-110,-10},{-90,10}})));

equation
  //
  // Mass balance
  //
  0 = port_a.m_flow + port_b.m_flow
    "Steady state mass balance";

  port_a.xi_outflow = inStream(port_b.xi_outflow)
    "Stream variable: Trivial equation since no change of mass fractions";
  port_b.xi_outflow = inStream(port_a.xi_outflow)
    "Stream variable: Trivial equation since no change of mass fractions";

  //
  // Energy balance
  //
  port_a.h_outflow = inStream(port_b.h_outflow)
    "Stream variable: Trivial equation since no change of energy";
  port_b.h_outflow = inStream(port_a.h_outflow)
    "Stream variable: Trivial equation since no change of energy";

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false)), Diagram(
        coordinateSystem(preserveAspectRatio=false)),
    Documentation(revisions="<html>
<ul>
  <li>
  January 20, 2021, by Mirko Engelpracht:<br/>
  Smaller revisions after restructuring of the library.
  </li>
  <li>
  December 11, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
  <p>
    The VLE valves are used to connect two VLE volumes and determine the mass flow between the volumes. 
    The valve is modeled isenthalpic with no volume. 
    The partial model includes the main equations, used for VLE valves models including:
    <ul>
      <li>2 vle ports</li>
      <li>Mass balance</li>
      <li>Energy balance</li>
    </ul>
  </p>
<h4>Main equations</h4>
  <p>
    The VLE valve is modelled as isenthalpic valves with no storage volume. 
    Thus, the mass balance reads:
    <p align=\"center\"><i><code>m&#775;</code></i><sub>in</sub> = <i><code>m&#775;</code></i><sub>out</sub> </p>
    The energy balance boils down to equal specific enthalpies:
    <p align=\"center\"><i>h</i><sub>in</sub> = <i>h</i><sub>out</sub> </p>
  </p>
<h4>Assumptions and limitations</h4>
<p>
xxx
</p>
<h4>Typical use and important parameters</h4>
<p>
xxx
</p>
<h4>Options</h4>
<p>
xxx
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>Implementation</h4>
<p>
xxx
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialValve;
