within SorpLib.Internals.Numerics;
function regStep_noEvent
  "Approximation of a general step, such that the characteristic is continuous and differentiable"
  extends Modelica.Icons.Function;

  //
  // Definition of inputs
  //
  input Real x
    "Abscissa value";
  input Real y1
    "Ordinate value for x > 0";
  input Real y2
    "Ordinate value for x < 0";
  input Real x_small(min=0) = 1e-5
    "Approximation of step for -x_small <= x <= x_small; x_small >= 0 required";

  //
  // Definition of outputs
  //
  output Real y
    "Ordinate value to approximate y = if x > 0 then y1 else y2";

algorithm
  y := smooth(1, noEvent(if x >  x_small then y1 else
                         if x < -x_small then y2 else
                         if x_small > 0 then
                           (x/x_small)*((x/x_small)^2 - 3)*(y2-y1)/4 + (y1+y2)/2 else (y1+y2)/2));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end regStep_noEvent;
