within SorpLib.Internals.Numerics;
function squareFunction_noEvent
  "Approximation of square function, such that the slope becomes zero at the 
  origin, that the function  is continuous and differentiable, and that sign
  of input does not change"
  extends Modelica.Icons.Function;

  //
  // Definition of inputs
  //
  input Real x
    "Value";
  input Real delta_x = 1e-4
    "Regulation value for approximation";

  //
  // Definition of outputs
  //
  output Real y
    "Approximated value";

algorithm
  if noEvent(x > delta_x) then
    y := x*x;

  elseif noEvent(x < -delta_x) then
    y := -x*x;

  else
    y := (0.5/delta_x*x*x + 0.5*delta_x)*x;

  end if;

  //
  // Annotations
  //
  annotation(smoothOrder=1, inverse(x = squareFunction_inverse_noEvent(y,delta_x)),
    Documentation(revisions="<html>
<ul>
  <li>
  January 18, 2021, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end squareFunction_noEvent;
