within SorpLib.Media.Function.SingleComponent.AdsorptionEnthalpy.Tester;
model TestDhAds_ClausiusClapeyron_num
  "Model to test Clausius-Clapeyron approach for calculating adsorption enthalpy"
  extends Modelica.Icons.Example;

  //
  // Definition of temperature
  //
  parameter Modelica.SIunits.Pressure M = 0.018015
    "Molar mass of sorptive";

  parameter Modelica.SIunits.Pressure p = 250
    "Adsorption pressure";
  parameter  Modelica.SIunits.Temperature T = 303.15
    "Adsorption temperature";

  //
  // Definition of variables
  //
  Modelica.SIunits.SpecificEnthalpy dhAds
    "Specific enthalpy of adsorption";

equation
  //
  // Calculation of specific enthalpy of adsorption
  //
  dhAds =dhAds_ClausiusClapeyron_num(
        Modelica.Constants.R/M,
        0.99*p,
        1.01*p,
        0.99*T,
        1.01*T)
    "Calculating adsorption enthalpy";

  //
  // Annotations
  //
  annotation (Documentation(info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>", revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>"));
end TestDhAds_ClausiusClapeyron_num;
