within SorpLib.Media.Function.SingleComponent.AdsorptionEnthalpy;
function dhAds_ClausiusClapeyron
  "Function that calculates adsorption enthalpy using Clausius-Clapeyron
   approach"
  extends Modelica.Icons.Function;

  //
  // Definition of inputs
  //
  input Modelica.SIunits.SpecificHeatCapacity R_adsorpt
    "Specific gas constant of adsorpt"
    annotation (Dialog(tab="General", group="Inputs"));

  input Modelica.SIunits.Pressure p_adsorpt
    "Pressure of adsorpt"
    annotation (Dialog(tab="General", group="Inputs"));
  input Modelica.SIunits.Temperature T_adsorpt
    "Temperature of adsorpt"
    annotation (Dialog(tab="General", group="Inputs"));

  input Real dx_dT(unit="kg/(kg.K)")
    "Partial derivative of x_adsorpt w.r.t. temperature"
    annotation (Dialog(tab="General", group="Inputs"));
  input Real dx_dp(unit="kg/(kg.Pa)")
    "Partial derivative of x_adsorpt w.r.t. pressure"
    annotation (Dialog(tab="General", group="Inputs"));

  //
  // Definition of outputs
  //
  output Modelica.SIunits.SpecificEnthalpy dh_ads
    "Adsorption enthalpy"
    annotation (Dialog(tab="General", group="Outputs", enable=false));

algorithm
  dh_ads := -R_adsorpt*T_adsorpt*T_adsorpt/
    max(p_adsorpt, Modelica.Constants.small) * dx_dT /
    max(dx_dp, Modelica.Constants.small)
   "Calculation of adsorption enthalpy";

  //
  // Annotations
  //
  annotation (Documentation(info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>", revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>"));
end dhAds_ClausiusClapeyron;
