within SorpLib.Media.Function.SingleComponent.Equilibrium.SurfaceApproach;
function LangmuirIsotherm__dxdT
  "Derivative of Langmuir isotherm with resprect to temperature at constant
   pressure"
  extends BaseClasses.PartialSurfaceFunction_dT;

  //
  // Definition of variables
  //
protected
  Real dx_adsorpt_dc1 = (c[2]*p_adsorpt)/(1 + c[2]*p_adsorpt)
    "Derivative of loading wrt. to first coefficient of Langmuir isotherm";
  Real dx_adsorpt_dc2 = c[1]*p_adsorpt / (1 + c[2]*p_adsorpt) ^2
    "Derivative of loading wrt. to second coefficient of Langmuir isotherm";

algorithm
  //
  // Calculation of derivative of equilibrium loading wrt. temperature
  //
  dx_adsorpt_dT := (dx_adsorpt_dc1 * dc_dT[1]) + (dx_adsorpt_dc2 * dc_dT[2])
    "Derivative of loading wrt. temperature in kg/kg/K";

  //
  // Annotations
  //
  annotation(smoothOrder=2,
             Inline=false, LateInline=true,
    Documentation(revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end LangmuirIsotherm__dxdT;
