within SorpLib.Media.Function.SingleComponent.Equilibrium.SurfaceApproach;
function TothIsotherm__dxdT
  "Derivative of Toth isotherm with respect to temperature at constant pressure"
  extends BaseClasses.PartialSurfaceFunction_dT;

  //
  // Definition of variables
  //
protected
  Modelica.SIunits.Pressure p_adsorpt_eff=
    max(p_adsorpt,Modelica.Constants.small)
    "Effective pressure to avoid errors";

  Real dx_adsorpt_dc1 = p_adsorpt_eff /
    ((1 + (c[2]*p_adsorpt_eff)^c[3])^(1/c[3]))
    "Derivative of loading wrt. to first coefficient of Toth isotherm";
  Real dx_adsorpt_dc2 = -p_adsorpt_eff * (c[2]*p_adsorpt_eff)^c[3] / c[2] *
    SorpLib.Media.Function.SingleComponent.Equilibrium.SurfaceApproach.TothIsotherm__dxdp(
    p_adsorpt, c)
    "Derivative of loading wrt. to second coefficient of Toth isotherm";
  Real dx_adsorpt_dc3 = c[1] * dx_adsorpt_dc1 *
    (log((c[2]*p_adsorpt_eff)^c[3] + 1) / c[3]^2 -
    (c[2]*p_adsorpt_eff)^c[3] * log(c[2]*p_adsorpt_eff) /
    (((c[2]*p_adsorpt_eff)^c[3] + 1) * c[3]))
    "Derivative of loading wrt. to third coefficient of Toth isotherm";

algorithm
  //
  // Calculation of derivative of equilibrium loading wrt. temperature
  //
  dx_adsorpt_dT := (dx_adsorpt_dc1 * dc_dT[1]) + (dx_adsorpt_dc2 * dc_dT[2]) +
    (dx_adsorpt_dc3 * dc_dT[3])
    "Derivative of loading wrt. temperature in kg/kg/K";

  //
  // Annotations
  //
  annotation(smoothOrder=2,
             Inline=false, LateInline=true,
    Documentation(revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TothIsotherm__dxdT;
