within SorpLib.Media.Function.SingleComponent.Equilibrium.SurfaceApproach;
function TothIsotherm_inverse
  "Inverse of Toth isotherm"
  extends BaseClasses.PartialSurfaceFunction_inverse;

  //
  // Definition of outputs
  //
  output Modelica.SIunits.Pressure p_adsorpt
    "Equilibrium pressure of adsorpt"
    annotation (Dialog(tab="General", group="Outputs", enable=false));

  //
  // Definition of variables
  //
protected
  Real x_adsorpt_eff(min=0, unit="1") = max(x_adsorpt,Modelica.Constants.small)
    "Effective loading to avoid errors";

algorithm
  //
  // Calculation of equilibrium pressure
  //
  p_adsorpt := x_adsorpt_eff /
    ((c[1]^c[3]-(c[2]*x_adsorpt_eff)^c[3])^(1/c[3]))
    "Pressure in Pa";

  //
  // Annotations
  //
  annotation (smoothOrder=2,
              inverse(x_adsorpt=SorpLib.Media.Function.SingleComponent.Equilibrium.SurfaceApproach.TothIsotherm(p_adsorpt,c)),
              Inline=false, LateInline=true,
    Documentation(revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TothIsotherm_inverse;
