within SorpLib.Media.Function.SingleComponent.Equilibrium.SurfaceApproach;
function TothIsotherm_inverse__dpdT
  "Derivative of inverse of Toth isotherm with respect to temperature at constant
   loading"
  extends BaseClasses.PartialSurfaceFunction_inverse_dT;

  //
  // Definition of variables
  //
protected
  Real x_adsorpt_eff(min=0, unit="1") = max(x_adsorpt,Modelica.Constants.small)
    "Effective loading to avoid errors";

  Real dp_adsorpt_dc1 = -x_adsorpt_eff * c[1]^(c[3]-1) *
    (c[1]^c[3]-(c[2]*x_adsorpt_eff)^c[3])^(-1/c[3]-1)
    "Derivative of equilibrium pressure of adsorpt wrt. coefficient 1";
  Real dp_adsorpt_dc2 = x_adsorpt_eff/c[2] * (c[2]*x_adsorpt_eff)^c[3] *
    (c[1]^c[3]-(c[2]*x_adsorpt_eff)^c[3])^(-1/c[3]-1)
    "Derivative of equilibrium pressure of adsorpt wrt. coefficient 2";
  Real dp_adsorpt_dc3 = x_adsorpt_eff * (
    log(c[1]^c[3]-(c[2]*x_adsorpt_eff)^c[3]) / c[3]^2 -
    (c[1]^c[3] * log(c[1]) - (c[2]*x_adsorpt_eff)^c[3] *
    log(c[2]*x_adsorpt_eff)) /
    ((c[1]^c[3]-(c[2]*x_adsorpt_eff)^c[3])*c[3])) /
    ((c[1]^c[3]-(c[2]*x_adsorpt_eff)^c[3])^(1/c[3]))
    "Derivative of equilibrium pressure of adsorpt wrt. coefficient 3";

algorithm
  //
  // Calculation of derivative of equilibrium pressure wrt. temperature
  //
  dp_adsorpt_dT := dp_adsorpt_dc1*dc_dT[1] + dp_adsorpt_dc2*dc_dT[2] +
    dp_adsorpt_dc3*dc_dT[3]
    "Derivative of equilibrium pressure of adsorpt wrt. temperature";

  //
  // Annotations
  //
  annotation (smoothOrder=2,
              Inline=false, LateInline=true,
    Documentation(revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end TothIsotherm_inverse__dpdT;
