within SorpLib.Media.Function.SingleComponent.Equilibrium.VolumetricApproach;
function CharCurve_Arctan__dAdW
  "Function for derivative dAdW of characteristic curve W(A) using arctan-approach"
  extends BaseClasses.PartiaVolumetricFunction_inverse;

  //
  // Definition of outputs
  //
  output Real dAdW(unit="J/m3")
    "Derivative of adsorption potential A wrt to specific volume of adsorbate W"
    annotation(Dialog(tab = "General", group= "Outputs", enable=false));

algorithm
  //
  // Calculate derivative
  //
  dAdW := c[3]*Modelica.Constants.pi /
    (c[1]*cos((W-c[4])/c[1]*Modelica.Constants.pi-Modelica.Constants.pi/2)^2);

  //
  // Annotations
  //
  annotation(smoothOrder=2,
             Inline=false, LateInline=true,
    Documentation(revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  Adaptations (e.g., object-orientied approach) due to restructuring of the library.
  </li>
  <li>
  October 18, 2018, by Andrej Gibelhaus:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>This function describes the derivative of the inverse characteristic curve with respect to the specific volume of adsorbent <i>W</i>: <i>dA/dW</i> </p>
<h4>Main equations</h4>
<p>The derivative with respect to the specific volume of adsorbent has the following basic equation: </p>
<p align=\"center\"><i>dA/dW = c<sub>3</sub> / cos((W-c<sub>4</sub>) * <code>&pi;</code> / c<sub>1</sub>  - <code>&pi;</code> / 2)<sup>2</sup>
<p>where <i>c<sub>1</i></sub>,<i>c<sub>2</i></sub>,<i>c<sub>3</i></sub>,<i>c<sub>4</i></sub> are the fit parameters of the chracteristic curve. </p>
<h4>Assumptions and limitations</h4>
<p>Both the adsorption potential A and the specific volume of the adsorbate W should be non-negative </p>
<h4>Typical uses</h4>
<p>The function is used to describe empirical equilibrium data of working pairs following the Dubinin model. </p>
<h4>References</h4>
<p>This type of characteristic curve is used in the following publications: </p>
<ul>
<li>Schawe, D. Theoretical and Experimental Investigations of an Adsorption Heat Pump with Heat Transfer between two Adsorbers. PhD Thesis. Stuttgart, 1999. </li>
</ul>
</html>"));
end CharCurve_Arctan__dAdW;
