within SorpLib.Media.Function.SingleComponent.Equilibrium.VolumetricApproach;
function CharCurve_Arctan__dWdA
  "Function for derivative dWdA of characteristic curve W(A) using arctan-approach"
  extends BaseClasses.PartiaVolumetricFunction;

  //
  // Definition of outputs
  //
  output Real dWdA(unit="m3/J")
    "Derivative of specific volume of adsorbate W wrt to adsorption potential A"
    annotation(Dialog(tab = "General", group= "Outputs", enable=false));

algorithm
  //
  // Calculate derivative
  //
  dWdA := c[1]/(Modelica.Constants.pi*c[3]*(1 + (A
     - c[2])^2/c[3]^2));

  //
  // Annotations
  //
  annotation(smoothOrder=2,
             Inline=false, LateInline=true,
    Documentation(revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  Adaptations (e.g., object-orientied approach) due to restructuring of the library.
  </li>
  <li>
  November 17, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>This function describes the derivative of the characteristic curve with respect to the adsorption potential <i>A</i>: <i>dW/dA</i> </p>
<h4>Main equations</h4>
<p>The derivative with respect to the adsorption potential has the following basic equation: </p>
<p align=\"center\"><i>dW/dA = c<sub>1</sub> / ( <code>&pi;</code> * c<sub>3</sub> ( 1 + (A-c<sub>2</sub>)<sup>2</sup> / c<sub>3</sub><sup>2</sup> )) </i></p>
<p>where <i>c<sub>1</i></sub>,<i>c<sub>2</i></sub>,<i>c<sub>3</i></sub>,<i>c<sub>4</i></sub> are the fit parameters of the chracteristic curve. </p>
<h4>Assumptions and limitations</h4>
<p>Both the adsorption potential A and the specific volume of the adsorbate should be non-negative </p>
<h4>Typical use</h4>
<p>The function is used to describe empirical equilibrium data of working pairs following the Dubinin model. </p>
<h4>References</h4>
<p>This type of characteristic curve is used in the following publications: </p>
<ul>
<li>Schawe, D. Theoretical and Experimental Investigations of an Adsorption Heat Pump with Heat Transfer between two Adsorbers. PhD Thesis. Stuttgart, 1999. </li>
</ul>
</html>"));
end CharCurve_Arctan__dWdA;
