within SorpLib.Media.Function.SingleComponent.Equilibrium.VolumetricApproach;
function CharCurve_Arctan_inverse
  "Function for inverse of characteristic curve W(A) using arctan-approach"
  extends BaseClasses.PartiaVolumetricFunction_inverse;

  //
  // Definition of outputs
  //
  output Modelica.SIunits.SpecificEnergy A
    "Adsorption potential"
    annotation(Dialog(tab = "General", group= "Outputs", enable=false));

algorithm
  //
  // Calculate adsorption potential
  //
  A := c[3] * Modelica.Math.tan((W-c[4])/c[1]*Modelica.Constants.pi -
    Modelica.Constants.pi/2)+c[2];

  //
  // Annotations
  //
  annotation(smoothOrder=2, inverse(W=SorpLib.Media.Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan(A,c)),
             Inline=false, LateInline=true,
    Documentation(revisions="<html>
<ul>
  <li>
  December 10, 2020, by Mirko Engelpracht:<br/>
  Adaptations (e.g., object-orientied approach) due to restructuring of the library.
  </li>
  <li>
  November 17, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>
This function implements the inverse function of the arctan characteristic curves.
</p>
<h4>Main equations</h4>
<p>
The characteristic curve has the following basic equation:
<p align=\"center\" style=\"font-style:italic;\">
A = c<sub>3</sub> tan (( W - c<sub>4</sub> ) * <code>&#960;</code> / c<sub>1</sub>  - <code>&#960;</code> / 2 ) + c<sub>2</sub> ,
</p>
<p>
where <i>c<sub>1</sub></i>,<i>c<sub>2</sub></i>,<i>c<sub>3</sub></i>,<i>c<sub>4</sub></i> are the fit parameters of the chracteristic curve.
</p>
<h4>Assumptions and limitations</h4>
<p>
Both the adsorption potential A and the specific volume of the adsorbate should be non-negative
</p>
<h4>Typical use</h4>
<p>
The function is used to describe empirical equilibrium data of working pairs following the Dubinin model.
</p>
<h4>References</h4>
<p>
This type of characteristic curve is used in the following publications:
<ul>
  <li>
  Schawe, D. Theoretical and Experimental Investigations of an Adsorption Heat Pump with Heat Transfer between two Adsorbers. PhD Thesis. Stuttgart, 1999.
  </li>
</ul>
</p>
</html>"));
end CharCurve_Arctan_inverse;
