within SorpLib.Media.WorkingPair.BaseClasses;
partial model PartialMediaModel "Base model for all models calculating fluid properties required by 
   adsorption equilibrium models"

  //
  // Definition of parameters
  //
  parameter Boolean calculate_caloric_properties=true
    "= true, to calculate caloric properties (e.g. u_adsorpt, h_adsorpt, ...)"
    annotation (Dialog(tab="Media", group="General"),
                Evaluate=true,
                HideResult = true);

  parameter Internals.Types.AdsorptionEnthalpy type_AdsorptionEnthalpy=
    Internals.Types.AdsorptionEnthalpy.Bonding
    "Calculation approach for adsorption enthalpy"
    annotation (Dialog(tab="Advanced",group="Adsorption Enthalpy",
                enable=calculate_caloric_properties),
                Evaluate=true,
                HideResult = true);

  parameter Internals.Types.SpecificEnthalpySorptive type_SpecEnthalpySorptive=
    Internals.Types.SpecificEnthalpySorptive.Media_pT
    "Calculation approach for specific enthalpy of sorptive (i.e., gas or vapor
     phase)"
    annotation (Dialog(tab="Advanced",group="Sorptive",
                enable = calculate_caloric_properties),
                Evaluate=true,
                HideResult = true);

  parameter Internals.Types.SpecificEnthalpyAdsorpt type_SpecEnthalpyAdsorpt=
    Internals.Types.SpecificEnthalpyAdsorpt.AdsEnthalpy
    "Calculation approach for specific enthalpy of adsorpt (e.g., definition of
     adsorption enthalpy or detailed model)"
    annotation (Dialog(tab="Advanced",group="Adsorpt",
                enable = calculate_caloric_properties),
                Evaluate=true,
                HideResult = true);
  parameter Internals.Types.SpecificHeatCapacityAdsorpt type_SpecHeatCapacityAdsorpt=
    Internals.Types.SpecificHeatCapacityAdsorpt.SatLiq
    "Calculation approach for specific heat capacity of adsorpt"
    annotation (Dialog(tab="Advanced",group="Adsorpt",
                enable = calculate_caloric_properties),
                Evaluate=true,
                HideResult = true);
  parameter Boolean use_SpecVolumeAdsorpt = true
    "= true, if term p_adsorpt*v_adsorpt shall be considered when calculating
     internal energy of adsorpt"
    annotation (Dialog(tab="Advanced",group="Adsorpt",
                enable = calculate_caloric_properties),
                Evaluate=true,
                HideResult = true);
  parameter Internals.Types.SpecificVolumeAdsorpt type_SpecVolumeAdsorpt=
    Internals.Types.SpecificVolumeAdsorpt.SatLiq
    "Calculation approach for specific volume of adsorpt"
    annotation (Dialog(tab="Advanced",group="Adsorpt",
                enable = calculate_caloric_properties and use_SpecVolumeAdsorpt),
                Evaluate=true,
                HideResult = true);

  parameter Boolean avoid_events = true
    "= true, if events are avoid by using noEvent()-operator"
    annotation (Dialog(tab = "Advanced", group = "Numerics"),
                Evaluate=true,
                HideResult = true);

  //
  // Definition of inputs
  //
  input Modelica.SIunits.Temperature T_adsorpt
    "Temperature of adsorpt (i.e., equilibrium temperature)"
    annotation (Dialog(tab = "General", group = "Inputs"));

  //
  // Annotations
  //
  annotation (Icon(coordinateSystem(preserveAspectRatio=false), graphics={
        Rectangle(
          extent={{-100,100},{100,-100}},
          lineColor={175,175,175},
          fillColor={215,215,215},
          fillPattern=FillPattern.Solid,
          radius=25),
        Line(
          points={{-66,-70},{-52,-20},{-22,50},{14,76},{58,76},{83,55},{72,2},{58,
              -40},{48,-70}},
          color={0,0,0},
          smooth=Smooth.Bezier),
        Line(
          points={{-30,30},{78,30}},
          color={0,0,0}),
        Line(
          points={{-30,30},{-34,44},{-38,70}},
          color={0,0,0}),
        Line(
          points={{78,30},{96,-48}},
          color={0,0,0}),
        Line(
          points={{-50,-18},{66,-18}},
          color={0,0,0}),
        Line(
          points={{-50,-18},{-58,8},{-62,40}},
          color={0,0,0}),
        Line(
          points={{66,-18},{80,-70}},
          color={0,0,0}),
        Line(
          points={{-66,-70},{48,-70}},
          color={0,0,0}),
        Line(
          points={{-66,-70},{-74,-34},{-78,18}},
          color={0,0,0}),
        Text(
          extent={{-100,96},{100,76}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillColor={215,215,215},
          fillPattern=FillPattern.Solid,
          textString="Fluid Properties",
          textStyle={TextStyle.Bold})}), Diagram(coordinateSystem(
          preserveAspectRatio=false)),
    Documentation(revisions="<html>
<ul>
  <li>
  December 14, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialMediaModel;
