within SorpLib.Media.WorkingPair.SingleComponent.BaseClasses;
partial model PartialSingleMediaModel_Surface "Base model for all models calculating fluid properties required by 
   adsorption equilibrium models of single component adsorption based on the 
   surface approach"
  extends PartialSingleMediaModel(
    type_SpecEnthalpyAdsorpt=
      Internals.Types.SpecificEnthalpyAdsorpt.AdsEnthalpy,
    type_AdsorptionEnthalpy=
      Internals.Types.AdsorptionEnthalpy.ClausiusClapeyron);

  //
  // Definition of internal variables
  //
protected
  Modelica.Blocks.Interfaces.RealInput v_adsorpt_dummy(final unit="m3/kg")=
    -1 if not calculate_caloric_properties or not use_SpecVolumeAdsorpt
    "Specific volume of sorptive: Dummy value if caloric properties are not
     required"
    annotation (HideResult = true);

equation
  //
  // Connections for conditional removed variables / models
  //
  connect(v_adsorpt, v_adsorpt_dummy);

  //
  // Annotations
  //
  annotation (Icon(graphics={
        Text(
          extent={{-52,-68},{48,-88}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillColor={215,215,215},
          fillPattern=FillPattern.Solid,
          textStyle={TextStyle.Bold},
          textString="Surface Approach")}), Documentation(revisions="<html>
<ul>
  <li>
  December 14, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialSingleMediaModel_Surface;
