within SorpLib.Media.WorkingPair.SingleComponent.BaseClasses;
partial model PartialTester
  "Base test model for working pairs describing single component adsorption"
  extends Modelica.Icons.Example;

  //
  // Definition of parameters
  //
  replaceable model WorkingPair =
    PartialSingleWPair constrainedby PartialSingleWPair
    "Model of single-component working pair"
    annotation(choicesAllMatching = true);

  //
  // Instanziation of models
  //
  WorkingPair workingPair(
    final x_adsorpt=x_adsorpt,
    final T_adsorpt=T_adsorpt)
    "Working pair model"
    annotation(Placement(transformation(extent={{-10,-10},{10,10}})));

  //
  // Definition of variables
  //
protected
  Real x_adsorpt(unit="kg/kg")
    "Equilibrium loading"
    annotation (HideResult = true);
  Modelica.SIunits.Temperature T_adsorpt
    "Equilibrium temperature"
    annotation (HideResult = true);

equation
  //
  // Change equilibrium properties wrt. time
  //
  x_adsorpt = 1e-3 + 0.01*time;
  T_adsorpt = (273.15 + 30) + 0.25*time^2;

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  December 14, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end PartialTester;
