within SorpLib.Media.WorkingPair.SingleComponent.MediaModels;
model SingleMediaModel_Volumetric_TIL_VLE
  "Media model required by adsorption equilibrium models of single component 
   adsorption based on the volumetric approach and using the TILMedia library 
   to calculate fluid properties"
  extends BaseClasses.PartialSingleMediaModel_Volumetric;

  //
  // Definition of parameters
  //
  replaceable parameter TILMedia.VLEFluidTypes.TILMedia_Water vleType
    constrainedby TILMedia.VLEFluidTypes.BaseVLEFluid
    "VLE type"
    annotation (Dialog(tab = "Media", group = "Media Model"),
                choicesAllMatching=true,
                Evaluate=true,
                HideResult=true);

  //
  // Definition of media models
  //
  TILMedia.VLEFluid_pT media_sorptive(
    final vleFluidType=vleType,
    final stateSelectPreferForInputs=false,
    final computeTransportProperties=false,
    final interpolateTransportProperties=true,
    final computeSurfaceTension=false,
    final deactivateDensityDerivatives=true,
    final computeVLEAdditionalProperties=false,
    final computeVLETransportProperties=false,
    final deactivateTwoPhaseRegion=false,
    final p=p_adsorpt,
    final T=T_adsorpt) if
    calculate_caloric_properties and ((type_SpecEnthalpySorptive==
    Internals.Types.SpecificEnthalpySorptive.Media_pT) or
    (type_SpecHeatCapacityAdsorpt==
    Internals.Types.SpecificHeatCapacityAdsorpt.GasVapor))
    "Fluid properties of sorptive"
    annotation (Placement(transformation(extent={{-10,30},{10,50}})));

  TILMedia.VLEFluid_dT media_adsorpt(
    final vleFluidType=vleType,
    final stateSelectPreferForInputs=false,
    final computeTransportProperties=false,
    final interpolateTransportProperties=true,
    final computeSurfaceTension=false,
    final deactivateDensityDerivatives=true,
    final computeVLEAdditionalProperties=calculate_caloric_properties and (
        type_SpecHeatCapacityAdsorpt ==
        Internals.Types.SpecificHeatCapacityAdsorpt.SatLiq),
    final computeVLETransportProperties=false,
    final deactivateTwoPhaseRegion=false,
    final d=media_adsorpt.VLE.d_l,
    final T=T_adsorpt)
    "Fluid properties of adsorpt"
    annotation (Placement(transformation(extent={{-10,-50},{10,-30}})));

  TILMedia.VLEFluid_dT media_adsorpt_pdT(
    final vleFluidType=vleType,
    final stateSelectPreferForInputs=false,
    final computeTransportProperties=false,
    final interpolateTransportProperties=true,
    final computeSurfaceTension=false,
    final deactivateDensityDerivatives=true,
    final computeVLEAdditionalProperties=false,
    final computeVLETransportProperties=false,
    final deactivateTwoPhaseRegion=false,
    final d=media_adsorpt_pdT.VLE.d_l,
    final T=T_adsorpt+dT_AdsEnt_CC) if calculate_caloric_properties and
    type_AdsorptionEnthalpy ==
    Internals.Types.AdsorptionEnthalpy.ClausiusClapeyron
    "Fluid properties of adsorpt at T_adsorpt+dT_AdsEnt_CC"
    annotation (Placement(transformation(extent={{20,-60},{40,-40}})),
                HideResult=true);

  TILMedia.VLEFluid_dT media_adsorpt_mdT(
    final vleFluidType=vleType,
    final stateSelectPreferForInputs=false,
    final computeTransportProperties=false,
    final interpolateTransportProperties=true,
    final computeSurfaceTension=false,
    final deactivateDensityDerivatives=true,
    final computeVLEAdditionalProperties=false,
    final computeVLETransportProperties=false,
    final deactivateTwoPhaseRegion=false,
    final d=media_adsorpt_mdT.VLE.d_l,
    final T=T_adsorpt-dT_AdsEnt_CC) if calculate_caloric_properties and
    type_AdsorptionEnthalpy ==
    Internals.Types.AdsorptionEnthalpy.ClausiusClapeyron
    "Fluid properties of adsorpt at T_adsorpt+dT_AdsEnt_CC"
    annotation (Placement(transformation(extent={{-40,-60},{-20,-40}})),
                HideResult=true);

  //
  // Definition of internal variables
  //
protected
  Modelica.Blocks.Interfaces.RealInput h_sorptive_media_pT(final unit="J/kg")=
    media_sorptive.h if calculate_caloric_properties and
    (type_SpecEnthalpySorptive==
    Internals.Types.SpecificEnthalpySorptive.Media_pT)
    "Specific enthalpy of sorptive: Calculated with media object using states
     p_adsorpt and T_adsorpt"
    annotation (HideResult = true);
  Modelica.Blocks.Interfaces.RealInput h_sorptive_media_VLE(final unit="J/kg")=
    media_adsorpt.VLE.h_v if calculate_caloric_properties and
    (type_SpecEnthalpySorptive==
    Internals.Types.SpecificEnthalpySorptive.Media_VLE)
    "Specific enthalpy of sorptive: Calculated with VLE media object using states
     T_adsorpt"
    annotation (HideResult = true);

  Modelica.Blocks.Interfaces.RealInput p_sat_adsorpt_media_VLE(final unit="Pa")=
    media_adsorpt.p
    "Saturation pressure at temperature T_adsorpt"
    annotation (HideResult = true);

  Modelica.Blocks.Interfaces.RealInput v_adsorpt_satLiq(final unit="m3/kg")=
    1/media_adsorpt.VLE.d_l if type_SpecVolumeAdsorpt==
    Internals.Types.SpecificVolumeAdsorpt.SatLiq
    "Specific volume of adsorpt: Approximated as saturated liquid"
    annotation (HideResult = true);

  Modelica.Blocks.Interfaces.RealInput h_sat_liq_adsorpt_media_VLE(
    final unit="J/kg") = media_adsorpt.VLE.h_l if
    calculate_caloric_properties and type_SpecEnthalpyAdsorpt==
    Internals.Types.SpecificEnthalpyAdsorpt.BondEnthalpy
    "Specific bubble enthalpy: Dummy value if caloric properties are 
     not required"
    annotation (HideResult = true);

  Modelica.Blocks.Interfaces.RealInput beta_sat_liq_adsorpt_media_VLE(
    final unit="1/K") = media_adsorpt.VLEAdditional.beta_l if
    calculate_caloric_properties and type_SpecEnthalpyAdsorpt==
    Internals.Types.SpecificEnthalpyAdsorpt.BondEnthalpy
    "Bubble isobaric expansion coefficient: Dummy value if caloric properties 
     are not required"
    annotation (HideResult = true);
  Modelica.Blocks.Interfaces.RealInput cp_adsorpt_vapor(final unit="J/(kg.K)")=
    media_sorptive.cp if
    calculate_caloric_properties and (type_SpecHeatCapacityAdsorpt==
    Internals.Types.SpecificHeatCapacityAdsorpt.GasVapor)
    "Specific heat capacity of sorptive: Specific heat capacity of vapor phase"
    annotation (HideResult = true);
  Modelica.Blocks.Interfaces.RealInput cp_adsorpt_satLiq(final unit="J/(kg.K)")=
    media_adsorpt.VLEAdditional.cp_l if
    calculate_caloric_properties and (type_SpecHeatCapacityAdsorpt==
    Internals.Types.SpecificHeatCapacityAdsorpt.SatLiq)
    "Specific heat capacity of sorptive: Specific heat capacity of saturated
     liquid"
    annotation (HideResult = true);

  Modelica.Blocks.Interfaces.RealInput p_sat_mdT_adsorpt_media_VLE(
    final unit="Pa") = media_adsorpt_mdT.p if
    calculate_caloric_properties and type_SpecEnthalpyAdsorpt==
    Internals.Types.SpecificEnthalpyAdsorpt.AdsEnthalpy
    "Saturation pressure at T_adsorpt-dT_AdsEnt_CC"
    annotation (HideResult = true);
  Modelica.Blocks.Interfaces.RealInput p_sat_pdT_adsorpt_media_VLE(
    final unit="Pa") = media_adsorpt_pdT.p if
    calculate_caloric_properties and type_SpecEnthalpyAdsorpt==
    Internals.Types.SpecificEnthalpyAdsorpt.AdsEnthalpy
    "Saturation pressure at T_adsorpt+dT_AdsEnt_CC"
    annotation (HideResult = true);
  Modelica.Blocks.Interfaces.RealInput d_sat_liq_mdT_adsorpt_media_VLE(
    final unit="kg/m3") = media_adsorpt_mdT.VLE.d_l if
    calculate_caloric_properties and type_SpecEnthalpyAdsorpt==
    Internals.Types.SpecificEnthalpyAdsorpt.AdsEnthalpy
    "Saturated liquid density at T_adsorpt-dT_AdsEnt_CC"
    annotation (HideResult = true);
  Modelica.Blocks.Interfaces.RealInput d_sat_liq_pdT_adsorpt_media_VLE(
    final unit="kg/m3") = media_adsorpt_pdT.VLE.d_l if
    calculate_caloric_properties and type_SpecEnthalpyAdsorpt==
    Internals.Types.SpecificEnthalpyAdsorpt.AdsEnthalpy
    "Saturated liquid density at T_adsorpt+dT_AdsEnt_CC"
    annotation (HideResult = true);

equation
  //
  // Connections for conditional removed variables / models
  //
  connect(h_sorptive, h_sorptive_media_pT);
  connect(h_sorptive, h_sorptive_media_VLE);

  connect(v_adsorpt, v_adsorpt_satLiq);

  connect(cp_adsorpt, cp_adsorpt_vapor);
  connect(cp_adsorpt, cp_adsorpt_satLiq);

  connect(p_sat_adsorpt, p_sat_adsorpt_media_VLE);
  connect(h_sat_liq_adsorpt,h_sat_liq_adsorpt_media_VLE);
  connect(beta_sat_liq_adsorpt,beta_sat_liq_adsorpt_media_VLE);

  connect(p_sat_mdT_adsorpt,p_sat_mdT_adsorpt_media_VLE);
  connect(p_sat_pdT_adsorpt,p_sat_pdT_adsorpt_media_VLE);
  connect(d_sat_liq_mdT_adsorpt,d_sat_liq_mdT_adsorpt_media_VLE);
  connect(d_sat_liq_pdT_adsorpt,d_sat_liq_pdT_adsorpt_media_VLE);

  //
  // Annotations
  //
  annotation (Icon(graphics={
        Text(
          extent={{-40,-80},{40,-100}},
          lineColor={0,0,0},
          lineThickness=0.5,
          fillColor={215,215,215},
          fillPattern=FillPattern.Solid,
          textStyle={TextStyle.Bold},
          textString="TILMedia | VLE")}),
                    Diagram(graphics={                         Line(
          points={{0,20},{0,-20}},
          color={0,0,0},
          arrow={Arrow.Open,Arrow.Open}), Text(
          extent={{-20,10},{20,-10}},
          lineColor={0,0,0},
          textString="Equilibrium",
          origin={-10,0},
          rotation=90)}),
    Documentation(revisions="<html>
<ul>
  <li>
  December 14, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end SingleMediaModel_Volumetric_TIL_VLE;
