within SorpLib.Media.WorkingPair.SingleComponent.ParameterizedModels;
partial model CO2_Zeolite5A_Wang
  "CO2 / Zeolite 5A, published by Wang (2009)"
  extends BaseClasses.PartialSingleWPair_Surface(
    final M_adsorpt = 0.0440098,
    final no_coefficients = 3,
    redeclare final function func_x_pT =
        Function.SingleComponent.Equilibrium.SurfaceApproach.TothIsotherm,
    redeclare final function func_p_xT =
        Function.SingleComponent.Equilibrium.SurfaceApproach.TothIsotherm_inverse,
    redeclare final function func_dx_dp_pT =
        Function.SingleComponent.Equilibrium.SurfaceApproach.TothIsotherm__dxdp,
    redeclare final function func_dx_dT_pT =
        Function.SingleComponent.Equilibrium.SurfaceApproach.TothIsotherm__dxdT);

  //
  // Definition of paramters
  //
  final parameter  Real[5] c={9.875e-10*0.044091,6.761e-11,5.625e3,
    2.700e-1,-2.002e1}
    "Coefficients for Toth isotherm"
    annotation (Dialog(tab="General", group="Equilibrium Model"),
                Evaluate=true,
                HideResult = true);

equation
  //
  // Define temperature-dependancy of isotherm coefficients
  //
  c_isotherm = {c[1] * Modelica.Math.exp(c[3] / T_adsorpt),
                c[2] * Modelica.Math.exp(c[3] / T_adsorpt),
                c[4] + c[5] / T_adsorpt}
    "Temperature-dependent coefficients of Toth isotherm";

  //
  // Calculate partial derivatives of isotherm coefficients wrt. temperature
  //
  if calculate_caloric_properties then
    dc_isotherm_dT = {-c[3] / (T_adsorpt^2) * c_isotherm[1],
                      -c[3] / (T_adsorpt^2) * c_isotherm[2],
                      -c[5] / (T_adsorpt^2)}
      "Temperature-dependent coefficients of Toth isotherm";

  else
    dc_isotherm_dT = fill(-1, no_coefficients)
      "Temperature-dependent coefficients of Toth isotherm";

  end if;

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  December 14, 2020, by Mirko Engelpracht:<br/>
  First implementation.
  </li>
</ul>
</html>", info="<html>
<p>
A short introduction.
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
xxx
</p>
</html>"));
end CO2_Zeolite5A_Wang;
