within SorpLib.Media.WorkingPair.SingleComponent.ParameterizedModels;
partial model H2O_AQSOAZ02_Goldsworthy
  "H2O / AQSOA Z02, published by Goldsworthy (2014)"
  extends BaseClasses.PartialSingleWPair_Volumetric(
    final M_adsorpt = 0.018015267,
    final c={3.466e-4,3.094e5,-9.765e4,7.312e-7},
    redeclare final function func_W_A =
        Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan,
    redeclare final function func_A_W =
        Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan_inverse,
    redeclare final function func_dW_dA_A =
        Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan__dWdA,
    redeclare final function func_dA_dW_W =
        Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan__dAdW,
    redeclare final model CharCurve =
      Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan_Summary,
    use_CharCurveLimiter=true,
    A_min=Modelica.Constants.small,
    W_max=(c[1]/Modelica.Constants.pi*(Modelica.Math.atan(
      Modelica.Constants.small-c[2]/c[3]) + Modelica.Constants.pi/2) + c[4]));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  December 14, 2020, by Mirko Engelpracht:<br/>
  Revision after restructering of the library.
  </li>
  <li>
  November 17, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>
  This model provides the equilibrium data for the working pair AQSOA Z02 / Water as measured by Goldsworthy (2014). <br>
  The fit parameters were generated at the Chair of Technical Thermodynamics based on the reported measurement data by Goldsworthy (2014).
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
  <ul>
    <li>Dubinin, M.M. Adsorption in micropores. J. Colloid Interface Sci., 1967, 23(4), 487-499.</li>
    <li>Goldsworthy, M.J. Measurements of water vapour sorption isotherms for RD silica gel, AQSOA-Z01, AQSOA-Z02, AQSOA-Z05 and CECA zeolite 3A. Microporous and Mesoporous Materials, 2014, 196, 59-67.. </li>
  </ul>
</p>
</html>"));
end H2O_AQSOAZ02_Goldsworthy;
