within SorpLib.Media.WorkingPair.SingleComponent.ParameterizedModels;
partial model H2O_Silicagel123_Schawe
  "H2O / Silica gel 123, published by Schawe (1991)"
  extends BaseClasses.PartialSingleWPair_Volumetric(
    final M_adsorpt = 0.018015267,
    final c={5.072313e-4,1.305531e5,-8.492403e4,4.128962e-6},
    redeclare final function func_W_A =
        Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan,
    redeclare final function func_A_W =
        Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan_inverse,
    redeclare final function func_dW_dA_A =
        Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan__dWdA,
    redeclare final function func_dA_dW_W =
        Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan__dAdW,
    redeclare final model CharCurve =
      Function.SingleComponent.Equilibrium.VolumetricApproach.CharCurve_Arctan_Summary,
    use_CharCurveLimiter=true,
    A_min=Modelica.Constants.small,
    W_max=(c[1]/Modelica.Constants.pi*(Modelica.Math.atan(
      Modelica.Constants.small-c[2]/c[3]) + Modelica.Constants.pi/2) + c[4]));

  //
  // Annotations
  //
  annotation (Documentation(revisions="<html>
<ul>
  <li>
  December 14, 2020, by Mirko Engelpracht:<br/>
  Revision after restructering of the library.
  </li>
  <li>
  November 17, 2017, by Uwe Bau:<br/>
  Tidy up implementation and enhance documentation for publication of library.
  </li>
</ul>
</html>", info="<html>
<p>
This model provides the equilibrium data for the working pair Silica gel Grace 123 / Water as measured by Schawe (1999).
</p>
<h4>Main equations</h4>
<p>
Most important equations (e.g., mass and energy balances).
</p>
<h4>Assumptions and limitations</h4>
<p>
Main assumptions and limitations (e.g., ideal mixture).
</p>
<h4>Typical use</h4>
<p>
Typical use of model (e.g., to calculate mass transfer within sorbent).
</p>
<h4>Important parameters and options</h4>
<p>
Main parameters and options of the model (e.g., description of most important flags).
</p>
<h4>Dynamics</h4>
<p>
Describe which states and dynamics are present in the model
and which parameters may be used to influence them.
This need not be added in partial classes.
</p>
<h4>Validation</h4>
<p>
Describe whether the validation was done using
analytical validation, comparative model validation
or empirical validation.
</p>
<h4>References</h4>
<p>
  <ul>
    <li>Dubinin, M.M. Adsorption in micropores. J. Colloid Interface Sci., 1967, 23(4), 487-499.</li>
    <li>Schawe, D. Theoretical and Experimental Investigations of an Adsorption Heat Pump with Heat Transfer between two Adsorbers. PhD Thesis. Stuttgart, 1999. </li>
  </ul>
</p>
</html>"));
end H2O_Silicagel123_Schawe;
